@@ -145,9 +145,13 @@ var _ = Describe("App Runner", func() {
 				"COPILOT_APPLICATION_NAME": appName,
 				"COPILOT_ENVIRONMENT_NAME": envName,
 				"COPILOT_SERVICE_NAME":     svcName,
-				"S3STORAGE_NAME":           fmt.Sprintf("%s-%s-%s-s3storage", appName, envName, svcName),
+				"S3STORAGE_NAME":           "", // The value is unknown because it's autogenerated by CloudFormation.
 			}
 			for _, variable := range svc.Variables {
+				if variable.Name == "S3STORAGE_NAME" {
+					Expect(variable.Value).NotTo(BeEmpty())
+					continue
+				}
 				Expect(variable.Value).To(Equal(expectedVars[variable.Name]))
 			}
 		})
