@@ -68,6 +68,7 @@ func (e EnvInitRequestVPCImport) IsSet() bool {
 // calling copilot env init.
 type EnvInitRequestVPCConfig struct {
 	CIDR               string
+	AZs                string
 	PublicSubnetCIDRs  string
 	PrivateSubnetCIDRs string
 }
@@ -563,8 +564,10 @@ func (cli *CLI) EnvInit(opts *EnvInitRequest) (string, error) {
 			opts.VPCImport.PublicSubnetIDs, "--import-private-subnets", opts.VPCImport.PrivateSubnetIDs)
 	}
 	if (opts.VPCConfig != EnvInitRequestVPCConfig{}) {
-		commands = append(commands, "--override-vpc-cidr", opts.VPCConfig.CIDR, "--override-public-cidrs",
-			opts.VPCConfig.PublicSubnetCIDRs, "--override-private-cidrs", opts.VPCConfig.PrivateSubnetCIDRs)
+		commands = append(commands, "--override-vpc-cidr", opts.VPCConfig.CIDR,
+			"--override-az-names", opts.VPCConfig.AZs,
+			"--override-public-cidrs", opts.VPCConfig.PublicSubnetCIDRs,
+			"--override-private-cidrs", opts.VPCConfig.PrivateSubnetCIDRs)
 	}
 	return cli.exec(exec.Command(cli.path, commands...))
 }
@@ -653,9 +656,9 @@ func (cli *CLI) PipelineInit(app, url, branch string, envs []string) (string, er
 			"-e", strings.Join(envs, ",")))
 }
 
-// PipelineUpdate runs "copilot pipeline update".
-func (cli *CLI) PipelineUpdate(app string) (string, error) {
-	return cli.exec(exec.Command(cli.path, "pipeline", "update", "-a", app, "--yes"))
+// PipelineDeploy runs "copilot pipeline deploy".
+func (cli *CLI) PipelineDeploy(app string) (string, error) {
+	return cli.exec(exec.Command(cli.path, "pipeline", "deploy", "-a", app, "--yes"))
 }
 
 // PipelineShow runs "copilot pipeline show --json"
