@@ -10,9 +10,7 @@ import (
 	"fmt"
 	"io"
 	"io/ioutil"
-	"strconv"
 	"testing"
-	"time"
 
 	"github.com/aws/aws-sdk-go/aws/awserr"
 
@@ -24,76 +22,6 @@ import (
 	"github.com/stretchr/testify/require"
 )
 
-func TestS3_PutArtifact(t *testing.T) {
-	buf := &bytes.Buffer{}
-	fmt.Fprint(buf, "some data")
-	timeNow := strconv.FormatInt(time.Now().Unix(), 10)
-	testCases := map[string]struct {
-		inBucket            string
-		inFileName          string
-		inData              *bytes.Buffer
-		mockS3ManagerClient func(m *mocks.Mocks3ManagerAPI)
-
-		wantErr  error
-		wantPath string
-	}{
-		"should put artifact to s3 bucket and return the path": {
-			inBucket:   "mockBucket",
-			inData:     buf,
-			inFileName: "my-app.addons.stack.yml",
-			mockS3ManagerClient: func(m *mocks.Mocks3ManagerAPI) {
-				m.EXPECT().Upload(&s3manager.UploadInput{
-					Body:   buf,
-					Bucket: aws.String("mockBucket"),
-					Key:    aws.String(fmt.Sprintf("manual/%s/my-app.addons.stack.yml", timeNow)),
-				}).Return(&s3manager.UploadOutput{
-					Location: fmt.Sprintf("https://mockBucket/manual/%s/my-app.addons.stack.yml", timeNow),
-				}, nil)
-			},
-
-			wantPath: fmt.Sprintf("https://mockBucket/manual/%s/my-app.addons.stack.yml", timeNow),
-		},
-		"should return error if fail to upload": {
-			inBucket:   "mockBucket",
-			inData:     buf,
-			inFileName: "my-app.addons.stack.yml",
-			mockS3ManagerClient: func(m *mocks.Mocks3ManagerAPI) {
-				m.EXPECT().Upload(&s3manager.UploadInput{
-					Body:   buf,
-					Bucket: aws.String("mockBucket"),
-					Key:    aws.String(fmt.Sprintf("manual/%s/my-app.addons.stack.yml", timeNow)),
-				}).Return(nil, errors.New("some error"))
-			},
-
-			wantErr: fmt.Errorf(fmt.Sprintf("put manual/%s/my-app.addons.stack.yml to bucket mockBucket: some error", timeNow)),
-		},
-	}
-
-	for name, tc := range testCases {
-		t.Run(name, func(t *testing.T) {
-			// GIVEN
-			ctrl := gomock.NewController(t)
-			defer ctrl.Finish()
-
-			mockS3ManagerClient := mocks.NewMocks3ManagerAPI(ctrl)
-			tc.mockS3ManagerClient(mockS3ManagerClient)
-
-			service := S3{
-				s3Manager: mockS3ManagerClient,
-			}
-
-			gotPath, gotErr := service.PutArtifact(tc.inBucket, tc.inFileName, tc.inData)
-
-			if gotErr != nil {
-				require.EqualError(t, gotErr, tc.wantErr.Error())
-			} else {
-				require.Equal(t, tc.wantPath, gotPath)
-			}
-		})
-
-	}
-}
-
 func TestS3_ZipAndUpload(t *testing.T) {
 	testCases := map[string]struct {
 		mockS3ManagerClient func(m *mocks.Mocks3ManagerAPI)
@@ -185,9 +113,9 @@ func TestS3_Upload(t *testing.T) {
 				m.EXPECT().Upload(gomock.Any()).Do(func(in *s3manager.UploadInput, _ ...func(*s3manager.Uploader)) {
 					b, err := ioutil.ReadAll(in.Body)
 					require.NoError(t, err)
-					require.Equal(t, string(b), "bar")
-					require.Equal(t, aws.StringValue(in.Bucket), "mockBucket")
-					require.Equal(t, aws.StringValue(in.Key), "mockFileName")
+					require.Equal(t, "bar", string(b))
+					require.Equal(t, "mockBucket", aws.StringValue(in.Bucket))
+					require.Equal(t, "mockFileName", aws.StringValue(in.Key))
 				}).Return(&s3manager.UploadOutput{
 					Location: "mockURL",
 				}, nil)
@@ -209,7 +137,7 @@ func TestS3_Upload(t *testing.T) {
 				s3Manager: mockS3ManagerClient,
 			}
 
-			gotURL, gotErr := service.Upload("mockBucket", "mockFileName", namedBinary{})
+			gotURL, gotErr := service.Upload("mockBucket", "mockFileName", bytes.NewBuffer([]byte("bar")))
 
 			if gotErr != nil {
 				require.EqualError(t, gotErr, tc.wantError.Error())
@@ -478,3 +406,27 @@ func TestS3_ParseURL(t *testing.T) {
 		})
 	}
 }
+
+func TestS3_FormatARN(t *testing.T) {
+	testCases := map[string]struct {
+		inPartition string
+		inLocation  string
+
+		wantedARN string
+	}{
+		"success": {
+			inPartition: "aws",
+			inLocation:  "stackset-demo-infrastruc-pipelinebuiltartifactbuc-11dj7ctf52wyf/manual/1638391936/env",
+
+			wantedARN: "arn:aws:s3:::stackset-demo-infrastruc-pipelinebuiltartifactbuc-11dj7ctf52wyf/manual/1638391936/env",
+		},
+	}
+
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			gotARN := FormatARN(tc.inPartition, tc.inLocation)
+
+			require.Equal(t, gotARN, tc.wantedARN)
+		})
+	}
+}
