@@ -9,6 +9,8 @@ import (
 	"net"
 	"testing"
 
+	"github.com/aws/copilot-cli/internal/pkg/aws/ec2"
+
 	"github.com/aws/copilot-cli/internal/pkg/term/selector"
 
 	"github.com/aws/aws-sdk-go/aws"
@@ -34,17 +36,21 @@ type initEnvMocks struct {
 	selCreds     *mocks.MockcredsSelector
 	ec2Client    *mocks.Mockec2Client
 	selApp       *mocks.MockappSelector
+	store        *mocks.Mockstore
 }
 
 func TestInitEnvOpts_Validate(t *testing.T) {
 	testCases := map[string]struct {
-		inEnvName     string
-		inAppName     string
-		inDefault     bool
-		inVPCID       string
-		inPublicIDs   []string
-		inPrivateIDs  []string
+		inEnvName string
+		inAppName string
+		inDefault bool
+
+		inVPCID      string
+		inPublicIDs  []string
+		inPrivateIDs []string
+
 		inVPCCIDR     net.IPNet
+		inAZs         []string
 		inPublicCIDRs []string
 
 		inProfileName     string
@@ -52,11 +58,16 @@ func TestInitEnvOpts_Validate(t *testing.T) {
 		inSecretAccessKey string
 		inSessionToken    string
 
+		setupMocks func(m initEnvMocks)
+
 		wantedErrMsg string
 	}{
 		"valid environment creation": {
 			inEnvName: "test-pdx",
 			inAppName: "phonetool",
+			setupMocks: func(m initEnvMocks) {
+				m.store.EXPECT().GetEnvironment("phonetool", "test-pdx").Return(nil, &config.ErrNoSuchEnvironment{})
+			},
 		},
 		"invalid environment name": {
 			inEnvName: "123env",
@@ -64,6 +75,15 @@ func TestInitEnvOpts_Validate(t *testing.T) {
 
 			wantedErrMsg: fmt.Sprintf("environment name 123env is invalid: %s", errValueBadFormat),
 		},
+		"should error if environment already exists": {
+			inEnvName: "test-pdx",
+			inAppName: "phonetool",
+
+			setupMocks: func(m initEnvMocks) {
+				m.store.EXPECT().GetEnvironment("phonetool", "test-pdx").Return(nil, nil)
+			},
+			wantedErrMsg: "environment test-pdx already exists",
+		},
 		"cannot specify both vpc resources importing flags and configuring flags": {
 			inEnvName:     "test-pdx",
 			inAppName:     "phonetool",
@@ -75,6 +95,10 @@ func TestInitEnvOpts_Validate(t *testing.T) {
 			},
 			inVPCID: "mockID",
 
+			setupMocks: func(m initEnvMocks) {
+				m.store.EXPECT().GetEnvironment("phonetool", "test-pdx").Return(nil, &config.ErrNoSuchEnvironment{})
+			},
+
 			wantedErrMsg: "cannot specify both import vpc flags and configure vpc flags",
 		},
 		"cannot import or configure resources if use default flag is set": {
@@ -82,7 +106,9 @@ func TestInitEnvOpts_Validate(t *testing.T) {
 			inAppName: "phonetool",
 			inDefault: true,
 			inVPCID:   "mockID",
-
+			setupMocks: func(m initEnvMocks) {
+				m.store.EXPECT().GetEnvironment("phonetool", "test-pdx").Return(nil, &config.ErrNoSuchEnvironment{})
+			},
 			wantedErrMsg: fmt.Sprintf("cannot import or configure vpc if --%s is set", defaultConfigFlag),
 		},
 		"should err if both profile and access key id are set": {
@@ -90,7 +116,9 @@ func TestInitEnvOpts_Validate(t *testing.T) {
 			inEnvName:     "test",
 			inProfileName: "default",
 			inAccessKeyID: "AKIAIOSFODNN7EXAMPLE",
-
+			setupMocks: func(m initEnvMocks) {
+				m.store.EXPECT().GetEnvironment("phonetool", "test").Return(nil, &config.ErrNoSuchEnvironment{})
+			},
 			wantedErrMsg: "cannot specify both --profile and --aws-access-key-id",
 		},
 		"should err if both profile and secret access key are set": {
@@ -98,7 +126,9 @@ func TestInitEnvOpts_Validate(t *testing.T) {
 			inEnvName:         "test",
 			inProfileName:     "default",
 			inSecretAccessKey: "wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY",
-
+			setupMocks: func(m initEnvMocks) {
+				m.store.EXPECT().GetEnvironment("phonetool", "test").Return(nil, &config.ErrNoSuchEnvironment{})
+			},
 			wantedErrMsg: "cannot specify both --profile and --aws-secret-access-key",
 		},
 		"should err if both profile and session token are set": {
@@ -106,7 +136,9 @@ func TestInitEnvOpts_Validate(t *testing.T) {
 			inEnvName:      "test",
 			inProfileName:  "default",
 			inSessionToken: "verylongtoken",
-
+			setupMocks: func(m initEnvMocks) {
+				m.store.EXPECT().GetEnvironment("phonetool", "test").Return(nil, &config.ErrNoSuchEnvironment{})
+			},
 			wantedErrMsg: "cannot specify both --profile and --aws-session-token",
 		},
 		"should err if fewer than two private subnets are set:": {
@@ -116,6 +148,11 @@ func TestInitEnvOpts_Validate(t *testing.T) {
 
 			wantedErrMsg: "at least two private subnets must be imported",
 		},
+		"should err if fewer than two availability zones are provided": {
+			inAZs: []string{"us-east-1a"},
+
+			wantedErrMsg: "at least two availability zones must be provided to enable Load Balancing",
+		},
 		"invalid VPC resource import (no VPC, 1 public, 2 private)": {
 			inPublicIDs:  []string{"mockID"},
 			inPrivateIDs: []string{"mockID", "anotherMockID"},
@@ -136,12 +173,22 @@ func TestInitEnvOpts_Validate(t *testing.T) {
 
 	for name, tc := range testCases {
 		t.Run(name, func(t *testing.T) {
+			ctrl := gomock.NewController(t)
+			defer ctrl.Finish()
+			m := initEnvMocks{
+				store: mocks.NewMockstore(ctrl),
+			}
+			if tc.setupMocks != nil {
+				tc.setupMocks(m)
+			}
+
 			// GIVEN
 			opts := &initEnvOpts{
 				initEnvVars: initEnvVars{
 					name:          tc.inEnvName,
 					defaultConfig: tc.inDefault,
 					adjustVPC: adjustVPCVars{
+						AZs:               tc.inAZs,
 						PublicSubnetCIDRs: tc.inPublicCIDRs,
 						CIDR:              tc.inVPCCIDR,
 					},
@@ -158,6 +205,7 @@ func TestInitEnvOpts_Validate(t *testing.T) {
 						SessionToken:    tc.inSessionToken,
 					},
 				},
+				store: m.store,
 			}
 
 			// WHEN
@@ -256,6 +304,18 @@ func TestInitEnvOpts_Ask(t *testing.T) {
 			},
 			wantedError: fmt.Errorf("get environment name: some error"),
 		},
+		"should error if environment already exists": {
+			inAppName: mockApp,
+			setupMocks: func(m initEnvMocks) {
+				gomock.InOrder(
+					m.prompt.EXPECT().
+						Get(envInitNamePrompt, envInitNameHelpPrompt, gomock.Any(), gomock.Any()).
+						Return("test", nil),
+					m.store.EXPECT().GetEnvironment(mockApp, mockEnv).Return(nil, nil),
+				)
+			},
+			wantedError: errors.New("environment test already exists"),
+		},
 		"should create a session from a named profile if flag is provided": {
 			inAppName: mockApp,
 			inEnv:     mockEnv,
@@ -567,16 +627,58 @@ func TestInitEnvOpts_Ask(t *testing.T) {
 			},
 			wantedError: fmt.Errorf("get VPC CIDR: some error"),
 		},
+		"should return err when failed to retrieve list of AZs to adjust": {
+			inAppName: mockApp,
+			inEnv:     mockEnv,
+			inProfile: mockProfile,
+			setupMocks: func(m initEnvMocks) {
+				m.sessProvider.EXPECT().FromProfile(gomock.Any()).Return(mockSession, nil)
+				m.prompt.EXPECT().SelectOne(envInitDefaultEnvConfirmPrompt, gomock.Any(), gomock.Any(), gomock.Any()).
+					Return(envInitAdjustEnvResourcesSelectOption, nil)
+				m.prompt.EXPECT().Get(envInitVPCCIDRPrompt, gomock.Any(), gomock.Any(), gomock.Any()).
+					Return(mockVPCCIDR, nil)
+				m.ec2Client.EXPECT().ListAZs().Return(nil, errors.New("some error"))
+			},
+			wantedError: fmt.Errorf("list availability zones for region %s: some error", mockRegion),
+		},
+		"should return err if the number of available AZs does not meet the minimum": {
+			inAppName: mockApp,
+			inEnv:     mockEnv,
+			inProfile: mockProfile,
+			setupMocks: func(m initEnvMocks) {
+				m.sessProvider.EXPECT().FromProfile(gomock.Any()).Return(mockSession, nil)
+				m.prompt.EXPECT().SelectOne(envInitDefaultEnvConfirmPrompt, gomock.Any(), gomock.Any(), gomock.Any()).
+					Return(envInitAdjustEnvResourcesSelectOption, nil)
+				m.prompt.EXPECT().Get(envInitVPCCIDRPrompt, gomock.Any(), gomock.Any(), gomock.Any()).
+					Return(mockVPCCIDR, nil)
+				m.ec2Client.EXPECT().ListAZs().Return([]ec2.AZ{
+					{
+						Name: "us-east-1a",
+					},
+				}, nil)
+			},
+			wantedError: fmt.Errorf("requires at least 2 availability zones (us-east-1a) in region %s", mockRegion),
+		},
 		"fail to get public subnet CIDRs": {
 			inAppName: mockApp,
 			inEnv:     mockEnv,
 			inProfile: mockProfile,
 			setupMocks: func(m initEnvMocks) {
 				m.sessProvider.EXPECT().FromProfile(gomock.Any()).Return(mockSession, nil)
-				m.prompt.EXPECT().SelectOne(envInitDefaultEnvConfirmPrompt, "", envInitCustomizedEnvTypes, gomock.Any()).
+				m.prompt.EXPECT().SelectOne(envInitDefaultEnvConfirmPrompt, gomock.Any(), gomock.Any(), gomock.Any()).
 					Return(envInitAdjustEnvResourcesSelectOption, nil)
-				m.prompt.EXPECT().Get(envInitVPCCIDRPrompt, envInitVPCCIDRPromptHelp, gomock.Any(), gomock.Any()).
+				m.prompt.EXPECT().Get(envInitVPCCIDRPrompt, gomock.Any(), gomock.Any(), gomock.Any()).
 					Return(mockVPCCIDR, nil)
+				m.ec2Client.EXPECT().ListAZs().Return([]ec2.AZ{
+					{
+						Name: "us-east-1a",
+					},
+					{
+						Name: "us-east-1b",
+					},
+				}, nil)
+				m.prompt.EXPECT().MultiSelect(envInitAdjustAZPrompt, gomock.Any(), gomock.Any(), gomock.Any(), gomock.Any()).
+					Return([]string{"us-east-1a", "us-east-1b"}, nil)
 				m.prompt.EXPECT().Get(envInitPublicCIDRPrompt, envInitPublicCIDRPromptHelp, gomock.Any(), gomock.Any()).
 					Return("", mockErr)
 			},
@@ -588,13 +690,23 @@ func TestInitEnvOpts_Ask(t *testing.T) {
 			inProfile: mockProfile,
 			setupMocks: func(m initEnvMocks) {
 				m.sessProvider.EXPECT().FromProfile(gomock.Any()).Return(mockSession, nil)
-				m.prompt.EXPECT().SelectOne(envInitDefaultEnvConfirmPrompt, "", envInitCustomizedEnvTypes, gomock.Any()).
+				m.prompt.EXPECT().SelectOne(envInitDefaultEnvConfirmPrompt, gomock.Any(), gomock.Any(), gomock.Any()).
 					Return(envInitAdjustEnvResourcesSelectOption, nil)
-				m.prompt.EXPECT().Get(envInitVPCCIDRPrompt, envInitVPCCIDRPromptHelp, gomock.Any(), gomock.Any()).
+				m.prompt.EXPECT().Get(envInitVPCCIDRPrompt, gomock.Any(), gomock.Any(), gomock.Any()).
 					Return(mockVPCCIDR, nil)
-				m.prompt.EXPECT().Get(envInitPublicCIDRPrompt, envInitPublicCIDRPromptHelp, gomock.Any(), gomock.Any()).
+				m.ec2Client.EXPECT().ListAZs().Return([]ec2.AZ{
+					{
+						Name: "us-east-1a",
+					},
+					{
+						Name: "us-east-1b",
+					},
+				}, nil)
+				m.prompt.EXPECT().MultiSelect(envInitAdjustAZPrompt, gomock.Any(), gomock.Any(), gomock.Any(), gomock.Any()).
+					Return([]string{"us-east-1a", "us-east-1b"}, nil)
+				m.prompt.EXPECT().Get(envInitPublicCIDRPrompt, gomock.Any(), gomock.Any(), gomock.Any()).
 					Return(mockSubnetCIDRs, nil)
-				m.prompt.EXPECT().Get(envInitPrivateCIDRPrompt, envInitPrivateCIDRPromptHelp, gomock.Any(), gomock.Any()).
+				m.prompt.EXPECT().Get(envInitPrivateCIDRPrompt, gomock.Any(), gomock.Any(), gomock.Any()).
 					Return("", mockErr)
 			},
 			wantedError: fmt.Errorf("get private subnet CIDRs: some error"),
@@ -609,6 +721,16 @@ func TestInitEnvOpts_Ask(t *testing.T) {
 					Return(envInitAdjustEnvResourcesSelectOption, nil)
 				m.prompt.EXPECT().Get(envInitVPCCIDRPrompt, envInitVPCCIDRPromptHelp, gomock.Any(), gomock.Any()).
 					Return(mockVPCCIDR, nil)
+				m.ec2Client.EXPECT().ListAZs().Return([]ec2.AZ{
+					{
+						Name: "us-east-1a",
+					},
+					{
+						Name: "us-east-1b",
+					},
+				}, nil)
+				m.prompt.EXPECT().MultiSelect(envInitAdjustAZPrompt, gomock.Any(), []string{"us-east-1a", "us-east-1b"}, gomock.Any(), gomock.Any()).
+					Return([]string{"us-east-1a", "us-east-1b"}, nil)
 				m.prompt.EXPECT().Get(envInitPublicCIDRPrompt, envInitPublicCIDRPromptHelp, gomock.Any(), gomock.Any()).
 					Return(mockSubnetCIDRs, nil)
 				m.prompt.EXPECT().Get(envInitPrivateCIDRPrompt, envInitPrivateCIDRPromptHelp, gomock.Any(), gomock.Any()).
@@ -624,8 +746,9 @@ func TestInitEnvOpts_Ask(t *testing.T) {
 					IP:   net.IP{10, 1, 232, 0},
 					Mask: net.IPMask{255, 255, 255, 0},
 				},
-				PrivateSubnetCIDRs: []string{"mockPrivateCIDR"},
-				PublicSubnetCIDRs:  []string{"mockPublicCIDR"},
+				AZs:                []string{"us-east-1a", "us-east-1b"},
+				PrivateSubnetCIDRs: []string{"mockPrivateCIDR1", "mockPrivateCIDR2"},
+				PublicSubnetCIDRs:  []string{"mockPublicCIDR1", "mockPublicCIDR2"},
 			},
 			setupMocks: func(m initEnvMocks) {
 				m.sessProvider.EXPECT().FromProfile(gomock.Any()).Return(mockSession, nil)
@@ -646,6 +769,7 @@ func TestInitEnvOpts_Ask(t *testing.T) {
 				selCreds:     mocks.NewMockcredsSelector(ctrl),
 				ec2Client:    mocks.NewMockec2Client(ctrl),
 				selApp:       mocks.NewMockappSelector(ctrl),
+				store:        mocks.NewMockstore(ctrl),
 			}
 
 			tc.setupMocks(mocks)
@@ -667,6 +791,7 @@ func TestInitEnvOpts_Ask(t *testing.T) {
 				ec2Client:    mocks.ec2Client,
 				prompt:       mocks.prompt,
 				selApp:       mocks.selApp,
+				store:        mocks.store,
 			}
 
 			// WHEN
@@ -685,7 +810,7 @@ func TestInitEnvOpts_Ask(t *testing.T) {
 
 func TestInitEnvOpts_Execute(t *testing.T) {
 	testCases := map[string]struct {
-		inProd bool
+		enableContainerInsights bool
 
 		expectStore             func(m *mocks.Mockstore)
 		expectDeployer          func(m *mocks.Mockdeployer)
@@ -840,12 +965,7 @@ func TestInitEnvOpts_Execute(t *testing.T) {
 				m.EXPECT().GetApplication("phonetool").Return(&config.Application{
 					Name: "phonetool",
 				}, nil)
-				m.EXPECT().CreateEnvironment(&config.Environment{
-					App:       "phonetool",
-					Name:      "test",
-					AccountID: "1234",
-					Region:    "mars-1",
-				}).Return(errors.New("some create error"))
+				m.EXPECT().CreateEnvironment(gomock.Any()).Return(errors.New("some create error"))
 			},
 			expectIdentity: func(m *mocks.MockidentityService) {
 				m.EXPECT().Get().Return(identity.Caller{RootUserARN: "some arn", Account: "1234"}, nil).Times(2)
@@ -884,7 +1004,7 @@ func TestInitEnvOpts_Execute(t *testing.T) {
 			wantedErrorS: "store environment: some create error",
 		},
 		"success": {
-			inProd: true,
+			enableContainerInsights: true,
 
 			expectStore: func(m *mocks.Mockstore) {
 				m.EXPECT().GetApplication("phonetool").Return(&config.Application{Name: "phonetool"}, nil)
@@ -892,8 +1012,10 @@ func TestInitEnvOpts_Execute(t *testing.T) {
 					App:       "phonetool",
 					Name:      "test",
 					AccountID: "1234",
-					Prod:      true,
 					Region:    "mars-1",
+					Telemetry: &config.Telemetry{
+						EnableContainerInsights: true,
+					},
 				}).Return(nil)
 			},
 			expectIdentity: func(m *mocks.MockidentityService) {
@@ -917,7 +1039,6 @@ func TestInitEnvOpts_Execute(t *testing.T) {
 					AccountID: "1234",
 					Region:    "mars-1",
 					Name:      "test",
-					Prod:      false,
 					App:       "phonetool",
 				}, nil)
 				m.EXPECT().AddEnvToApp(gomock.Any()).Return(nil)
@@ -940,6 +1061,9 @@ func TestInitEnvOpts_Execute(t *testing.T) {
 					Name:      "test",
 					AccountID: "1234",
 					Region:    "mars-1",
+					Telemetry: &config.Telemetry{
+						EnableContainerInsights: false,
+					},
 				}).Return(nil)
 			},
 			expectIdentity: func(m *mocks.MockidentityService) {
@@ -965,7 +1089,12 @@ func TestInitEnvOpts_Execute(t *testing.T) {
 						AccountPrincipalARN: "some arn",
 					},
 					CustomResourcesURLs: map[string]string{"mockCustomResource": "mockURL"},
-					Version:             deploy.LatestEnvTemplateVersion,
+					Telemetry: &config.Telemetry{
+						EnableContainerInsights: false,
+					},
+					Version: deploy.LatestEnvTemplateVersion,
+          ArtifactBucketARN:    "arn:aws:s3:::mockBucket",
+					ArtifactBucketKeyARN: "mockKMS",
 				}).Return(&cloudformation.ErrStackAlreadyExists{})
 				m.EXPECT().GetEnvironment("phonetool", "test").Return(&config.Environment{
 					AccountID: "1234",
@@ -978,7 +1107,8 @@ func TestInitEnvOpts_Execute(t *testing.T) {
 			expectAppCFN: func(m *mocks.MockappResourcesGetter) {
 				m.EXPECT().GetAppResourcesByRegion(&config.Application{Name: "phonetool"}, "us-west-2").
 					Return(&stack.AppRegionalResources{
-						S3Bucket: "mockBucket",
+						S3Bucket:  "mockBucket",
+						KMSKeyARN: "mockKMS",
 					}, nil)
 			},
 			expectResourcesUploader: func(m *mocks.MockcustomResourcesUploader) {
@@ -1009,6 +1139,9 @@ func TestInitEnvOpts_Execute(t *testing.T) {
 					Name:      "test",
 					AccountID: "4567",
 					Region:    "us-west-2",
+					Telemetry: &config.Telemetry{
+						EnableContainerInsights: false,
+					},
 				}).Return(nil)
 			},
 			expectIdentity: func(m *mocks.MockidentityService) {
@@ -1069,7 +1202,7 @@ func TestInitEnvOpts_Execute(t *testing.T) {
 			mockIAM := mocks.NewMockroleManager(ctrl)
 			mockCFN := mocks.NewMockstackExistChecker(ctrl)
 			mockResourcesUploader := mocks.NewMockcustomResourcesUploader(ctrl)
-			mockUploader := mocks.NewMockzipAndUploader(ctrl)
+			mockUploader := mocks.NewMockuploader(ctrl)
 			if tc.expectStore != nil {
 				tc.expectStore(mockStore)
 			}
@@ -1100,9 +1233,11 @@ func TestInitEnvOpts_Execute(t *testing.T) {
 
 			opts := &initEnvOpts{
 				initEnvVars: initEnvVars{
-					name:         "test",
-					appName:      "phonetool",
-					isProduction: tc.inProd,
+					name:    "test",
+					appName: "phonetool",
+					telemetry: telemetryVars{
+						EnableContainerInsights: tc.enableContainerInsights,
+					},
 				},
 				store:       mockStore,
 				envDeployer: mockDeployer,
@@ -1115,7 +1250,7 @@ func TestInitEnvOpts_Execute(t *testing.T) {
 				sess:        sess,
 				appCFN:      mockAppCFN,
 				uploader:    mockResourcesUploader,
-				newS3: func(region string) (zipAndUploader, error) {
+				newS3: func(region string) (uploader, error) {
 					return mockUploader, nil
 				},
 			}
