@@ -26,7 +26,6 @@ const (
 	jsonFlag     = "json"
 	allFlag      = "all"
 	forceFlag    = "force"
-
 	// Command specific flags.
 	dockerFileFlag        = "dockerfile"
 	dockerFileContextFlag = "build-context"
@@ -89,9 +88,12 @@ const (
 	publicSubnetsFlag  = "import-public-subnets"
 	privateSubnetsFlag = "import-private-subnets"
 
-	vpcCIDRFlag            = "override-vpc-cidr"
-	publicSubnetCIDRsFlag  = "override-public-cidrs"
-	privateSubnetCIDRsFlag = "override-private-cidrs"
+	overrideVPCCIDRFlag            = "override-vpc-cidr"
+	overrideAZsFlag                = "override-az-names"
+	overridePublicSubnetCIDRsFlag  = "override-public-cidrs"
+	overridePrivateSubnetCIDRsFlag = "override-private-cidrs"
+
+	enableContainerInsightsFlag = "container-insights"
 
 	defaultConfigFlag = "default-config"
 
@@ -137,7 +139,7 @@ const (
 // Descriptions for flags.
 var (
 	svcTypeFlagDescription = fmt.Sprintf(`Type of service to create. Must be one of:
-%s.`, strings.Join(template.QuoteSliceFunc(manifest.ServiceTypes), ", "))
+%s.`, strings.Join(template.QuoteSliceFunc(manifest.ServiceTypes()), ", "))
 	imageFlagDescription = fmt.Sprintf(`The location of an existing Docker image.
 Mutually exclusive with -%s, --%s.`, dockerFileFlagShort, dockerFileFlag)
 	dockerFileFlagDescription = fmt.Sprintf(`Path to the Dockerfile.
@@ -147,9 +149,9 @@ Mutually exclusive with -%s, --%s.`, imageFlagShort, imageFlag)
 	storageTypeFlagDescription = fmt.Sprintf(`Type of storage to add. Must be one of:
 %s.`, strings.Join(template.QuoteSliceFunc(storageTypes), ", "))
 	jobTypeFlagDescription = fmt.Sprintf(`Type of job to create. Must be one of:
-%s.`, strings.Join(template.QuoteSliceFunc(manifest.JobTypes), ", "))
+%s.`, strings.Join(template.QuoteSliceFunc(manifest.JobTypes()), ", "))
 	wkldTypeFlagDescription = fmt.Sprintf(`Type of job or svc to create. Must be one of:
-%s.`, strings.Join(template.QuoteSliceFunc(manifest.WorkloadTypes), ", "))
+%s.`, strings.Join(template.QuoteSliceFunc(manifest.WorkloadTypes()), ", "))
 
 	clusterFlagDescription = fmt.Sprintf(`Optional. The short name or full ARN of the cluster to run the task in. 
 Cannot be specified with '%s', '%s' or '%s'.`, appFlag, envFlag, taskDefaultFlag)
@@ -269,9 +271,16 @@ Cannot be specified with any other flags.`
 	publicSubnetsFlagDescription  = "Optional. Use existing public subnet IDs."
 	privateSubnetsFlagDescription = "Optional. Use existing private subnet IDs."
 
-	vpcCIDRFlagDescription            = "Optional. Global CIDR to use for VPC (default 10.0.0.0/16)."
-	publicSubnetCIDRsFlagDescription  = "Optional. CIDR to use for public subnets (default 10.0.0.0/24,10.0.1.0/24)."
-	privateSubnetCIDRsFlagDescription = "Optional. CIDR to use for private subnets (default 10.0.2.0/24,10.0.3.0/24)."
+	overrideVPCCIDRFlagDescription = `Optional. Global CIDR to use for VPC.
+(default 10.0.0.0/16)`
+	overrideAZsFlagDescription = `Optional. Availability Zone names.
+(default 2 random AZs)`
+	overridePublicSubnetCIDRsFlagDescription = `Optional. CIDR to use for public subnets. 
+(default 10.0.0.0/24,10.0.1.0/24)`
+	overridePrivateSubnetCIDRsFlagDescription = `Optional. CIDR to use for private subnets.
+(default 10.0.2.0/24,10.0.3.0/24)`
+
+	enableContainerInsightsFlagDescription = "Optional. Enable CloudWatch Container Insights."
 
 	defaultConfigFlagDescription = "Optional. Skip prompting and use default environment configuration."
 
