@@ -6,6 +6,7 @@ package cli
 import (
 	"encoding"
 	"io"
+	"time"
 
 	"github.com/aws/copilot-cli/internal/pkg/aws/ec2"
 
@@ -235,8 +236,8 @@ type manifestReader interface {
 	ReadWorkloadManifest(name string) (workspace.WorkloadManifest, error)
 }
 
-type copilotDirGetter interface {
-	CopilotDirPath() (string, error)
+type workspacePathGetter interface {
+	Path() (string, error)
 }
 
 type wsPipelineManifestReader interface {
@@ -259,7 +260,7 @@ type wsSvcReader interface {
 
 type wsSvcDirReader interface {
 	wsSvcReader
-	copilotDirGetter
+	workspacePathGetter
 }
 
 type jobLister interface {
@@ -277,13 +278,13 @@ type wlLister interface {
 
 type wsJobDirReader interface {
 	wsJobReader
-	copilotDirGetter
+	workspacePathGetter
 }
 
 type wsWlDirReader interface {
 	wsJobReader
 	wsSvcReader
-	copilotDirGetter
+	workspacePathGetter
 	wlLister
 	ListDockerfiles() ([]string, error)
 	Summary() (*workspace.Summary, error)
@@ -305,23 +306,15 @@ type wsAddonManager interface {
 	wlLister
 }
 
-type artifactUploader interface {
-	PutArtifact(bucket, fileName string, data io.Reader) (string, error)
-}
-
-type zipAndUploader interface {
+type uploader interface {
+	Upload(bucket, key string, data io.Reader) (string, error)
 	ZipAndUpload(bucket, key string, files ...s3.NamedBinary) (string, error)
 }
 
-type Uploader interface {
-	zipAndUploader
-	Upload(bucket, key string, file s3.NamedBinary) (string, error)
-}
-
 type customResourcesUploader interface {
 	UploadEnvironmentCustomResources(upload s3.CompressAndUploadFunc) (map[string]string, error)
 	UploadRequestDrivenWebServiceCustomResources(upload s3.CompressAndUploadFunc) (map[string]string, error)
-	UploadRequestDrivenWebServiceLayers(upload s3.UploadFunc) (map[string]string, error)
+	UploadNetworkLoadBalancedWebServiceCustomResources(upload s3.CompressAndUploadFunc) (map[string]string, error)
 }
 
 type bucketEmptier interface {
@@ -405,6 +398,10 @@ type domainHostedZoneGetter interface {
 	DomainHostedZoneID(domainName string) (string, error)
 }
 
+type domainInfoGetter interface {
+	IsRegisteredDomain(domainName string) error
+}
+
 type dockerfileParser interface {
 	GetExposedPorts() ([]dockerfile.Port, error)
 	GetHealthCheck() (*dockerfile.HealthCheck, error)
@@ -416,6 +413,7 @@ type statusDescriber interface {
 
 type envDescriber interface {
 	Describe() (*describe.EnvDescription, error)
+	PublicCIDRBlocks() ([]string, error)
 }
 
 type versionGetter interface {
@@ -522,10 +520,7 @@ type credsSelector interface {
 
 type ec2Client interface {
 	HasDNSSupport(vpcID string) (bool, error)
-}
-
-type vpcSubnetLister interface {
-	ListVPCSubnets(vpcID string) (*ec2.VPCSubnets, error)
+	ListAZs() ([]ec2.AZ, error)
 }
 
 type serviceResumer interface {
@@ -548,12 +543,13 @@ type serviceDescriber interface {
 	DescribeService(app, env, svc string) (*ecs.ServiceDesc, error)
 }
 
-type serviceUpdater interface {
+type svcForceUpdater interface {
 	ForceUpdateService(app, env, svc string) error
+	LastUpdatedAt(app, env, svc string) (time.Time, error)
 }
 
 type serviceDeployer interface {
-	DeployService(out termprogress.FileWriter, conf cloudformation.StackConfiguration, opts ...awscloudformation.StackOption) error
+	DeployService(out termprogress.FileWriter, conf cloudformation.StackConfiguration, bucketName string, opts ...awscloudformation.StackOption) error
 }
 
 type apprunnerServiceDescriber interface {
