@@ -4,11 +4,14 @@
 package cli
 
 import (
+	"bytes"
 	"errors"
 	"fmt"
 	"os"
+	"path/filepath"
 	"strings"
 
+	"github.com/aws/copilot-cli/internal/pkg/aws/partitions"
 	"github.com/aws/copilot-cli/internal/pkg/docker/dockerengine"
 
 	"github.com/aws/copilot-cli/internal/pkg/deploy"
@@ -19,6 +22,9 @@ import (
 	"github.com/aws/copilot-cli/internal/pkg/repository"
 	"github.com/aws/copilot-cli/internal/pkg/term/log"
 
+	"github.com/spf13/afero"
+	"github.com/spf13/cobra"
+
 	awscloudformation "github.com/aws/copilot-cli/internal/pkg/aws/cloudformation"
 	"github.com/aws/copilot-cli/internal/pkg/aws/ecr"
 	"github.com/aws/copilot-cli/internal/pkg/aws/s3"
@@ -33,7 +39,6 @@ import (
 	"github.com/aws/copilot-cli/internal/pkg/term/prompt"
 	"github.com/aws/copilot-cli/internal/pkg/term/selector"
 	"github.com/aws/copilot-cli/internal/pkg/workspace"
-	"github.com/spf13/cobra"
 )
 
 type deployJobOpts struct {
@@ -41,6 +46,7 @@ type deployJobOpts struct {
 
 	store              store
 	ws                 wsJobDirReader
+	fs                 *afero.Afero
 	unmarshal          func(in []byte) (manifest.WorkloadManifest, error)
 	newInterpolator    func(app, env string) interpolator
 	cmd                runner
@@ -49,7 +55,7 @@ type deployJobOpts struct {
 	jobCFN             cloudformation.CloudFormation
 	imageBuilderPusher imageBuilderPusher
 	sessProvider       sessionProvider
-	s3                 artifactUploader
+	s3                 uploader
 	envUpgradeCmd      actionCommand
 	endpointGetter     endpointGetter
 
@@ -57,9 +63,15 @@ type deployJobOpts struct {
 	sel     wsSelector
 	prompt  prompter
 
+	// cached variables
 	targetApp         *config.Application
 	targetEnvironment *config.Environment
 	targetJob         *config.Workload
+	appEnvResources   *stack.AppRegionalResources
+	appliedManifest   interface{}
+	workspacePath     string
+	addonsURL         string
+	envFileARN        string
 	imageDigest       string
 	buildRequired     bool
 }
@@ -83,6 +95,7 @@ func newJobDeployOpts(vars deployWkldVars) (*deployJobOpts, error) {
 
 		store:           store,
 		ws:              ws,
+		fs:              &afero.Afero{Fs: afero.NewOsFs()},
 		unmarshal:       manifest.UnmarshalWorkload,
 		spinner:         termprogress.NewSpinner(log.DiagnosticWriter),
 		sel:             selector.NewWorkspaceSelect(prompter, store, ws),
@@ -130,63 +143,119 @@ func (o *deployJobOpts) Execute() error {
 		return err
 	}
 	o.targetEnvironment = env
-
 	app, err := o.store.GetApplication(o.appName)
 	if err != nil {
 		return err
 	}
 	o.targetApp = app
-
 	job, err := o.store.GetJob(o.appName, o.name)
 	if err != nil {
 		return fmt.Errorf("get job configuration: %w", err)
 	}
 	o.targetJob = job
-
 	if err := o.configureClients(); err != nil {
 		return err
 	}
-
 	if err := o.envUpgradeCmd.Execute(); err != nil {
 		return fmt.Errorf(`execute "env upgrade --app %s --name %s": %v`, o.appName, o.targetEnvironment.Name, err)
 	}
-
 	if err := o.configureContainerImage(); err != nil {
 		return err
 	}
+	if err := o.pushArtifactsToS3(); err != nil {
+		return err
+	}
+	return o.deployJob()
+}
 
-	addonsURL, err := o.pushAddonsTemplateToS3Bucket()
+func (o *deployJobOpts) pushArtifactsToS3() error {
+	mft, err := o.manifest()
 	if err != nil {
 		return err
 	}
-
-	return o.deployJob(addonsURL)
+	if err := o.pushEnvFilesToS3Bucket(envFile(mft)); err != nil {
+		return err
+	}
+	return o.pushAddonsTemplateToS3Bucket()
 }
 
-// pushAddonsTemplateToS3Bucket generates the addons template for the job and pushes it to S3.
-// If the job doesn't have any addons, it returns the empty string and no errors.
-// If the job has addons, it returns the URL of the S3 object storing the addons template.
-func (o *deployJobOpts) pushAddonsTemplateToS3Bucket() (string, error) {
+func (o *deployJobOpts) pushEnvFilesToS3Bucket(path string) error {
+	if path == "" {
+		return nil
+	}
+	if err := o.retrieveWorkspacePath(); err != nil {
+		return err
+	}
+	content, err := o.fs.ReadFile(filepath.Join(o.workspacePath, path))
+	if err != nil {
+		return fmt.Errorf("read env file %s: %w", path, err)
+	}
+	if err := o.retrieveAppResourcesForEnvRegion(); err != nil {
+		return err
+	}
+	reader := bytes.NewReader(content)
+	url, err := o.s3.Upload(o.appEnvResources.S3Bucket, s3.MkdirSHA256(path, content), reader)
+	if err != nil {
+		return fmt.Errorf("put env file %s artifact to bucket %s: %w", path, o.appEnvResources.S3Bucket, err)
+	}
+	bucket, key, err := s3.ParseURL(url)
+	if err != nil {
+		return fmt.Errorf("parse s3 url: %w", err)
+	}
+	// The app and environment are always within the same partition.
+	region := o.targetEnvironment.Region
+	partition, err := partitions.Region(region).Partition()
+	if err != nil {
+		return err
+	}
+	o.envFileARN = s3.FormatARN(partition.ID(), fmt.Sprintf("%s/%s", bucket, key))
+	return nil
+}
+
+func (o *deployJobOpts) pushAddonsTemplateToS3Bucket() error {
 	template, err := o.addons.Template()
 	if err != nil {
 		var notFoundErr *addon.ErrAddonsNotFound
 		if errors.As(err, &notFoundErr) {
 			// addons doesn't exist for job, the url is empty.
-			return "", nil
+			return nil
 		}
-		return "", fmt.Errorf("retrieve addons template: %w", err)
+		return fmt.Errorf("retrieve addons template: %w", err)
+	}
+	if err := o.retrieveAppResourcesForEnvRegion(); err != nil {
+		return err
+	}
+	reader := strings.NewReader(template)
+	url, err := o.s3.Upload(o.appEnvResources.S3Bucket, fmt.Sprintf(deploy.AddonsCfnTemplateNameFormat, o.name), reader)
+	if err != nil {
+		return fmt.Errorf("put addons artifact to bucket %s: %w", o.appEnvResources.S3Bucket, err)
+	}
+	o.addonsURL = url
+	return nil
+}
+
+func (o *deployJobOpts) retrieveWorkspacePath() error {
+	if o.workspacePath != "" {
+		return nil
+	}
+	workspacePath, err := o.ws.Path()
+	if err != nil {
+		return fmt.Errorf("get workspace path: %w", err)
+	}
+	o.workspacePath = workspacePath
+	return nil
+}
+
+func (o *deployJobOpts) retrieveAppResourcesForEnvRegion() error {
+	if o.appEnvResources != nil {
+		return nil
 	}
 	resources, err := o.appCFN.GetAppResourcesByRegion(o.targetApp, o.targetEnvironment.Region)
 	if err != nil {
-		return "", fmt.Errorf("get app resources: %w", err)
+		return fmt.Errorf("get application %s resources from region %s: %w", o.targetApp.Name, o.targetEnvironment.Region, err)
 	}
-
-	reader := strings.NewReader(template)
-	url, err := o.s3.PutArtifact(resources.S3Bucket, fmt.Sprintf(deploy.AddonsCfnTemplateNameFormat, o.name), reader)
-	if err != nil {
-		return "", fmt.Errorf("put addons artifact to bucket %s: %w", resources.S3Bucket, err)
-	}
-	return url, nil
+	o.appEnvResources = resources
+	return nil
 }
 
 func (o *deployJobOpts) configureClients() error {
@@ -208,7 +277,7 @@ func (o *deployJobOpts) configureClients() error {
 		return fmt.Errorf("initiate image builder pusher: %w", err)
 	}
 
-	o.s3 = s3.New(defaultSessEnvRegion)
+	o.s3 = s3.New(envSession)
 
 	// CF client against env account profile AND target environment region
 	o.jobCFN = cloudformation.New(envSession)
@@ -272,31 +341,33 @@ func (o *deployJobOpts) configureContainerImage() error {
 }
 
 func (o *deployJobOpts) dfBuildArgs(job interface{}) (*dockerengine.BuildArguments, error) {
-	copilotDir, err := o.ws.CopilotDirPath()
-	if err != nil {
-		return nil, fmt.Errorf("get copilot directory: %w", err)
+	if err := o.retrieveWorkspacePath(); err != nil {
+		return nil, err
 	}
-	return buildArgs(o.name, o.imageTag, copilotDir, job)
+	return buildArgs(o.name, o.imageTag, o.workspacePath, job)
 }
 
-func (o *deployJobOpts) deployJob(addonsURL string) error {
-	conf, err := o.stackConfiguration(addonsURL)
+func (o *deployJobOpts) deployJob() error {
+	if err := o.retrieveAppResourcesForEnvRegion(); err != nil {
+		return err
+	}
+	conf, err := o.stackConfiguration()
 	if err != nil {
 		return err
 	}
-	if err := o.jobCFN.DeployService(os.Stderr, conf, awscloudformation.WithRoleARN(o.targetEnvironment.ExecutionRoleARN)); err != nil {
+	if err := o.jobCFN.DeployService(os.Stderr, conf, o.appEnvResources.S3Bucket, awscloudformation.WithRoleARN(o.targetEnvironment.ExecutionRoleARN)); err != nil {
 		return fmt.Errorf("deploy job: %w", err)
 	}
 	log.Successf("Deployed %s.\n", color.HighlightUserInput(o.name))
 	return nil
 }
 
-func (o *deployJobOpts) stackConfiguration(addonsURL string) (cloudformation.StackConfiguration, error) {
+func (o *deployJobOpts) stackConfiguration() (cloudformation.StackConfiguration, error) {
 	mft, err := o.manifest()
 	if err != nil {
 		return nil, err
 	}
-	rc, err := o.runtimeConfig(addonsURL)
+	rc, err := o.runtimeConfig()
 	if err != nil {
 		return nil, err
 	}
@@ -313,25 +384,24 @@ func (o *deployJobOpts) stackConfiguration(addonsURL string) (cloudformation.Sta
 	return conf, nil
 }
 
-func (o *deployJobOpts) runtimeConfig(addonsURL string) (*stack.RuntimeConfig, error) {
+func (o *deployJobOpts) runtimeConfig() (*stack.RuntimeConfig, error) {
 	endpoint, err := o.endpointGetter.ServiceDiscoveryEndpoint()
 	if err != nil {
 		return nil, err
 	}
 	if !o.buildRequired {
 		return &stack.RuntimeConfig{
-			AddonsTemplateURL:        addonsURL,
+			AddonsTemplateURL:        o.addonsURL,
 			AdditionalTags:           tags.Merge(o.targetApp.Tags, o.resourceTags),
 			ServiceDiscoveryEndpoint: endpoint,
 			AccountID:                o.targetEnvironment.AccountID,
 			Region:                   o.targetEnvironment.Region,
 		}, nil
 	}
-	resources, err := o.appCFN.GetAppResourcesByRegion(o.targetApp, o.targetEnvironment.Region)
-	if err != nil {
-		return nil, fmt.Errorf("get application %s resources from region %s: %w", o.targetApp.Name, o.targetEnvironment.Region, err)
+	if err := o.retrieveAppResourcesForEnvRegion(); err != nil {
+		return nil, err
 	}
-	repoURL, ok := resources.RepositoryURLs[o.name]
+	repoURL, ok := o.appEnvResources.RepositoryURLs[o.name]
 	if !ok {
 		return nil, &errRepoNotFound{
 			wlName:       o.name,
@@ -345,7 +415,7 @@ func (o *deployJobOpts) runtimeConfig(addonsURL string) (*stack.RuntimeConfig, e
 			ImageTag: o.imageTag,
 			Digest:   o.imageDigest,
 		},
-		AddonsTemplateURL:        addonsURL,
+		AddonsTemplateURL:        o.addonsURL,
 		AdditionalTags:           tags.Merge(o.targetApp.Tags, o.resourceTags),
 		ServiceDiscoveryEndpoint: endpoint,
 		AccountID:                o.targetEnvironment.AccountID,
@@ -354,6 +424,9 @@ func (o *deployJobOpts) runtimeConfig(addonsURL string) (*stack.RuntimeConfig, e
 }
 
 func (o *deployJobOpts) manifest() (interface{}, error) {
+	if o.appliedManifest != nil {
+		return o.appliedManifest, nil
+	}
 	raw, err := o.ws.ReadWorkloadManifest(o.name)
 	if err != nil {
 		return nil, fmt.Errorf("read job %s manifest: %w", o.name, err)
@@ -373,6 +446,7 @@ func (o *deployJobOpts) manifest() (interface{}, error) {
 	if err := envMft.Validate(); err != nil {
 		return nil, fmt.Errorf("validate manifest against environment %s: %s", o.envName, err)
 	}
+	o.appliedManifest = envMft // cache the results.
 	return envMft, nil
 }
 
