@@ -4,16 +4,18 @@
 package cli
 
 import (
+	"bytes"
 	"errors"
 	"fmt"
 	"os"
 	"path/filepath"
 	"regexp"
 	"strings"
-
-	"github.com/aws/copilot-cli/internal/pkg/aws/ec2"
+	"time"
 
 	"github.com/aws/aws-sdk-go/aws/session"
+	"github.com/aws/copilot-cli/internal/pkg/aws/partitions"
+
 	"github.com/aws/copilot-cli/internal/pkg/apprunner"
 	"github.com/aws/copilot-cli/internal/pkg/docker/dockerengine"
 	"github.com/aws/copilot-cli/internal/pkg/ecs"
@@ -24,6 +26,9 @@ import (
 	"github.com/aws/aws-sdk-go/aws"
 	"golang.org/x/mod/semver"
 
+	"github.com/spf13/afero"
+	"github.com/spf13/cobra"
+
 	"github.com/aws/copilot-cli/internal/pkg/addon"
 	awscloudformation "github.com/aws/copilot-cli/internal/pkg/aws/cloudformation"
 	"github.com/aws/copilot-cli/internal/pkg/aws/ecr"
@@ -44,7 +49,6 @@ import (
 	"github.com/aws/copilot-cli/internal/pkg/term/prompt"
 	"github.com/aws/copilot-cli/internal/pkg/term/selector"
 	"github.com/aws/copilot-cli/internal/pkg/workspace"
-	"github.com/spf13/cobra"
 )
 
 const (
@@ -68,7 +72,7 @@ type deployWkldVars struct {
 
 type uploadCustomResourcesOpts struct {
 	uploader      customResourcesUploader
-	newS3Uploader func() (Uploader, error)
+	newS3Uploader func() (uploader, error)
 }
 
 type deploySvcOpts struct {
@@ -77,22 +81,22 @@ type deploySvcOpts struct {
 	store               store
 	deployStore         *deploy.Store
 	ws                  wsSvcDirReader
+	fs                  *afero.Afero
 	imageBuilderPusher  imageBuilderPusher
 	unmarshal           func([]byte) (manifest.WorkloadManifest, error)
 	newInterpolator     func(app, env string) interpolator
-	s3                  artifactUploader
+	s3                  uploader
 	cmd                 runner
 	addons              templater
 	appCFN              appResourcesGetter
 	svcCFN              serviceDeployer
-	newSvcUpdater       func(func(*session.Session) serviceUpdater)
+	newSvcUpdater       func(func(*session.Session) svcForceUpdater)
 	sessProvider        sessionProvider
 	envUpgradeCmd       actionCommand
 	newAppVersionGetter func(string) (versionGetter, error)
 	endpointGetter      endpointGetter
 	snsTopicGetter      deployedEnvironmentLister
 	identity            identityService
-	subnetLister        vpcSubnetLister
 	envDescriber        envDescriber
 
 	spinner progress
@@ -106,9 +110,13 @@ type deploySvcOpts struct {
 	appliedManifest   interface{}
 	imageDigest       string
 	buildRequired     bool
+	addonsURL         string
+	envFileARN        string
 	appEnvResources   *stack.AppRegionalResources
+	workspacePath     string
 	rdSvcAlias        string
-	svcUpdater        serviceUpdater
+	svcUpdater        svcForceUpdater
+	now               func() time.Time
 
 	subscriptions []manifest.TopicSubscription
 
@@ -132,13 +140,14 @@ func newSvcDeployOpts(vars deployWkldVars) (*deploySvcOpts, error) {
 	opts := &deploySvcOpts{
 		deployWkldVars: vars,
 
-		store:     store,
+		store:       store,
 		deployStore: deployStore,
-		ws:        ws,
-		unmarshal: manifest.UnmarshalWorkload,
-		spinner:   termprogress.NewSpinner(log.DiagnosticWriter),
-		sel:       selector.NewWorkspaceSelect(prompter, store, ws),
-		prompt:    prompter,
+		ws:          ws,
+		fs:          &afero.Afero{Fs: afero.NewOsFs()},
+		unmarshal:   manifest.UnmarshalWorkload,
+		spinner:     termprogress.NewSpinner(log.DiagnosticWriter),
+		sel:         selector.NewWorkspaceSelect(prompter, store, ws),
+		prompt:      prompter,
 		newAppVersionGetter: func(appName string) (versionGetter, error) {
 			d, err := describe.NewAppDescriber(appName)
 			if err != nil {
@@ -148,6 +157,7 @@ func newSvcDeployOpts(vars deployWkldVars) (*deploySvcOpts, error) {
 		},
 		newInterpolator: newManifestInterpolator,
 		cmd:             exec.NewCmd(),
+		now:             time.Now,
 		sessProvider:    sessions.NewProvider(),
 		snsTopicGetter:  deployStore,
 	}
@@ -220,12 +230,11 @@ func (o *deploySvcOpts) Execute() error {
 		return err
 	}
 
-	addonsURL, err := o.pushAddonsTemplateToS3Bucket()
-	if err != nil {
+	if err := o.pushArtifactsToS3(); err != nil {
 		return err
 	}
 
-	if err := o.deploySvc(addonsURL); err != nil {
+	if err := o.deploySvc(); err != nil {
 		return err
 	}
 	log.Successf("Deployed service %s.\n", color.HighlightUserInput(o.name))
@@ -321,7 +330,6 @@ func (o *deploySvcOpts) configureClients() error {
 		return fmt.Errorf("create describer for environment %s in application %s: %w", o.envName, o.appName, err)
 	}
 	o.envDescriber = d
-	o.subnetLister = ec2.New(envSession)
 
 	// ECR client against tools account profile AND target environment region.
 	repoName := fmt.Sprintf("%s/%s", o.appName, o.name)
@@ -331,9 +339,9 @@ func (o *deploySvcOpts) configureClients() error {
 		return fmt.Errorf("initiate image builder pusher: %w", err)
 	}
 
-	o.s3 = s3.New(defaultSessEnvRegion)
+	o.s3 = s3.New(envSession)
 
-	o.newSvcUpdater = func(f func(*session.Session) serviceUpdater) {
+	o.newSvcUpdater = func(f func(*session.Session) svcForceUpdater) {
 		o.svcUpdater = f(envSession)
 	}
 
@@ -376,23 +384,6 @@ func (o *deploySvcOpts) configureClients() error {
 	return nil
 }
 
-func (o *deploySvcOpts) publicCIDRBlocks() ([]string, error) {
-	envDescription, err := o.envDescriber.Describe()
-	if err != nil {
-		return nil, fmt.Errorf("describe environment %s: %w", o.envName, err)
-	}
-	vpcID := envDescription.EnvironmentVPC.ID
-	subnets, err := o.subnetLister.ListVPCSubnets(vpcID)
-	if err != nil {
-		return nil, fmt.Errorf("list subnets of vpc %s in environment %s: %w", vpcID, o.envName, err)
-	}
-	var cidrBlocks []string
-	for _, subnet := range subnets.Public {
-		cidrBlocks = append(cidrBlocks, subnet.CIDRBlock)
-	}
-	return cidrBlocks, nil
-}
-
 func (o *deploySvcOpts) configureContainerImage() error {
 	svc, err := o.manifest()
 	if err != nil {
@@ -421,62 +412,76 @@ func (o *deploySvcOpts) configureContainerImage() error {
 }
 
 func (o *deploySvcOpts) dfBuildArgs(svc interface{}) (*dockerengine.BuildArguments, error) {
-	copilotDir, err := o.ws.CopilotDirPath()
+	if err := o.retrieveWorkspacePath(); err != nil {
+		return nil, err
+	}
+	return buildArgs(o.name, o.imageTag, o.workspacePath, svc)
+}
+
+func (o *deploySvcOpts) pushArtifactsToS3() error {
+	mft, err := o.manifest()
 	if err != nil {
-		return nil, fmt.Errorf("get copilot directory: %w", err)
+		return err
 	}
-	return buildArgs(o.name, o.imageTag, copilotDir, svc)
+	if err := o.pushEnvFilesToS3Bucket(envFile(mft)); err != nil {
+		return err
+	}
+	return o.pushAddonsTemplateToS3Bucket()
 }
 
-func buildArgs(name, imageTag, copilotDir string, unmarshaledManifest interface{}) (*dockerengine.BuildArguments, error) {
-	type dfArgs interface {
-		BuildArgs(rootDirectory string) *manifest.DockerBuildArgs
-		ContainerPlatform() string
+func (o *deploySvcOpts) pushEnvFilesToS3Bucket(path string) error {
+	if path == "" {
+		return nil
 	}
-	mf, ok := unmarshaledManifest.(dfArgs)
-	if !ok {
-		return nil, fmt.Errorf("%s does not have required methods BuildArgs() and ContainerPlatform()", name)
+	if err := o.retrieveWorkspacePath(); err != nil {
+		return err
 	}
-	var tags []string
-	if imageTag != "" {
-		tags = append(tags, imageTag)
+	content, err := o.fs.ReadFile(filepath.Join(o.workspacePath, path))
+	if err != nil {
+		return fmt.Errorf("read env file %s: %w", path, err)
 	}
-	args := mf.BuildArgs(filepath.Dir(copilotDir))
-	return &dockerengine.BuildArguments{
-		Dockerfile: *args.Dockerfile,
-		Context:    *args.Context,
-		Args:       args.Args,
-		CacheFrom:  args.CacheFrom,
-		Target:     aws.StringValue(args.Target),
-		Platform:   mf.ContainerPlatform(),
-		Tags:       tags,
-	}, nil
+	if err := o.retrieveAppResourcesForEnvRegion(); err != nil {
+		return err
+	}
+	reader := bytes.NewReader(content)
+	url, err := o.s3.Upload(o.appEnvResources.S3Bucket, s3.MkdirSHA256(path, content), reader)
+	if err != nil {
+		return fmt.Errorf("put env file %s artifact to bucket %s: %w", path, o.appEnvResources.S3Bucket, err)
+	}
+	bucket, key, err := s3.ParseURL(url)
+	if err != nil {
+		return fmt.Errorf("parse s3 url: %w", err)
+	}
+	// The app and environment are always within the same partition.
+	region := o.targetEnvironment.Region
+	partition, err := partitions.Region(region).Partition()
+	if err != nil {
+		return err
+	}
+	o.envFileARN = s3.FormatARN(partition.ID(), fmt.Sprintf("%s/%s", bucket, key))
+	return nil
 }
 
-// pushAddonsTemplateToS3Bucket generates the addons template for the service and pushes it to S3.
-// If the service doesn't have any addons, it returns the empty string and no errors.
-// If the service has addons, it returns the URL of the S3 object storing the addons template.
-func (o *deploySvcOpts) pushAddonsTemplateToS3Bucket() (string, error) {
+func (o *deploySvcOpts) pushAddonsTemplateToS3Bucket() error {
 	template, err := o.addons.Template()
 	if err != nil {
 		var notFoundErr *addon.ErrAddonsNotFound
 		if errors.As(err, &notFoundErr) {
 			// addons doesn't exist for service, the url is empty.
-			return "", nil
+			return nil
 		}
-		return "", fmt.Errorf("retrieve addons template: %w", err)
+		return fmt.Errorf("retrieve addons template: %w", err)
 	}
-
 	if err := o.retrieveAppResourcesForEnvRegion(); err != nil {
-		return "", err
+		return err
 	}
-
 	reader := strings.NewReader(template)
-	url, err := o.s3.PutArtifact(o.appEnvResources.S3Bucket, fmt.Sprintf(deploy.AddonsCfnTemplateNameFormat, o.name), reader)
+	url, err := o.s3.Upload(o.appEnvResources.S3Bucket, fmt.Sprintf(deploy.AddonsCfnTemplateNameFormat, o.name), reader)
 	if err != nil {
-		return "", fmt.Errorf("put addons artifact to bucket %s: %w", o.appEnvResources.S3Bucket, err)
+		return fmt.Errorf("put addons artifact to bucket %s: %w", o.appEnvResources.S3Bucket, err)
 	}
-	return url, nil
+	o.addonsURL = url
+	return nil
 }
 
 func (o *deploySvcOpts) manifest() (interface{}, error) {
@@ -507,7 +512,7 @@ func (o *deploySvcOpts) manifest() (interface{}, error) {
 	return envMft, nil
 }
 
-func (o *deploySvcOpts) runtimeConfig(addonsURL string) (*stack.RuntimeConfig, error) {
+func (o *deploySvcOpts) runtimeConfig() (*stack.RuntimeConfig, error) {
 	endpoint, err := o.endpointGetter.ServiceDiscoveryEndpoint()
 	if err != nil {
 		return nil, err
@@ -515,7 +520,8 @@ func (o *deploySvcOpts) runtimeConfig(addonsURL string) (*stack.RuntimeConfig, e
 
 	if !o.buildRequired {
 		return &stack.RuntimeConfig{
-			AddonsTemplateURL:        addonsURL,
+			AddonsTemplateURL:        o.addonsURL,
+			EnvFileARN:               o.envFileARN,
 			AdditionalTags:           tags.Merge(o.targetApp.Tags, o.resourceTags),
 			ServiceDiscoveryEndpoint: endpoint,
 			AccountID:                o.targetEnvironment.AccountID,
@@ -536,7 +542,8 @@ func (o *deploySvcOpts) runtimeConfig(addonsURL string) (*stack.RuntimeConfig, e
 		}
 	}
 	return &stack.RuntimeConfig{
-		AddonsTemplateURL: addonsURL,
+		AddonsTemplateURL: o.addonsURL,
+		EnvFileARN:        o.envFileARN,
 		AdditionalTags:    tags.Merge(o.targetApp.Tags, o.resourceTags),
 		Image: &stack.ECRImage{
 			RepoURL:  repoURL,
@@ -549,7 +556,7 @@ func (o *deploySvcOpts) runtimeConfig(addonsURL string) (*stack.RuntimeConfig, e
 	}, nil
 }
 
-func uploadCustomResources(o *uploadCustomResourcesOpts, appEnvResources *stack.AppRegionalResources) (map[string]string, error) {
+func uploadRDWSCustomResources(o *uploadCustomResourcesOpts, appEnvResources *stack.AppRegionalResources) (map[string]string, error) {
 	s3Client, err := o.newS3Uploader()
 	if err != nil {
 		return nil, err
@@ -565,57 +572,61 @@ func uploadCustomResources(o *uploadCustomResourcesOpts, appEnvResources *stack.
 	return urls, nil
 }
 
-func (o *deploySvcOpts) stackConfiguration(addonsURL string) (cloudformation.StackConfiguration, error) {
+func (o *deploySvcOpts) stackConfiguration() (cloudformation.StackConfiguration, error) {
 	mft, err := o.manifest()
 	if err != nil {
 		return nil, err
 	}
-	rc, err := o.runtimeConfig(addonsURL)
+	rc, err := o.runtimeConfig()
 	if err != nil {
 		return nil, err
 	}
-	o.newSvcUpdater(func(s *session.Session) serviceUpdater {
+	o.newSvcUpdater(func(s *session.Session) svcForceUpdater {
 		return ecs.New(s)
 	})
 	var conf cloudformation.StackConfiguration
 	switch t := mft.(type) {
 	case *manifest.LoadBalancedWebService:
-		if o.targetApp.Domain == "" && !t.Alias.IsEmpty() {
-			log.Errorf(aliasUsedWithoutDomainFriendlyText)
-			return nil, errors.New("alias specified when application is not associated with a domain")
+		var appVersionGetter versionGetter
+		appVersionGetter, err = o.newAppVersionGetter(o.appName)
+		if err != nil {
+			return nil, fmt.Errorf("new app describer for application %s: %w", o.appName, err)
+		}
+		if err := validateLBWSRuntime(o.targetApp, o.envName, t, appVersionGetter); err != nil {
+			return nil, err
 		}
 
 		var opts []stack.LoadBalancedWebServiceOption
-
-		// TODO: https://github.com/aws/copilot-cli/issues/2918
-		// 1. Should error out if `nlb.alias` is specified with targetApp.Domain == ""
-		// 2. Should validate `nlb.alias` is specified
-		// 3. ALB block should not be executed if http is disabled
-		if o.targetApp.RequiresDNSDelegation() {
-			var appVersionGetter versionGetter
-			if appVersionGetter, err = o.newAppVersionGetter(o.appName); err != nil {
-				return nil, err
-			}
-			if err = validateLBSvcAliasAndAppVersion(aws.StringValue(t.Name), t.Alias, o.targetApp, o.envName, appVersionGetter); err != nil {
-				return nil, err
-			}
-			opts = append(opts, stack.WithHTTPS())
-			opts = append(opts, stack.WithDNSDelegation())
-		}
 		if !t.NLBConfig.IsEmpty() {
-			cidrBlocks, err := o.publicCIDRBlocks()
+			cidrBlocks, err := o.envDescriber.PublicCIDRBlocks()
 			if err != nil {
-				return nil, err
+				return nil, fmt.Errorf("get public CIDR blocks information from the VPC of environment %s: %w", o.envName, err)
 			}
 			opts = append(opts, stack.WithNLB(cidrBlocks))
 		}
+		if o.targetApp.RequiresDNSDelegation() {
+			var caller identity.Caller
+			caller, err = o.identity.Get()
+			if err != nil {
+				return nil, fmt.Errorf("get identity: %w", err)
+			}
+			opts = append(opts, stack.WithDNSDelegation(deploy.AppInformation{
+				Name:                o.targetEnvironment.App,
+				DNSName:             o.targetApp.Domain,
+				AccountPrincipalARN: caller.RootUserARN,
+			}))
+
+			if !t.RoutingRule.Disabled() {
+				opts = append(opts, stack.WithHTTPS())
+			}
+		}
 		conf, err = stack.NewLoadBalancedWebService(t, o.targetEnvironment.Name, o.targetEnvironment.App, *rc, opts...)
 	case *manifest.RequestDrivenWebService:
 		if o.targetApp.Domain == "" && t.Alias != nil {
 			log.Errorf(aliasUsedWithoutDomainFriendlyText)
 			return nil, errors.New("alias specified when application is not associated with a domain")
 		}
-		o.newSvcUpdater(func(s *session.Session) serviceUpdater {
+		o.newSvcUpdater(func(s *session.Session) svcForceUpdater {
 			return apprunner.New(s)
 		})
 		var caller identity.Caller
@@ -649,7 +660,7 @@ func (o *deploySvcOpts) stackConfiguration(addonsURL string) (cloudformation.Sta
 		if err = o.retrieveAppResourcesForEnvRegion(); err != nil {
 			return nil, err
 		}
-		if urls, err = uploadCustomResources(o.uploadOpts, o.appEnvResources); err != nil {
+		if urls, err = uploadRDWSCustomResources(o.uploadOpts, o.appEnvResources); err != nil {
 			return nil, err
 		}
 		conf, err = stack.NewRequestDrivenWebServiceWithAlias(t, o.targetEnvironment.Name, appInfo, *rc, urls)
@@ -690,27 +701,39 @@ func (o *deploySvcOpts) stackConfiguration(addonsURL string) (cloudformation.Sta
 	return conf, nil
 }
 
-func (o *deploySvcOpts) deploySvc(addonsURL string) error {
-	conf, err := o.stackConfiguration(addonsURL)
+func (o *deploySvcOpts) deploySvc() error {
+	conf, err := o.stackConfiguration()
 	if err != nil {
 		return err
 	}
-
-	if err := o.svcCFN.DeployService(os.Stderr, conf, awscloudformation.WithRoleARN(o.targetEnvironment.ExecutionRoleARN)); err != nil {
+	if err := o.retrieveAppResourcesForEnvRegion(); err != nil {
+		return err
+	}
+	cmdRunAt := o.now()
+	if err := o.svcCFN.DeployService(os.Stderr, conf, o.appEnvResources.S3Bucket, awscloudformation.WithRoleARN(o.targetEnvironment.ExecutionRoleARN)); err != nil {
 		var errEmptyCS *awscloudformation.ErrChangeSetEmpty
-		if errors.As(err, &errEmptyCS) {
-			if o.forceNewUpdate {
-				return o.forceDeploy()
-			}
+		if !errors.As(err, &errEmptyCS) {
+			return fmt.Errorf("deploy service: %w", err)
+		}
+		if !o.forceNewUpdate {
 			log.Warningf("Set --%s to force an update for the service.\n", forceFlag)
+			return fmt.Errorf("deploy service: %w", err)
+		}
+	}
+	// Force update the service if --force is set and the service is not updated by the CFN.
+	if o.forceNewUpdate {
+		lastUpdatedAt, err := o.svcUpdater.LastUpdatedAt(o.appName, o.envName, o.name)
+		if err != nil {
+			return fmt.Errorf("get the last updated deployment time for %s: %w", o.name, err)
+		}
+		if cmdRunAt.After(lastUpdatedAt) {
+			return o.forceDeploy()
 		}
-		return fmt.Errorf("deploy service: %w", err)
 	}
 	return nil
 }
 
 func (o *deploySvcOpts) forceDeploy() error {
-	// Force update the service if --force is set and change set is empty.
 	o.spinner.Start(fmt.Sprintf(fmtForceUpdateSvcStart, color.HighlightUserInput(o.name), color.HighlightUserInput(o.envName)))
 	if err := o.svcUpdater.ForceUpdateService(o.appName, o.envName, o.name); err != nil {
 		errLog := fmt.Sprintf(fmtForceUpdateSvcFailed, color.HighlightUserInput(o.name),
@@ -727,7 +750,44 @@ func (o *deploySvcOpts) forceDeploy() error {
 	return nil
 }
 
-func validateLBSvcAliasAndAppVersion(svcName string, aliases manifest.Alias, app *config.Application, envName string, appVersionGetter versionGetter) error {
+func buildArgs(name, imageTag, workspacePath string, unmarshaledManifest interface{}) (*dockerengine.BuildArguments, error) {
+	type dfArgs interface {
+		BuildArgs(rootDirectory string) *manifest.DockerBuildArgs
+		ContainerPlatform() string
+	}
+	mf, ok := unmarshaledManifest.(dfArgs)
+	if !ok {
+		return nil, fmt.Errorf("%s does not have required methods BuildArgs() and ContainerPlatform()", name)
+	}
+	var tags []string
+	if imageTag != "" {
+		tags = append(tags, imageTag)
+	}
+	args := mf.BuildArgs(workspacePath)
+	return &dockerengine.BuildArguments{
+		Dockerfile: *args.Dockerfile,
+		Context:    *args.Context,
+		Args:       args.Args,
+		CacheFrom:  args.CacheFrom,
+		Target:     aws.StringValue(args.Target),
+		Platform:   mf.ContainerPlatform(),
+		Tags:       tags,
+	}, nil
+}
+
+func envFile(unmarshaledManifest interface{}) string {
+	type envFile interface {
+		EnvFile() string
+	}
+	mf, ok := unmarshaledManifest.(envFile)
+	if ok {
+		return mf.EnvFile()
+	}
+	// If the manifest type doesn't support envFiles, ignore and move forward.
+	return ""
+}
+
+func validateLBSvcAlias(aliases manifest.Alias, app *config.Application, envName string) error {
 	if aliases.IsEmpty() {
 		return nil
 	}
@@ -735,10 +795,6 @@ func validateLBSvcAliasAndAppVersion(svcName string, aliases manifest.Alias, app
 	if err != nil {
 		return fmt.Errorf(`convert 'http.alias' to string slice: %w`, err)
 	}
-	if err := validateAppVersion(app.Name, appVersionGetter); err != nil {
-		logAppVersionOutdatedError(svcName)
-		return err
-	}
 	for _, alias := range aliasList {
 		// Alias should be within either env, app, or root hosted zone.
 		var regEnvHostedZone, regAppHostedZone, regRootHostedZone *regexp.Regexp
@@ -848,6 +904,25 @@ func validateAppVersion(appName string, appVersionGetter versionGetter) error {
 	return nil
 }
 
+func validateLBWSRuntime(app *config.Application, envName string, mft *manifest.LoadBalancedWebService, appVersionGetter versionGetter) error {
+	if app.Domain == "" && mft.HasAliases() {
+		log.Errorf(aliasUsedWithoutDomainFriendlyText)
+		return errors.New("alias specified when application is not associated with a domain")
+	}
+
+	if app.RequiresDNSDelegation() {
+		if err := validateAppVersion(app.Name, appVersionGetter); err != nil {
+			logAppVersionOutdatedError(aws.StringValue(mft.Name))
+			return err
+		}
+	}
+
+	if err := validateLBSvcAlias(mft.RoutingRule.Alias, app, envName); err != nil {
+		return err
+	}
+	return validateLBSvcAlias(mft.NLBConfig.Aliases, app, envName)
+}
+
 func logAppVersionOutdatedError(name string) {
 	log.Errorf(`Cannot deploy service %s because the application version is incompatible.
 To upgrade the application, please run %s first (see https://aws.github.io/copilot-cli/docs/credentials/#application-credentials).
@@ -857,7 +932,7 @@ To upgrade the application, please run %s first (see https://aws.github.io/copil
 func newUploadCustomResourcesOpts(opts *deploySvcOpts) *uploadCustomResourcesOpts {
 	return &uploadCustomResourcesOpts{
 		uploader: template.New(),
-		newS3Uploader: func() (Uploader, error) {
+		newS3Uploader: func() (uploader, error) {
 			envRegion := opts.targetEnvironment.Region
 			sess, err := opts.sessProvider.DefaultWithRegion(opts.targetEnvironment.Region)
 			if err != nil {
@@ -869,6 +944,18 @@ func newUploadCustomResourcesOpts(opts *deploySvcOpts) *uploadCustomResourcesOpt
 	}
 }
 
+func (o *deploySvcOpts) retrieveWorkspacePath() error {
+	if o.workspacePath != "" {
+		return nil
+	}
+	workspacePath, err := o.ws.Path()
+	if err != nil {
+		return fmt.Errorf("get workspace path: %w", err)
+	}
+	o.workspacePath = workspacePath
+	return nil
+}
+
 func (o *deploySvcOpts) retrieveAppResourcesForEnvRegion() error {
 	if o.appEnvResources != nil {
 		return nil
