@@ -8,27 +8,28 @@ import (
 	"fmt"
 	"path/filepath"
 	"testing"
+	"time"
 
-	"github.com/aws/copilot-cli/internal/pkg/describe"
-
+	"github.com/aws/aws-sdk-go/aws"
 	"github.com/aws/aws-sdk-go/aws/session"
+	"github.com/spf13/afero"
+
+	"github.com/aws/copilot-cli/internal/pkg/addon"
+	"github.com/aws/copilot-cli/internal/pkg/aws/cloudformation"
+	"github.com/aws/copilot-cli/internal/pkg/aws/ecs"
+	"github.com/aws/copilot-cli/internal/pkg/aws/identity"
+	"github.com/aws/copilot-cli/internal/pkg/deploy"
+	"github.com/aws/copilot-cli/internal/pkg/deploy/cloudformation/stack"
 	"github.com/aws/copilot-cli/internal/pkg/docker/dockerengine"
 	"github.com/aws/copilot-cli/internal/pkg/term/color"
 	"github.com/aws/copilot-cli/internal/pkg/term/log"
 
-	"github.com/aws/copilot-cli/internal/pkg/aws/ecs"
-	"github.com/aws/copilot-cli/internal/pkg/aws/identity"
-
-	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/copilot-cli/internal/pkg/addon"
-	"github.com/aws/copilot-cli/internal/pkg/aws/cloudformation"
-	"github.com/aws/copilot-cli/internal/pkg/config"
-	"github.com/aws/copilot-cli/internal/pkg/deploy"
-	"github.com/aws/copilot-cli/internal/pkg/deploy/cloudformation/stack"
-	"github.com/aws/copilot-cli/internal/pkg/manifest"
 	"github.com/golang/mock/gomock"
 	"github.com/stretchr/testify/require"
 
+	"github.com/aws/copilot-cli/internal/pkg/config"
+	"github.com/aws/copilot-cli/internal/pkg/manifest"
+
 	"github.com/aws/copilot-cli/internal/pkg/cli/mocks"
 )
 
@@ -40,11 +41,22 @@ type deploySvcMocks struct {
 	mockEndpointGetter     *mocks.MockendpointGetter
 	mockServiceDeployer    *mocks.MockserviceDeployer
 	mockSpinner            *mocks.Mockprogress
-	mockServiceUpdater     *mocks.MockserviceUpdater
+	mockServiceUpdater     *mocks.MocksvcForceUpdater
 	mockInterpolator       *mocks.Mockinterpolator
 	mockDeployStore        *mocks.MockdeployedEnvironmentLister
 	mockEnvDescriber       *mocks.MockenvDescriber
-	mockSubnetLister       *mocks.MockvpcSubnetLister
+	mockS3Svc              *mocks.Mockuploader
+	mockAddons             *mocks.Mocktemplater
+	mockIdentity           *mocks.MockidentityService
+	mockUploader           *mocks.MockcustomResourcesUploader
+}
+
+type mockWorkloadMft struct {
+	fileName string
+}
+
+func (m *mockWorkloadMft) EnvFile() string {
+	return m.fileName
 }
 
 func TestSvcDeployOpts_Validate(t *testing.T) {
@@ -222,6 +234,8 @@ func TestSvcDeployOpts_configureContainerImage(t *testing.T) {
 	mockError := errors.New("mockError")
 	mockManifest := []byte(`name: serviceA
 type: 'Load Balanced Web Service'
+http:
+  path: "/"
 image:
   build:
     dockerfile: path/to/Dockerfile
@@ -230,15 +244,20 @@ image:
 `)
 	mockManifestWithBadPlatform := []byte(`name: serviceA
 type: 'Load Balanced Web Service'
+http:
+  path: "/"
 platform: linus/abc123
 image:
   build:
     dockerfile: path/to/Dockerfile
     context: path
   port: 80
+
 `)
 	mockManifestWithGoodPlatform := []byte(`name: serviceA
 type: 'Load Balanced Web Service'
+http:
+  path: "/"
 platform: linux/amd64
 image:
   build:
@@ -248,18 +267,24 @@ image:
 `)
 	mockMftNoBuild := []byte(`name: serviceA
 type: 'Load Balanced Web Service'
+http:
+  path: "/"
 image:
   location: foo/bar
   port: 80
 `)
 	mockMftBuildString := []byte(`name: serviceA
 type: 'Load Balanced Web Service'
+http:
+  path: "/"
 image:
   build: path/to/Dockerfile
   port: 80
 `)
 	mockMftNoContext := []byte(`name: serviceA
 type: 'Load Balanced Web Service'
+http:
+  path: "/"
 image:
   build:
     dockerfile: path/to/Dockerfile
@@ -297,10 +322,10 @@ image:
 				gomock.InOrder(
 					m.mockWs.EXPECT().ReadWorkloadManifest(gomock.Any()).Return(mockManifest, nil),
 					m.mockInterpolator.EXPECT().Interpolate(string(mockManifest)).Return(string(mockManifest), nil),
-					m.mockWs.EXPECT().CopilotDirPath().Return("", mockError),
+					m.mockWs.EXPECT().Path().Return("", mockError),
 				)
 			},
-			wantErr: fmt.Errorf("get copilot directory: %w", mockError),
+			wantErr: fmt.Errorf("get workspace path: %w", mockError),
 		},
 		"should return error if platform is invalid": {
 			inputSvc: "serviceA",
@@ -318,7 +343,7 @@ image:
 				gomock.InOrder(
 					m.mockWs.EXPECT().ReadWorkloadManifest("serviceA").Return(mockManifestWithGoodPlatform, nil),
 					m.mockInterpolator.EXPECT().Interpolate(string(mockManifestWithGoodPlatform)).Return(string(mockManifestWithGoodPlatform), nil),
-					m.mockWs.EXPECT().CopilotDirPath().Return("/ws/root/copilot", nil),
+					m.mockWs.EXPECT().Path().Return("/ws/root", nil),
 					m.mockimageBuilderPusher.EXPECT().BuildAndPush(gomock.Any(), &dockerengine.BuildArguments{
 						Dockerfile: filepath.Join("/ws", "root", "path", "to", "Dockerfile"),
 						Context:    filepath.Join("/ws", "root", "path"),
@@ -334,7 +359,7 @@ image:
 				gomock.InOrder(
 					m.mockWs.EXPECT().ReadWorkloadManifest("serviceA").Return(mockMftNoBuild, nil),
 					m.mockInterpolator.EXPECT().Interpolate(string(mockMftNoBuild)).Return(string(mockMftNoBuild), nil),
-					m.mockWs.EXPECT().CopilotDirPath().Times(0),
+					m.mockWs.EXPECT().Path().Times(0),
 					m.mockimageBuilderPusher.EXPECT().BuildAndPush(gomock.Any(), gomock.Any()).Times(0),
 				)
 			},
@@ -345,7 +370,7 @@ image:
 				gomock.InOrder(
 					m.mockWs.EXPECT().ReadWorkloadManifest("serviceA").Return(mockManifest, nil),
 					m.mockInterpolator.EXPECT().Interpolate(string(mockManifest)).Return(string(mockManifest), nil),
-					m.mockWs.EXPECT().CopilotDirPath().Return("/ws/root/copilot", nil),
+					m.mockWs.EXPECT().Path().Return("/ws/root", nil),
 					m.mockimageBuilderPusher.EXPECT().BuildAndPush(gomock.Any(), gomock.Any()).Return("", mockError),
 				)
 			},
@@ -357,7 +382,7 @@ image:
 				gomock.InOrder(
 					m.mockWs.EXPECT().ReadWorkloadManifest("serviceA").Return(mockManifest, nil),
 					m.mockInterpolator.EXPECT().Interpolate(string(mockManifest)).Return(string(mockManifest), nil),
-					m.mockWs.EXPECT().CopilotDirPath().Return("/ws/root/copilot", nil),
+					m.mockWs.EXPECT().Path().Return("/ws/root", nil),
 					m.mockimageBuilderPusher.EXPECT().BuildAndPush(gomock.Any(), &dockerengine.BuildArguments{
 						Dockerfile: filepath.Join("/ws", "root", "path", "to", "Dockerfile"),
 						Context:    filepath.Join("/ws", "root", "path"),
@@ -372,7 +397,7 @@ image:
 				gomock.InOrder(
 					m.mockWs.EXPECT().ReadWorkloadManifest("serviceA").Return(mockMftBuildString, nil),
 					m.mockInterpolator.EXPECT().Interpolate(string(mockMftBuildString)).Return(string(mockMftBuildString), nil),
-					m.mockWs.EXPECT().CopilotDirPath().Return("/ws/root/copilot", nil),
+					m.mockWs.EXPECT().Path().Return("/ws/root", nil),
 					m.mockimageBuilderPusher.EXPECT().BuildAndPush(gomock.Any(), &dockerengine.BuildArguments{
 						Dockerfile: filepath.Join("/ws", "root", "path", "to", "Dockerfile"),
 						Context:    filepath.Join("/ws", "root", "path", "to"),
@@ -387,7 +412,7 @@ image:
 				gomock.InOrder(
 					m.mockWs.EXPECT().ReadWorkloadManifest("serviceA").Return(mockMftNoContext, nil),
 					m.mockInterpolator.EXPECT().Interpolate(string(mockMftNoContext)).Return(string(mockMftNoContext), nil),
-					m.mockWs.EXPECT().CopilotDirPath().Return("/ws/root/copilot", nil),
+					m.mockWs.EXPECT().Path().Return("/ws/root", nil),
 					m.mockimageBuilderPusher.EXPECT().BuildAndPush(gomock.Any(), &dockerengine.BuildArguments{
 						Dockerfile: filepath.Join("/ws", "root", "path", "to", "Dockerfile"),
 						Context:    filepath.Join("/ws", "root", "path", "to"),
@@ -436,48 +461,59 @@ image:
 	}
 }
 
-func TestSvcDeployOpts_pushAddonsTemplateToS3Bucket(t *testing.T) {
+func TestSvcDeployOpts_pushToS3Bucket(t *testing.T) {
+	const (
+		mockSvcName         = "mockSvc"
+		mockEnvFile         = "foo.env"
+		mockS3Bucket        = "mockBucket"
+		mockAddonsS3URL     = "https://mockS3DomainName/mockPath"
+		mockBadEnvFileS3URL = "badURL"
+		mockEnvFileS3URL    = "https://stackset-demo-infrastruc-pipelinebuiltartifactbuc-11dj7ctf52wyf.s3.us-west-2.amazonaws.com/manual/1638391936/env"
+		mockEnvFileS3ARN    = "arn:aws:s3:::stackset-demo-infrastruc-pipelinebuiltartifactbuc-11dj7ctf52wyf/manual/1638391936/env"
+	)
+	mockEnvFilePath := fmt.Sprintf("%s/%s/%s", "manual", "e3b0c44298fc1c149afbf4c8996fb92427ae41e4649b934ca495991b7852b855", mockEnvFile)
 	mockError := errors.New("some error")
 	tests := map[string]struct {
-		inputSvc      string
+		inEnvFile     string
 		inEnvironment *config.Environment
 		inApp         *config.Application
 
-		mockAppResourcesGetter func(m *mocks.MockappResourcesGetter)
-		mockS3Svc              func(m *mocks.MockartifactUploader)
-		mockAddons             func(m *mocks.Mocktemplater)
+		mock func(m *deploySvcMocks)
 
-		wantPath string
-		wantErr  error
+		wantAddonsURL  string
+		wantEnvFileARN string
+		wantErr        error
 	}{
-		"should push addons template to S3 bucket": {
-			inputSvc: "mockSvc",
-			inEnvironment: &config.Environment{
-				Name:   "mockEnv",
-				Region: "us-west-2",
+		"error if fail to put env file to s3 bucket": {
+			inEnvFile: mockEnvFile,
+			mock: func(m *deploySvcMocks) {
+				m.mockS3Svc.EXPECT().Upload(mockS3Bucket, mockEnvFilePath, gomock.Any()).
+					Return("", mockError)
 			},
-			inApp: &config.Application{
-				Name: "mockApp",
-			},
-			mockAppResourcesGetter: func(m *mocks.MockappResourcesGetter) {
-				m.EXPECT().GetAppResourcesByRegion(&config.Application{
-					Name: "mockApp",
-				}, "us-west-2").Return(&stack.AppRegionalResources{
-					S3Bucket: "mockBucket",
-				}, nil)
-			},
-			mockAddons: func(m *mocks.Mocktemplater) {
-				m.EXPECT().Template().Return("some data", nil)
-			},
-			mockS3Svc: func(m *mocks.MockartifactUploader) {
-				m.EXPECT().PutArtifact("mockBucket", "mockSvc.addons.stack.yml", gomock.Any()).Return("https://mockS3DomainName/mockPath", nil)
-			},
-
-			wantErr:  nil,
-			wantPath: "https://mockS3DomainName/mockPath",
+			wantErr: fmt.Errorf("put env file foo.env artifact to bucket mockBucket: some error"),
 		},
-		"should return error if fail to get app resources": {
-			inputSvc: "mockSvc",
+		"error if fail to parse s3 url": {
+			inEnvFile: mockEnvFile,
+			mock: func(m *deploySvcMocks) {
+				m.mockS3Svc.EXPECT().Upload(mockS3Bucket, mockEnvFilePath, gomock.Any()).
+					Return(mockBadEnvFileS3URL, nil)
+
+			},
+			wantErr: fmt.Errorf("parse s3 url: cannot parse S3 URL badURL into bucket name and key"),
+		},
+		"error if fail to find the partition": {
+			inEnvFile: mockEnvFile,
+			inEnvironment: &config.Environment{
+				Region: "sun-south-0",
+			},
+			mock: func(m *deploySvcMocks) {
+				m.mockS3Svc.EXPECT().Upload(mockS3Bucket, mockEnvFilePath, gomock.Any()).
+					Return(mockEnvFileS3URL, nil)
+			},
+			wantErr: fmt.Errorf("find the partition for region sun-south-0"),
+		},
+		"should push addons template to S3 bucket": {
+			inEnvFile: mockEnvFile,
 			inEnvironment: &config.Environment{
 				Name:   "mockEnv",
 				Region: "us-west-2",
@@ -485,20 +521,18 @@ func TestSvcDeployOpts_pushAddonsTemplateToS3Bucket(t *testing.T) {
 			inApp: &config.Application{
 				Name: "mockApp",
 			},
-			mockAppResourcesGetter: func(m *mocks.MockappResourcesGetter) {
-				m.EXPECT().GetAppResourcesByRegion(&config.Application{
-					Name: "mockApp",
-				}, "us-west-2").Return(nil, mockError)
+			mock: func(m *deploySvcMocks) {
+				m.mockS3Svc.EXPECT().Upload(mockS3Bucket, mockEnvFilePath, gomock.Any()).
+					Return(mockEnvFileS3URL, nil)
+				m.mockAddons.EXPECT().Template().Return("some data", nil)
+				m.mockS3Svc.EXPECT().Upload(mockS3Bucket, "mockSvc.addons.stack.yml", gomock.Any()).
+					Return(mockAddonsS3URL, nil)
 			},
-			mockAddons: func(m *mocks.Mocktemplater) {
-				m.EXPECT().Template().Return("some data", nil)
-			},
-			mockS3Svc: func(m *mocks.MockartifactUploader) {},
 
-			wantErr: fmt.Errorf("get application mockApp resources from region us-west-2: some error"),
+			wantAddonsURL:  mockAddonsS3URL,
+			wantEnvFileARN: mockEnvFileS3ARN,
 		},
 		"should return error if fail to upload to S3 bucket": {
-			inputSvc: "mockSvc",
 			inEnvironment: &config.Environment{
 				Name:   "mockEnv",
 				Region: "us-west-2",
@@ -506,84 +540,67 @@ func TestSvcDeployOpts_pushAddonsTemplateToS3Bucket(t *testing.T) {
 			inApp: &config.Application{
 				Name: "mockApp",
 			},
-
-			mockAppResourcesGetter: func(m *mocks.MockappResourcesGetter) {
-				m.EXPECT().GetAppResourcesByRegion(&config.Application{
-					Name: "mockApp",
-				}, "us-west-2").Return(&stack.AppRegionalResources{
-					S3Bucket: "mockBucket",
-				}, nil)
-			},
-			mockAddons: func(m *mocks.Mocktemplater) {
-				m.EXPECT().Template().Return("some data", nil)
-			},
-			mockS3Svc: func(m *mocks.MockartifactUploader) {
-				m.EXPECT().PutArtifact("mockBucket", "mockSvc.addons.stack.yml", gomock.Any()).Return("", mockError)
+			mock: func(m *deploySvcMocks) {
+				m.mockAddons.EXPECT().Template().Return("some data", nil)
+				m.mockS3Svc.EXPECT().Upload(mockS3Bucket, "mockSvc.addons.stack.yml", gomock.Any()).
+					Return("", mockError)
 			},
 
 			wantErr: fmt.Errorf("put addons artifact to bucket mockBucket: some error"),
 		},
-		"should return empty url if the service doesn't have any addons": {
-			inputSvc: "mockSvc",
-			mockAddons: func(m *mocks.Mocktemplater) {
-				m.EXPECT().Template().Return("", &addon.ErrAddonsNotFound{
+		"should return empty url if the service doesn't have any addons and env files": {
+			mock: func(m *deploySvcMocks) {
+				m.mockAddons.EXPECT().Template().Return("", &addon.ErrAddonsNotFound{
 					WlName: "mockSvc",
 				})
 			},
-			mockAppResourcesGetter: func(m *mocks.MockappResourcesGetter) {
-				m.EXPECT().GetAppResourcesByRegion(gomock.Any(), gomock.Any()).Times(0)
-			},
-			mockS3Svc: func(m *mocks.MockartifactUploader) {
-				m.EXPECT().PutArtifact(gomock.Any(), gomock.Any(), gomock.Any()).Times(0)
-			},
-			wantPath: "",
 		},
 		"should fail if addons cannot be retrieved from workspace": {
-			inputSvc: "mockSvc",
-			mockAddons: func(m *mocks.Mocktemplater) {
-				m.EXPECT().Template().Return("", mockError)
-			},
-			mockAppResourcesGetter: func(m *mocks.MockappResourcesGetter) {
-				m.EXPECT().GetAppResourcesByRegion(gomock.Any(), gomock.Any()).Times(0)
-			},
-			mockS3Svc: func(m *mocks.MockartifactUploader) {
-				m.EXPECT().PutArtifact(gomock.Any(), gomock.Any(), gomock.Any()).Times(0)
+			mock: func(m *deploySvcMocks) {
+				m.mockAddons.EXPECT().Template().Return("", mockError)
 			},
 			wantErr: fmt.Errorf("retrieve addons template: %w", mockError),
 		},
 	}
 
 	for name, tc := range tests {
+		fs := afero.NewMemMapFs()
+		afero.WriteFile(fs, mockEnvFile, []byte{}, 0644)
 		t.Run(name, func(t *testing.T) {
 			ctrl := gomock.NewController(t)
 			defer ctrl.Finish()
 
-			mockAppSvc := mocks.NewMockstore(ctrl)
-			mockAppResourcesGetter := mocks.NewMockappResourcesGetter(ctrl)
-			mockS3Svc := mocks.NewMockartifactUploader(ctrl)
-			mockAddons := mocks.NewMocktemplater(ctrl)
-			tc.mockAppResourcesGetter(mockAppResourcesGetter)
-			tc.mockS3Svc(mockS3Svc)
-			tc.mockAddons(mockAddons)
+			m := &deploySvcMocks{
+				mockWs:     mocks.NewMockwsSvcDirReader(ctrl),
+				mockS3Svc:  mocks.NewMockuploader(ctrl),
+				mockAddons: mocks.NewMocktemplater(ctrl),
+			}
+			tc.mock(m)
 
 			opts := deploySvcOpts{
 				deployWkldVars: deployWkldVars{
-					name: tc.inputSvc,
+					name: mockSvcName,
 				},
-				store:             mockAppSvc,
-				appCFN:            mockAppResourcesGetter,
-				addons:            mockAddons,
-				s3:                mockS3Svc,
+				addons:            m.mockAddons,
+				s3:                m.mockS3Svc,
+				ws:                m.mockWs,
+				fs:                &afero.Afero{Fs: fs},
+				appliedManifest:   &mockWorkloadMft{tc.inEnvFile},
+				workspacePath:     ".",
 				targetEnvironment: tc.inEnvironment,
 				targetApp:         tc.inApp,
+				appEnvResources: &stack.AppRegionalResources{
+					S3Bucket: mockS3Bucket,
+				},
 			}
 
-			gotPath, gotErr := opts.pushAddonsTemplateToS3Bucket()
+			gotErr := opts.pushArtifactsToS3()
 
 			if gotErr != nil {
 				require.EqualError(t, gotErr, tc.wantErr.Error())
 			} else {
-				require.Equal(t, tc.wantPath, gotPath)
+				require.Equal(t, tc.wantAddonsURL, opts.addonsURL)
+				require.Equal(t, tc.wantEnvFileARN, opts.envFileARN)
 			}
 		})
 	}
@@ -597,6 +614,9 @@ func TestSvcDeployOpts_deploySvc(t *testing.T) {
 		mockSvcName   = "mockSvc"
 		mockAddonsURL = "mockAddonsURL"
 	)
+	mockAfterTime := time.Unix(1494505756, 0)
+	mockNowTime := time.Unix(1494505750, 0)
+	mockBeforeTime := time.Unix(1494505743, 0)
 	tests := map[string]struct {
 		inAliases      manifest.Alias
 		inNLB          manifest.NetworkLoadBalancerConfiguration
@@ -622,10 +642,10 @@ func TestSvcDeployOpts_deploySvc(t *testing.T) {
 			},
 			wantErr: fmt.Errorf("interpolate environment variables for mockSvc manifest: %w", mockError),
 		},
-		"fail to describe environment": {
+		"fail to get public CIDR blocks": {
 			inBuildRequire: false,
 			inNLB: manifest.NetworkLoadBalancerConfiguration{
-				Port: aws.String("443/udp"),
+				Port: aws.String("443/tls"),
 			},
 			inEnvironment: &config.Environment{
 				Name:   mockEnvName,
@@ -638,34 +658,9 @@ func TestSvcDeployOpts_deploySvc(t *testing.T) {
 				m.mockWs.EXPECT().ReadWorkloadManifest(mockSvcName).Return([]byte{}, nil)
 				m.mockInterpolator.EXPECT().Interpolate("").Return("", nil)
 				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
-				m.mockEnvDescriber.EXPECT().Describe().Return(nil, errors.New("some error"))
+				m.mockEnvDescriber.EXPECT().PublicCIDRBlocks().Return(nil, errors.New("some error"))
 			},
-			wantErr: fmt.Errorf("describe environment mockEnv: some error"),
-		},
-		"fail to list subnets": {
-			inBuildRequire: false,
-			inNLB: manifest.NetworkLoadBalancerConfiguration{
-				Port: aws.String("443/udp"),
-			},
-			inEnvironment: &config.Environment{
-				Name:   mockEnvName,
-				Region: "us-west-2",
-			},
-			inApp: &config.Application{
-				Name: mockAppName,
-			},
-			mock: func(m *deploySvcMocks) {
-				m.mockWs.EXPECT().ReadWorkloadManifest(mockSvcName).Return([]byte{}, nil)
-				m.mockInterpolator.EXPECT().Interpolate("").Return("", nil)
-				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
-				m.mockEnvDescriber.EXPECT().Describe().Return(&describe.EnvDescription{
-					EnvironmentVPC: describe.EnvironmentVPC{
-						ID: "mockVPCID",
-					},
-				}, nil)
-				m.mockSubnetLister.EXPECT().ListVPCSubnets("mockVPCID").Return(nil, errors.New("some error"))
-			},
-			wantErr: fmt.Errorf("list subnets of vpc mockVPCID in environment mockEnv: some error"),
+			wantErr: fmt.Errorf("get public CIDR blocks information from the VPC of environment mockEnv: some error"),
 		},
 		"fail to get app resources": {
 			inBuildRequire: true,
@@ -761,6 +756,27 @@ func TestSvcDeployOpts_deploySvc(t *testing.T) {
 			},
 			wantErr: fmt.Errorf("alias is not compatible with application versions below %s", deploy.AliasLeastAppTemplateVersion),
 		},
+		"fail to enable nlb alias because of incompatible app version": {
+			inNLB: manifest.NetworkLoadBalancerConfiguration{
+				Port:    aws.String("80"),
+				Aliases: manifest.Alias{String: aws.String("mockAlias")},
+			},
+			inEnvironment: &config.Environment{
+				Name:   mockEnvName,
+				Region: "us-west-2",
+			},
+			inApp: &config.Application{
+				Name:   mockAppName,
+				Domain: "mockDomain",
+			},
+			mock: func(m *deploySvcMocks) {
+				m.mockWs.EXPECT().ReadWorkloadManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockInterpolator.EXPECT().Interpolate("").Return("", nil)
+				m.mockAppVersionGetter.EXPECT().Version().Return("v0.0.0", nil)
+				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
+			},
+			wantErr: fmt.Errorf("alias is not compatible with application versions below %s", deploy.AliasLeastAppTemplateVersion),
+		},
 		"fail to enable https alias because of invalid alias": {
 			inAliases: manifest.Alias{String: aws.String("v1.v2.mockDomain")},
 			inEnvironment: &config.Environment{
@@ -779,20 +795,45 @@ func TestSvcDeployOpts_deploySvc(t *testing.T) {
 			},
 			wantErr: fmt.Errorf(`alias "v1.v2.mockDomain" is not supported in hosted zones managed by Copilot`),
 		},
+		"fail to enable nlb alias because of invalid alias": {
+			inNLB: manifest.NetworkLoadBalancerConfiguration{
+				Port:    aws.String("80"),
+				Aliases: manifest.Alias{String: aws.String("v1.v2.mockDomain")},
+			},
+			inEnvironment: &config.Environment{
+				Name:   mockEnvName,
+				Region: "us-west-2",
+			},
+			inApp: &config.Application{
+				Name:   mockAppName,
+				Domain: "mockDomain",
+			},
+			mock: func(m *deploySvcMocks) {
+				m.mockWs.EXPECT().ReadWorkloadManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockInterpolator.EXPECT().Interpolate("").Return("", nil)
+				m.mockAppVersionGetter.EXPECT().Version().Return("v1.0.0", nil)
+				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
+			},
+			wantErr: fmt.Errorf(`alias "v1.v2.mockDomain" is not supported in hosted zones managed by Copilot`),
+		},
 		"error if fail to deploy service": {
 			inEnvironment: &config.Environment{
 				Name:   mockEnvName,
 				Region: "us-west-2",
 			},
 			inApp: &config.Application{
-				Name:   mockAppName,
-				Domain: "mockDomain",
+				Name: mockAppName,
 			},
 			mock: func(m *deploySvcMocks) {
 				m.mockWs.EXPECT().ReadWorkloadManifest(mockSvcName).Return([]byte{}, nil)
 				m.mockInterpolator.EXPECT().Interpolate("").Return("", nil)
 				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
-				m.mockServiceDeployer.EXPECT().DeployService(gomock.Any(), gomock.Any(), gomock.Any()).Return(errors.New("some error"))
+				m.mockAppResourcesGetter.EXPECT().GetAppResourcesByRegion(&config.Application{
+					Name: mockAppName,
+				}, "us-west-2").Return(&stack.AppRegionalResources{
+					S3Bucket: "mockBucket",
+				}, nil)
+				m.mockServiceDeployer.EXPECT().DeployService(gomock.Any(), gomock.Any(), "mockBucket", gomock.Any()).Return(errors.New("some error"))
 			},
 			wantErr: fmt.Errorf("deploy service: some error"),
 		},
@@ -802,17 +843,70 @@ func TestSvcDeployOpts_deploySvc(t *testing.T) {
 				Region: "us-west-2",
 			},
 			inApp: &config.Application{
-				Name:   mockAppName,
-				Domain: "mockDomain",
+				Name: mockAppName,
 			},
 			mock: func(m *deploySvcMocks) {
 				m.mockWs.EXPECT().ReadWorkloadManifest(mockSvcName).Return([]byte{}, nil)
 				m.mockInterpolator.EXPECT().Interpolate("").Return("", nil)
 				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
-				m.mockServiceDeployer.EXPECT().DeployService(gomock.Any(), gomock.Any(), gomock.Any()).Return(cloudformation.NewMockErrChangeSetEmpty())
+				m.mockAppResourcesGetter.EXPECT().GetAppResourcesByRegion(&config.Application{
+					Name: mockAppName,
+				}, "us-west-2").Return(&stack.AppRegionalResources{
+					S3Bucket: "mockBucket",
+				}, nil)
+				m.mockServiceDeployer.EXPECT().DeployService(gomock.Any(), gomock.Any(), "mockBucket", gomock.Any()).Return(cloudformation.NewMockErrChangeSetEmpty())
 			},
 			wantErr: fmt.Errorf("deploy service: change set with name mockChangeSet for stack mockStack has no changes"),
 		},
+		"error if fail to get last update time when force an update": {
+			inForceDeploy: true,
+			inEnvironment: &config.Environment{
+				Name:   mockEnvName,
+				Region: "us-west-2",
+			},
+			inApp: &config.Application{
+				Name: mockAppName,
+			},
+			mock: func(m *deploySvcMocks) {
+				m.mockWs.EXPECT().ReadWorkloadManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockInterpolator.EXPECT().Interpolate("").Return("", nil)
+				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
+				m.mockAppResourcesGetter.EXPECT().GetAppResourcesByRegion(&config.Application{
+					Name: mockAppName,
+				}, "us-west-2").Return(&stack.AppRegionalResources{
+					S3Bucket: "mockBucket",
+				}, nil)
+				m.mockServiceDeployer.EXPECT().DeployService(gomock.Any(), gomock.Any(), "mockBucket", gomock.Any()).
+					Return(nil)
+				m.mockServiceUpdater.EXPECT().LastUpdatedAt(mockAppName, mockEnvName, mockSvcName).
+					Return(time.Time{}, mockError)
+			},
+			wantErr: fmt.Errorf("get the last updated deployment time for mockSvc: some error"),
+		},
+		"skip force updating when cmd run time is after the last update time": {
+			inForceDeploy: true,
+			inEnvironment: &config.Environment{
+				Name:   mockEnvName,
+				Region: "us-west-2",
+			},
+			inApp: &config.Application{
+				Name: mockAppName,
+			},
+			mock: func(m *deploySvcMocks) {
+				m.mockWs.EXPECT().ReadWorkloadManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockInterpolator.EXPECT().Interpolate("").Return("", nil)
+				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
+				m.mockAppResourcesGetter.EXPECT().GetAppResourcesByRegion(&config.Application{
+					Name: mockAppName,
+				}, "us-west-2").Return(&stack.AppRegionalResources{
+					S3Bucket: "mockBucket",
+				}, nil)
+				m.mockServiceDeployer.EXPECT().DeployService(gomock.Any(), gomock.Any(), "mockBucket", gomock.Any()).
+					Return(nil)
+				m.mockServiceUpdater.EXPECT().LastUpdatedAt(mockAppName, mockEnvName, mockSvcName).
+					Return(mockAfterTime, nil)
+			},
+		},
 		"error if fail to force an update": {
 			inForceDeploy: true,
 			inEnvironment: &config.Environment{
@@ -820,15 +914,21 @@ func TestSvcDeployOpts_deploySvc(t *testing.T) {
 				Region: "us-west-2",
 			},
 			inApp: &config.Application{
-				Name:   mockAppName,
-				Domain: "mockDomain",
+				Name: mockAppName,
 			},
 			mock: func(m *deploySvcMocks) {
 				m.mockWs.EXPECT().ReadWorkloadManifest(mockSvcName).Return([]byte{}, nil)
 				m.mockInterpolator.EXPECT().Interpolate("").Return("", nil)
 				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
-				m.mockServiceDeployer.EXPECT().DeployService(gomock.Any(), gomock.Any(), gomock.Any()).
+				m.mockAppResourcesGetter.EXPECT().GetAppResourcesByRegion(&config.Application{
+					Name: mockAppName,
+				}, "us-west-2").Return(&stack.AppRegionalResources{
+					S3Bucket: "mockBucket",
+				}, nil)
+				m.mockServiceDeployer.EXPECT().DeployService(gomock.Any(), gomock.Any(), "mockBucket", gomock.Any()).
 					Return(cloudformation.NewMockErrChangeSetEmpty())
+				m.mockServiceUpdater.EXPECT().LastUpdatedAt(mockAppName, mockEnvName, mockSvcName).
+					Return(mockBeforeTime, nil)
 				m.mockSpinner.EXPECT().Start(fmt.Sprintf(fmtForceUpdateSvcStart, mockSvcName, mockEnvName))
 				m.mockServiceUpdater.EXPECT().ForceUpdateService(mockAppName, mockEnvName, mockSvcName).Return(mockError)
 				m.mockSpinner.EXPECT().Stop(log.Serrorf(fmtForceUpdateSvcFailed, mockSvcName, mockEnvName, mockError))
@@ -842,15 +942,21 @@ func TestSvcDeployOpts_deploySvc(t *testing.T) {
 				Region: "us-west-2",
 			},
 			inApp: &config.Application{
-				Name:   mockAppName,
-				Domain: "mockDomain",
+				Name: mockAppName,
 			},
 			mock: func(m *deploySvcMocks) {
 				m.mockWs.EXPECT().ReadWorkloadManifest(mockSvcName).Return([]byte{}, nil)
 				m.mockInterpolator.EXPECT().Interpolate("").Return("", nil)
 				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
-				m.mockServiceDeployer.EXPECT().DeployService(gomock.Any(), gomock.Any(), gomock.Any()).
+				m.mockAppResourcesGetter.EXPECT().GetAppResourcesByRegion(&config.Application{
+					Name: mockAppName,
+				}, "us-west-2").Return(&stack.AppRegionalResources{
+					S3Bucket: "mockBucket",
+				}, nil)
+				m.mockServiceDeployer.EXPECT().DeployService(gomock.Any(), gomock.Any(), "mockBucket", gomock.Any()).
 					Return(cloudformation.NewMockErrChangeSetEmpty())
+				m.mockServiceUpdater.EXPECT().LastUpdatedAt(mockAppName, mockEnvName, mockSvcName).
+					Return(mockBeforeTime, nil)
 				m.mockSpinner.EXPECT().Start(fmt.Sprintf(fmtForceUpdateSvcStart, mockSvcName, mockEnvName))
 				m.mockServiceUpdater.EXPECT().ForceUpdateService(mockAppName, mockEnvName, mockSvcName).
 					Return(&ecs.ErrWaitServiceStableTimeout{})
@@ -881,8 +987,16 @@ func TestSvcDeployOpts_deploySvc(t *testing.T) {
 				m.mockInterpolator.EXPECT().Interpolate("").Return("", nil)
 				m.mockAppVersionGetter.EXPECT().Version().Return("v1.0.0", nil)
 				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
-				m.mockServiceDeployer.EXPECT().DeployService(gomock.Any(), gomock.Any(), gomock.Any()).Return(nil)
-
+				m.mockIdentity.EXPECT().Get().Return(identity.Caller{
+					RootUserARN: "1234",
+				}, nil)
+				m.mockAppResourcesGetter.EXPECT().GetAppResourcesByRegion(&config.Application{
+					Name:   mockAppName,
+					Domain: "mockDomain",
+				}, "us-west-2").Return(&stack.AppRegionalResources{
+					S3Bucket: "mockBucket",
+				}, nil)
+				m.mockServiceDeployer.EXPECT().DeployService(gomock.Any(), gomock.Any(), "mockBucket", gomock.Any()).Return(nil)
 			},
 		},
 		"success with force update": {
@@ -892,14 +1006,21 @@ func TestSvcDeployOpts_deploySvc(t *testing.T) {
 				Region: "us-west-2",
 			},
 			inApp: &config.Application{
-				Name:   mockAppName,
-				Domain: "mockDomain",
+				Name: mockAppName,
 			},
 			mock: func(m *deploySvcMocks) {
 				m.mockWs.EXPECT().ReadWorkloadManifest(mockSvcName).Return([]byte{}, nil)
 				m.mockInterpolator.EXPECT().Interpolate("").Return("", nil)
 				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
-				m.mockServiceDeployer.EXPECT().DeployService(gomock.Any(), gomock.Any(), gomock.Any()).Return(cloudformation.NewMockErrChangeSetEmpty())
+				m.mockAppResourcesGetter.EXPECT().GetAppResourcesByRegion(&config.Application{
+					Name: mockAppName,
+				}, "us-west-2").Return(&stack.AppRegionalResources{
+					S3Bucket: "mockBucket",
+				}, nil)
+				m.mockServiceDeployer.EXPECT().DeployService(gomock.Any(), gomock.Any(), "mockBucket", gomock.Any()).
+					Return(cloudformation.NewMockErrChangeSetEmpty())
+				m.mockServiceUpdater.EXPECT().LastUpdatedAt(mockAppName, mockEnvName, mockSvcName).
+					Return(mockBeforeTime, nil)
 				m.mockSpinner.EXPECT().Start(fmt.Sprintf(fmtForceUpdateSvcStart, mockSvcName, mockEnvName))
 				m.mockServiceUpdater.EXPECT().ForceUpdateService(mockAppName, mockEnvName, mockSvcName).Return(nil)
 				m.mockSpinner.EXPECT().Stop(log.Ssuccessf(fmtForceUpdateSvcComplete, mockSvcName, mockEnvName))
@@ -918,11 +1039,12 @@ func TestSvcDeployOpts_deploySvc(t *testing.T) {
 				mockAppVersionGetter:   mocks.NewMockversionGetter(ctrl),
 				mockEndpointGetter:     mocks.NewMockendpointGetter(ctrl),
 				mockServiceDeployer:    mocks.NewMockserviceDeployer(ctrl),
-				mockServiceUpdater:     mocks.NewMockserviceUpdater(ctrl),
+				mockServiceUpdater:     mocks.NewMocksvcForceUpdater(ctrl),
 				mockSpinner:            mocks.NewMockprogress(ctrl),
 				mockInterpolator:       mocks.NewMockinterpolator(ctrl),
 				mockEnvDescriber:       mocks.NewMockenvDescriber(ctrl),
-				mockSubnetLister:       mocks.NewMockvpcSubnetLister(ctrl),
+				mockIdentity:           mocks.NewMockidentityService(ctrl),
+				mockUploader:           mocks.NewMockcustomResourcesUploader(ctrl),
 			}
 			tc.mock(m)
 
@@ -940,6 +1062,7 @@ func TestSvcDeployOpts_deploySvc(t *testing.T) {
 					return m.mockAppVersionGetter, nil
 				},
 				endpointGetter:    m.mockEndpointGetter,
+				identity:          m.mockIdentity,
 				targetApp:         tc.inApp,
 				targetEnvironment: tc.inEnvironment,
 				newInterpolator: func(app, env string) interpolator {
@@ -959,8 +1082,11 @@ func TestSvcDeployOpts_deploySvc(t *testing.T) {
 									Port: aws.Uint16(80),
 								},
 							},
-							RoutingRule: manifest.RoutingRule{
-								Alias: tc.inAliases,
+							RoutingRule: manifest.RoutingRuleConfigOrBool{
+								RoutingRuleConfiguration: manifest.RoutingRuleConfiguration{
+									Path:  aws.String("/"),
+									Alias: tc.inAliases,
+								},
 							},
 							NLBConfig: tc.inNLB,
 						},
@@ -968,13 +1094,23 @@ func TestSvcDeployOpts_deploySvc(t *testing.T) {
 				},
 				svcCFN:        m.mockServiceDeployer,
 				svcUpdater:    m.mockServiceUpdater,
-				newSvcUpdater: func(f func(*session.Session) serviceUpdater) {},
+				newSvcUpdater: func(f func(*session.Session) svcForceUpdater) {},
 				spinner:       m.mockSpinner,
 				envDescriber:  m.mockEnvDescriber,
-				subnetLister:  m.mockSubnetLister,
+
+				addonsURL: mockAddonsURL,
+				now: func() time.Time {
+					return mockNowTime
+				},
+				uploadOpts: &uploadCustomResourcesOpts{
+					uploader: m.mockUploader,
+					newS3Uploader: func() (uploader, error) {
+						return nil, nil
+					},
+				},
 			}
 
-			gotErr := opts.deploySvc(mockAddonsURL)
+			gotErr := opts.deploySvc()
 
 			if tc.wantErr != nil {
 				require.EqualError(t, gotErr, tc.wantErr.Error())
@@ -1026,7 +1162,6 @@ func TestSvcDeployOpts_rdWebServiceStackConfiguration(t *testing.T) {
 				m.mockWorkspace.EXPECT().ReadWorkloadManifest(mockSvcName).Return([]byte{}, nil)
 				m.mockInterpolator.EXPECT().Interpolate("").Return("", nil)
 				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
-
 			},
 
 			wantErr: errors.New("alias specified when application is not associated with a domain"),
@@ -1258,7 +1393,7 @@ func TestSvcDeployOpts_rdWebServiceStackConfiguration(t *testing.T) {
 				newInterpolator: func(app, env string) interpolator {
 					return m.mockInterpolator
 				},
-				newSvcUpdater:     func(f func(*session.Session) serviceUpdater) {},
+				newSvcUpdater:     func(f func(*session.Session) svcForceUpdater) {},
 				endpointGetter:    m.mockEndpointGetter,
 				identity:          m.mockIdentity,
 				targetApp:         tc.inApp,
@@ -1283,13 +1418,14 @@ func TestSvcDeployOpts_rdWebServiceStackConfiguration(t *testing.T) {
 				},
 				uploadOpts: &uploadCustomResourcesOpts{
 					uploader: m.mockUploader,
-					newS3Uploader: func() (Uploader, error) {
+					newS3Uploader: func() (uploader, error) {
 						return nil, nil
 					},
 				},
+				addonsURL: mockAddonsURL,
 			}
 
-			_, gotErr := opts.stackConfiguration(mockAddonsURL)
+			_, gotErr := opts.stackConfiguration()
 
 			if tc.wantErr != nil {
 				require.EqualError(t, gotErr, tc.wantErr.Error())
@@ -1382,7 +1518,7 @@ func TestSvcDeployOpts_stackConfiguration_worker(t *testing.T) {
 				},
 				ws:                m.mockWs,
 				buildRequired:     tc.inBuildRequire,
-				newSvcUpdater:     func(f func(*session.Session) serviceUpdater) {},
+				newSvcUpdater:     func(f func(*session.Session) svcForceUpdater) {},
 				endpointGetter:    m.mockEndpointGetter,
 				snsTopicGetter:    m.mockDeployStore,
 				targetApp:         tc.inApp,
@@ -1404,9 +1540,10 @@ func TestSvcDeployOpts_stackConfiguration_worker(t *testing.T) {
 						},
 					}, nil
 				},
+				addonsURL: mockAddonsURL,
 			}
 
-			_, gotErr := opts.stackConfiguration(mockAddonsURL)
+			_, gotErr := opts.stackConfiguration()
 
 			if tc.wantErr != nil {
 				require.EqualError(t, gotErr, tc.wantErr.Error())
