@@ -31,7 +31,6 @@ import (
 )
 
 const (
-	wkldInitImagePrompt     = `What's the location of the image to use?`
 	wkldInitImagePromptHelp = `The name of an existing Docker image. Images in the Docker Hub registry are available by default.
 Other repositories are specified with either repository-url/image:tag or repository-url/image@digest`
 	wkldInitAppRunnerImagePromptHelp = `The name of an existing Docker image. App Runner supports images hosted in ECR or ECR Public registries.`
@@ -40,6 +39,7 @@ Other repositories are specified with either repository-url/image:tag or reposit
 const (
 	defaultSvcPortString = "80"
 	service              = "service"
+	job                  = "job"
 )
 
 var (
@@ -77,6 +77,8 @@ You should set this to the port which your Dockerfile uses to communicate with t
 	svcInitPublisherPrompt     = "Which topics do you want to subscribe to?"
 	svcInitPublisherHelpPrompt = `A publisher is an existing SNS Topic to which a service publishes messages. 
 These messages can be consumed by the Worker Service.`
+
+	wkldInitImagePrompt = fmt.Sprintf("What's the %s ([registry/]repository[:tag|@digest]) of the image to use?", color.Emphasize("location"))
 )
 
 var serviceTypeHints = map[string]string{
@@ -109,6 +111,7 @@ type initSvcOpts struct {
 	fs           afero.Fs
 	init         svcInitializer
 	prompt       prompter
+	store        store
 	dockerEngine dockerEngine
 	sel          dockerfileSelector
 	topicSel     topicSelector
@@ -158,8 +161,8 @@ func newInitSvcOpts(vars initSvcVars) (*initSvcOpts, error) {
 	}
 	fs := &afero.Afero{Fs: afero.NewOsFs()}
 	opts := &initSvcOpts{
-		initSvcVars: vars,
-
+		initSvcVars:  vars,
+		store:        store,
 		fs:           fs,
 		init:         initSvc,
 		prompt:       prompter,
@@ -192,6 +195,9 @@ func (o *initSvcOpts) Validate() error {
 		if err := validateSvcName(o.name, o.wkldType); err != nil {
 			return err
 		}
+		if err := o.validateDuplicateSvc(); err != nil {
+			return err
+		}
 	}
 	if o.dockerfilePath != "" && o.image != "" {
 		return fmt.Errorf("--%s and --%s cannot be specified together", dockerFileFlag, imageFlag)
@@ -229,7 +235,7 @@ func (o *initSvcOpts) Ask() error {
 			return fmt.Errorf(`read "type" field for service %s from local manifest: %w`, o.name, err)
 		}
 		o.wkldType = svcType
-		log.Infof("Manifest file for job %s already exists. Skipping configuration.\n", o.name)
+		log.Infof("Manifest file for service %s already exists. Skipping configuration.\n", o.name)
 		return nil
 	}
 	var (
@@ -328,6 +334,27 @@ func (o *initSvcOpts) askSvcType() error {
 	return nil
 }
 
+func (o *initSvcOpts) validateDuplicateSvc() error {
+	_, err := o.store.GetService(o.appName, o.name)
+	if err == nil {
+		log.Errorf(`It seems like you are trying to init a service that already exists.
+To recreate the service, please run:
+1. %s. Note: The manifest file will not be deleted and will be used in Step 2.
+If you'd prefer a new default manifest, please manually delete the existing one.
+2. And then %s
+`,
+			color.HighlightCode(fmt.Sprintf("copilot svc delete --name %s", o.name)),
+			color.HighlightCode(fmt.Sprintf("copilot svc init --name %s", o.name)))
+		return fmt.Errorf("service %s already exists", color.HighlightUserInput(o.name))
+	}
+
+	var errNoSuchSvc *config.ErrNoSuchService
+	if !errors.As(err, &errNoSuchSvc) {
+		return fmt.Errorf("validate if service exists: %w", err)
+	}
+	return nil
+}
+
 func (o *initSvcOpts) askSvcName() error {
 	if o.name != "" {
 		return nil
@@ -343,7 +370,7 @@ func (o *initSvcOpts) askSvcName() error {
 		return fmt.Errorf("get service name: %w", err)
 	}
 	o.name = name
-	return nil
+	return o.validateDuplicateSvc()
 }
 
 func (o *initSvcOpts) askImage() error {
@@ -558,7 +585,7 @@ func parseHealthCheck(df dockerfileParser) (manifest.ContainerHealthCheck, error
 
 func svcTypePromptOpts() []prompt.Option {
 	var options []prompt.Option
-	for _, svcType := range manifest.ServiceTypes {
+	for _, svcType := range manifest.ServiceTypes() {
 		options = append(options, prompt.Option{
 			Value: svcType,
 			Hint:  serviceTypeHints[svcType],
