@@ -7,10 +7,11 @@ import (
 	"errors"
 	"testing"
 
+	"github.com/aws/aws-sdk-go/aws"
+
 	"github.com/aws/aws-sdk-go/aws/session"
 
 	awscfn "github.com/aws/copilot-cli/internal/pkg/aws/cloudformation"
-	"github.com/aws/copilot-cli/internal/pkg/aws/sessions"
 	"github.com/aws/copilot-cli/internal/pkg/cli/mocks"
 	"github.com/aws/copilot-cli/internal/pkg/config"
 	"github.com/aws/copilot-cli/internal/pkg/deploy"
@@ -19,8 +20,9 @@ import (
 )
 
 type validateMocks struct {
-	store *mocks.Mockstore
-	cfn   *mocks.MocktaskStackManager
+	store    *mocks.Mockstore
+	cfn      *mocks.MocktaskStackManager
+	provider *mocks.MocksessionProvider
 }
 
 func TestDeleteTaskOpts_Validate(t *testing.T) {
@@ -62,6 +64,7 @@ func TestDeleteTaskOpts_Validate(t *testing.T) {
 				m.store.EXPECT().GetApplication("phonetool").Return(&config.Application{Name: "phonetool"}, nil)
 				m.store.EXPECT().GetEnvironment("phonetool", "test").Return(&config.Environment{Name: "test", App: "phonetool"}, nil)
 				m.store.EXPECT().GetEnvironment("phonetool", "test").Return(&config.Environment{Name: "test", App: "phonetool"}, nil)
+				m.provider.EXPECT().FromRole(gomock.Any(), gomock.Any()).Return(&session.Session{}, nil)
 				m.cfn.EXPECT().GetTaskStack("oneoff")
 			},
 			want: nil,
@@ -75,6 +78,7 @@ func TestDeleteTaskOpts_Validate(t *testing.T) {
 				m.store.EXPECT().GetApplication("phonetool").Return(&config.Application{Name: "phonetool"}, nil)
 				m.store.EXPECT().GetEnvironment("phonetool", "test").Return(&config.Environment{Name: "test", App: "phonetool"}, nil)
 				m.store.EXPECT().GetEnvironment("phonetool", "test").Return(&config.Environment{Name: "test", App: "phonetool"}, nil)
+				m.provider.EXPECT().FromRole(gomock.Any(), gomock.Any()).Return(&session.Session{}, nil)
 				m.cfn.EXPECT().GetTaskStack("oneoff").Return(nil, errors.New("some error"))
 			},
 		},
@@ -82,6 +86,7 @@ func TestDeleteTaskOpts_Validate(t *testing.T) {
 			inDefaultCluster: true,
 			inName:           "oneoff",
 			setupMocks: func(m validateMocks) {
+				m.provider.EXPECT().Default().Return(&session.Session{}, nil)
 				m.cfn.EXPECT().GetTaskStack("oneoff")
 			},
 			want: nil,
@@ -111,8 +116,9 @@ func TestDeleteTaskOpts_Validate(t *testing.T) {
 			mocktaskStackManager := mocks.NewMocktaskStackManager(ctrl)
 
 			mocks := validateMocks{
-				store: mockstore,
-				cfn:   mocktaskStackManager,
+				store:    mockstore,
+				cfn:      mocktaskStackManager,
+				provider: mocks.NewMocksessionProvider(ctrl),
 			}
 
 			tc.setupMocks(mocks)
@@ -129,7 +135,7 @@ func TestDeleteTaskOpts_Validate(t *testing.T) {
 				newStackManager: func(_ *session.Session) taskStackManager {
 					return mocktaskStackManager
 				},
-				sess: sessions.NewProvider(),
+				provider: mocks.provider,
 			}
 
 			// WHEN
@@ -292,10 +298,10 @@ func TestDeleteTaskOpts_Ask(t *testing.T) {
 					name:             tc.inName,
 				},
 
-				store:  mockStore,
-				sel:    mockSel,
-				sess:   mockSess,
-				prompt: mockPrompt,
+				store:    mockStore,
+				sel:      mockSel,
+				provider: mockSess,
+				prompt:   mockPrompt,
 
 				newTaskSel: func(sess *session.Session) cfTaskSelector { return mockTaskSel },
 			}
@@ -315,7 +321,7 @@ func TestDeleteTaskOpts_Ask(t *testing.T) {
 
 type deleteTaskMocks struct {
 	store   *mocks.Mockstore
-	sess    *sessions.Provider
+	sess    *mocks.MocksessionProvider
 	ecr     *mocks.MockimageRemover
 	ecs     *mocks.MocktaskStopper
 	cfn     *mocks.MocktaskStackManager
@@ -364,6 +370,12 @@ func TestDeleteTaskOpts_Execute(t *testing.T) {
 			inName: mockTaskName,
 
 			setupMocks: func(m deleteTaskMocks) {
+				m.sess.EXPECT().FromRole(mockEnv.ManagerRoleARN, mockEnv.Region).Return(&session.Session{
+					Config: &aws.Config{
+						Region: aws.String("mockRegion"),
+					},
+				}, nil)
+				m.sess.EXPECT().DefaultWithRegion("mockRegion").Return(&session.Session{}, nil)
 				gomock.InOrder(
 					m.store.EXPECT().GetEnvironment(mockApp, mockEnvName).Return(mockEnv, nil),
 					m.spinner.EXPECT().Start(gomock.Any()),
@@ -385,6 +397,7 @@ func TestDeleteTaskOpts_Execute(t *testing.T) {
 
 			setupMocks: func(m deleteTaskMocks) {
 				gomock.InOrder(
+					m.sess.EXPECT().Default().Return(&session.Session{}, nil),
 					m.spinner.EXPECT().Start(gomock.Any()),
 					m.ecs.EXPECT().StopDefaultClusterTasks(mockTaskName).Return(nil),
 					m.spinner.EXPECT().Stop(gomock.Any()),
@@ -419,6 +432,12 @@ func TestDeleteTaskOpts_Execute(t *testing.T) {
 			wantedErr: errors.New("delete stack for task hide-snacks: some error"),
 
 			setupMocks: func(m deleteTaskMocks) {
+				m.sess.EXPECT().FromRole(mockEnv.ManagerRoleARN, mockEnv.Region).Return(&session.Session{
+					Config: &aws.Config{
+						Region: aws.String("mockRegion"),
+					},
+				}, nil)
+				m.sess.EXPECT().DefaultWithRegion("mockRegion").Return(&session.Session{}, nil)
 				gomock.InOrder(
 					m.store.EXPECT().GetEnvironment(mockApp, mockEnvName).Return(mockEnv, nil),
 					m.spinner.EXPECT().Start(gomock.Any()),
@@ -441,6 +460,12 @@ func TestDeleteTaskOpts_Execute(t *testing.T) {
 
 			setupMocks: func(m deleteTaskMocks) {
 				mockErrStackNotFound := awscfn.ErrStackNotFound{}
+				m.sess.EXPECT().FromRole(mockEnv.ManagerRoleARN, mockEnv.Region).Return(&session.Session{
+					Config: &aws.Config{
+						Region: aws.String("mockRegion"),
+					},
+				}, nil)
+				m.sess.EXPECT().DefaultWithRegion("mockRegion").Return(&session.Session{}, nil)
 				gomock.InOrder(
 					m.store.EXPECT().GetEnvironment(mockApp, mockEnvName).Return(mockEnv, nil),
 					m.spinner.EXPECT().Start(gomock.Any()),
@@ -461,6 +486,12 @@ func TestDeleteTaskOpts_Execute(t *testing.T) {
 			wantedErr: errors.New("clear ECR repository for task hide-snacks: some error"),
 
 			setupMocks: func(m deleteTaskMocks) {
+				m.sess.EXPECT().FromRole(mockEnv.ManagerRoleARN, mockEnv.Region).Return(&session.Session{
+					Config: &aws.Config{
+						Region: aws.String("mockRegion"),
+					},
+				}, nil)
+				m.sess.EXPECT().DefaultWithRegion("mockRegion").Return(&session.Session{}, nil)
 				gomock.InOrder(
 					m.store.EXPECT().GetEnvironment(mockApp, mockEnvName).Return(mockEnv, nil),
 					m.spinner.EXPECT().Start(gomock.Any()),
@@ -480,6 +511,11 @@ func TestDeleteTaskOpts_Execute(t *testing.T) {
 			wantedErr: errors.New("stop running tasks in family hide-snacks: some error"),
 
 			setupMocks: func(m deleteTaskMocks) {
+				m.sess.EXPECT().FromRole(mockEnv.ManagerRoleARN, mockEnv.Region).Return(&session.Session{
+					Config: &aws.Config{
+						Region: aws.String("mockRegion"),
+					},
+				}, nil)
 				gomock.InOrder(
 					m.store.EXPECT().GetEnvironment(mockApp, mockEnvName).Return(mockEnv, nil),
 					m.spinner.EXPECT().Start(gomock.Any()),
@@ -496,6 +532,12 @@ func TestDeleteTaskOpts_Execute(t *testing.T) {
 			wantedErr: errors.New("some error"),
 
 			setupMocks: func(m deleteTaskMocks) {
+				m.sess.EXPECT().FromRole(mockEnv.ManagerRoleARN, mockEnv.Region).Return(&session.Session{
+					Config: &aws.Config{
+						Region: aws.String("mockRegion"),
+					},
+				}, nil)
+				m.sess.EXPECT().DefaultWithRegion("mockRegion").Return(&session.Session{}, nil)
 				gomock.InOrder(
 					m.store.EXPECT().GetEnvironment(mockApp, mockEnvName).Return(mockEnv, nil),
 					m.spinner.EXPECT().Start(gomock.Any()),
@@ -515,6 +557,7 @@ func TestDeleteTaskOpts_Execute(t *testing.T) {
 			wantedErr: errors.New("stop running tasks in family hide-snacks: some error"),
 
 			setupMocks: func(m deleteTaskMocks) {
+				m.sess.EXPECT().Default().Return(&session.Session{}, nil)
 				gomock.InOrder(
 					m.spinner.EXPECT().Start(gomock.Any()),
 					m.ecs.EXPECT().StopDefaultClusterTasks(mockTaskName).Return(mockError),
@@ -534,7 +577,8 @@ func TestDeleteTaskOpts_Execute(t *testing.T) {
 			mockECR := mocks.NewMockimageRemover(ctrl)
 			mockCFN := mocks.NewMocktaskStackManager(ctrl)
 			mockECS := mocks.NewMocktaskStopper(ctrl)
-			mockSession := sessions.NewProvider()
+			//mockSession := sessions.NewProvider()
+			mockSession := mocks.NewMocksessionProvider(ctrl)
 			mockSpinner := mocks.NewMockprogress(ctrl)
 
 			mockGetECR := func(_ *session.Session) imageRemover {
@@ -565,9 +609,9 @@ func TestDeleteTaskOpts_Execute(t *testing.T) {
 					name:           tc.inName,
 					defaultCluster: tc.inDefault,
 				},
-				store:   mockstore,
-				sess:    mockSession,
-				spinner: mockSpinner,
+				store:    mockstore,
+				provider: mockSession,
+				spinner:  mockSpinner,
 
 				newImageRemover: mockGetECR,
 				newStackManager: mockGetCFN,
