@@ -94,9 +94,12 @@ func (e *EnvStackConfig) Template() (string, error) {
 		DNSDelegationLambda:    dnsDelegation,
 		CustomDomainLambda:     customDomain,
 		ScriptBucketName:       bucket,
+		ArtifactBucketARN:      e.in.ArtifactBucketARN,
+		ArtifactBucketKeyARN:   e.in.ArtifactBucketKeyARN,
 		ImportVPC:              e.in.ImportVPCConfig,
 		VPCConfig:              vpcConf,
 		Version:                e.in.Version,
+		Telemetry:              e.in.Telemetry,
 		LatestVersion:          deploy.LatestEnvTemplateVersion,
 	}, template.WithFuncs(map[string]interface{}{
 		"inc": template.IncFunc,
