@@ -10,6 +10,7 @@ import (
 	"github.com/aws/aws-sdk-go/aws"
 	"github.com/aws/aws-sdk-go/service/cloudformation"
 	"github.com/aws/copilot-cli/internal/pkg/addon"
+	"github.com/aws/copilot-cli/internal/pkg/deploy"
 	"github.com/aws/copilot-cli/internal/pkg/manifest"
 	"github.com/aws/copilot-cli/internal/pkg/template"
 	"github.com/aws/copilot-cli/internal/pkg/template/override"
@@ -20,6 +21,8 @@ const (
 	lbWebSvcRulePriorityGeneratorPath = "custom-resources/alb-rule-priority-generator.js"
 	desiredCountGeneratorPath         = "custom-resources/desired-count-delegation.js"
 	envControllerPath                 = "custom-resources/env-controller.js"
+	nlbCertValidatorPath              = "custom-resources/nlb-cert-validator.js"
+	nlbCustomDomainPath               = "custom-resources/nlb-custom-domain.js"
 )
 
 // Parameter logical IDs for a load balanced web service.
@@ -31,6 +34,8 @@ const (
 	LBWebServiceTargetPortParamKey      = "TargetPort"
 	LBWebServiceStickinessParamKey      = "Stickiness"
 	LBWebServiceDNSDelegatedParamKey    = "DNSDelegated"
+	LBWebServiceNLBAliasesParamKey      = "NLBAliases"
+	LBWebServiceNLBPortParamKey         = "NLBPort"
 )
 
 type loadBalancedWebSvcReadParser interface {
@@ -52,6 +57,7 @@ type LoadBalancedWebService struct {
 	// should always be false; hence they could have different values at this time.
 	dnsDelegationEnabled   bool
 	publicSubnetCIDRBlocks []string
+	appInfo                deploy.AppInformation
 
 	parser loadBalancedWebSvcReadParser
 }
@@ -76,9 +82,10 @@ func WithNLB(cidrBlocks []string) func(s *LoadBalancedWebService) {
 }
 
 // WithDNSDelegation enables DNS delegation for a LoadBalancedWebService.
-func WithDNSDelegation() func(s *LoadBalancedWebService) {
+func WithDNSDelegation(app deploy.AppInformation) func(s *LoadBalancedWebService) {
 	return func(s *LoadBalancedWebService) {
 		s.dnsDelegationEnabled = true
+		s.appInfo = app
 	}
 }
 
@@ -172,7 +179,7 @@ func (s *LoadBalancedWebService) Template() (string, error) {
 
 	var aliases []string
 	if s.httpsEnabled {
-		if aliases, err = convertAlias(s.manifest.Alias); err != nil {
+		if aliases, err = convertAlias(s.manifest.RoutingRule.Alias); err != nil {
 			return "", err
 		}
 	}
@@ -183,41 +190,51 @@ func (s *LoadBalancedWebService) Template() (string, error) {
 	}
 
 	var allowedSourceIPs []string
-	for _, ipNet := range s.manifest.AllowedSourceIps {
+	for _, ipNet := range s.manifest.RoutingRule.AllowedSourceIps {
 		allowedSourceIPs = append(allowedSourceIPs, string(ipNet))
 	}
 
+	nlbConfig, err := s.convertNetworkLoadBalancer()
+	if err != nil {
+		return "", err
+	}
 	content, err := s.parser.ParseLoadBalancedWebService(template.WorkloadOpts{
-		Variables:                s.manifest.TaskConfig.Variables,
-		Secrets:                  s.manifest.TaskConfig.Secrets,
-		Aliases:                  aliases,
-		NestedStack:              addonsOutputs,
-		AddonsExtraParams:        addonsParams,
-		Sidecars:                 sidecars,
-		LogConfig:                convertLogging(s.manifest.Logging),
-		DockerLabels:             s.manifest.ImageConfig.Image.DockerLabels,
-		Autoscaling:              autoscaling,
-		CapacityProviders:        capacityProviders,
-		DesiredCountOnSpot:       desiredCountOnSpot,
-		ExecuteCommand:           convertExecuteCommand(&s.manifest.ExecuteCommand),
-		WorkloadType:             manifest.LoadBalancedWebServiceType,
-		HealthCheck:              convertContainerHealthCheck(s.manifest.ImageConfig.HealthCheck),
-		HTTPHealthCheck:          convertHTTPHealthCheck(&s.manifest.HealthCheck),
-		DeregistrationDelay:      deregistrationDelay,
-		AllowedSourceIps:         allowedSourceIPs,
-		RulePriorityLambda:       rulePriorityLambda.String(),
-		DesiredCountLambda:       desiredCountLambda.String(),
-		EnvControllerLambda:      envControllerLambda.String(),
-		Storage:                  convertStorageOpts(s.manifest.Name, s.manifest.Storage),
-		Network:                  convertNetworkConfig(s.manifest.Network),
-		EntryPoint:               entrypoint,
-		Command:                  command,
-		DependsOn:                convertDependsOn(s.manifest.ImageConfig.Image.DependsOn),
-		CredentialsParameter:     aws.StringValue(s.manifest.ImageConfig.Image.Credentials),
-		ServiceDiscoveryEndpoint: s.rc.ServiceDiscoveryEndpoint,
-		Publish:                  publishers,
-		Platform:                 convertPlatform(s.manifest.Platform),
-		HTTPVersion:              convertHTTPVersion(s.manifest.ProtocolVersion),
+		Variables:                      s.manifest.TaskConfig.Variables,
+		Secrets:                        s.manifest.TaskConfig.Secrets,
+		Aliases:                        aliases,
+		NestedStack:                    addonsOutputs,
+		AddonsExtraParams:              addonsParams,
+		Sidecars:                       sidecars,
+		LogConfig:                      convertLogging(s.manifest.Logging),
+		DockerLabels:                   s.manifest.ImageConfig.Image.DockerLabels,
+		Autoscaling:                    autoscaling,
+		CapacityProviders:              capacityProviders,
+		DesiredCountOnSpot:             desiredCountOnSpot,
+		ExecuteCommand:                 convertExecuteCommand(&s.manifest.ExecuteCommand),
+		WorkloadType:                   manifest.LoadBalancedWebServiceType,
+		HealthCheck:                    convertContainerHealthCheck(s.manifest.ImageConfig.HealthCheck),
+		HTTPHealthCheck:                convertHTTPHealthCheck(&s.manifest.RoutingRule.HealthCheck),
+		DeregistrationDelay:            deregistrationDelay,
+		AllowedSourceIps:               allowedSourceIPs,
+		RulePriorityLambda:             rulePriorityLambda.String(),
+		DesiredCountLambda:             desiredCountLambda.String(),
+		EnvControllerLambda:            envControllerLambda.String(),
+		Storage:                        convertStorageOpts(s.manifest.Name, s.manifest.Storage),
+		Network:                        convertNetworkConfig(s.manifest.Network),
+		EntryPoint:                     entrypoint,
+		Command:                        command,
+		DependsOn:                      convertDependsOn(s.manifest.ImageConfig.Image.DependsOn),
+		CredentialsParameter:           aws.StringValue(s.manifest.ImageConfig.Image.Credentials),
+		ServiceDiscoveryEndpoint:       s.rc.ServiceDiscoveryEndpoint,
+		Publish:                        publishers,
+		Platform:                       convertPlatform(s.manifest.Platform),
+		HTTPVersion:                    convertHTTPVersion(s.manifest.RoutingRule.ProtocolVersion),
+		NLB:                            nlbConfig.settings,
+		AppDNSName:                     nlbConfig.appDNSName,
+		AppDNSDelegationRole:           nlbConfig.appDNSDelegationRole,
+		NLBCertValidatorFunctionLambda: nlbConfig.certValidatorLambda,
+		NLBCustomDomainFunctionLambda:  nlbConfig.customDomainLambda,
+		ALBEnabled:                     !s.manifest.RoutingRule.Disabled(),
 	})
 	if err != nil {
 		return "", err
@@ -235,11 +252,11 @@ func (s *LoadBalancedWebService) httpLoadBalancerTarget() (targetContainer *stri
 	// Route load balancer traffic to main container by default.
 	targetContainer = aws.String(containerName)
 	targetPort = aws.String(containerPort)
-	if s.manifest.TargetContainer != nil {
-		targetContainer = s.manifest.TargetContainer
+	if s.manifest.RoutingRule.TargetContainer != nil {
+		targetContainer = s.manifest.RoutingRule.TargetContainer
 	}
-	if s.manifest.TargetContainerCamelCase != nil {
-		targetContainer = s.manifest.TargetContainerCamelCase
+	if s.manifest.RoutingRule.TargetContainerCamelCase != nil {
+		targetContainer = s.manifest.RoutingRule.TargetContainerCamelCase
 	}
 	if aws.StringValue(targetContainer) != containerName {
 		targetPort = s.manifest.Sidecars[aws.StringValue(targetContainer)].Port
@@ -247,6 +264,10 @@ func (s *LoadBalancedWebService) httpLoadBalancerTarget() (targetContainer *stri
 	return
 }
 
+func (s *LoadBalancedWebService) containerPort() string {
+	return strconv.FormatUint(uint64(aws.Uint16Value(s.manifest.ImageConfig.Port)), 10)
+}
+
 // Parameters returns the list of CloudFormation parameters used by the template.
 func (s *LoadBalancedWebService) Parameters() ([]*cloudformation.Parameter, error) {
 	wkldParams, err := s.ecsWkld.Parameters()
@@ -254,18 +275,10 @@ func (s *LoadBalancedWebService) Parameters() ([]*cloudformation.Parameter, erro
 		return nil, err
 	}
 	targetContainer, targetPort := s.httpLoadBalancerTarget()
-	return append(wkldParams, []*cloudformation.Parameter{
+	wkldParams = append(wkldParams, []*cloudformation.Parameter{
 		{
 			ParameterKey:   aws.String(LBWebServiceContainerPortParamKey),
-			ParameterValue: aws.String(strconv.FormatUint(uint64(aws.Uint16Value(s.manifest.ImageConfig.Port)), 10)),
-		},
-		{
-			ParameterKey:   aws.String(LBWebServiceRulePathParamKey),
-			ParameterValue: s.manifest.Path,
-		},
-		{
-			ParameterKey:   aws.String(LBWebServiceHTTPSParamKey),
-			ParameterValue: aws.String(strconv.FormatBool(s.httpsEnabled)),
+			ParameterValue: aws.String(s.containerPort()),
 		},
 		{
 			ParameterKey:   aws.String(LBWebServiceDNSDelegatedParamKey),
@@ -280,10 +293,44 @@ func (s *LoadBalancedWebService) Parameters() ([]*cloudformation.Parameter, erro
 			ParameterValue: targetPort,
 		},
 		{
-			ParameterKey:   aws.String(LBWebServiceStickinessParamKey),
-			ParameterValue: aws.String(strconv.FormatBool(aws.BoolValue(s.manifest.Stickiness))),
+			ParameterKey:   aws.String(WorkloadEnvFileARNParamKey),
+			ParameterValue: aws.String(s.rc.EnvFileARN),
 		},
-	}...), nil
+	}...)
+
+	if !s.manifest.RoutingRule.Disabled() {
+		wkldParams = append(wkldParams, []*cloudformation.Parameter{
+			{
+				ParameterKey:   aws.String(LBWebServiceRulePathParamKey),
+				ParameterValue: s.manifest.RoutingRule.Path,
+			},
+			{
+				ParameterKey:   aws.String(LBWebServiceHTTPSParamKey),
+				ParameterValue: aws.String(strconv.FormatBool(s.httpsEnabled)),
+			},
+			{
+				ParameterKey:   aws.String(LBWebServiceStickinessParamKey),
+				ParameterValue: aws.String(strconv.FormatBool(aws.BoolValue(s.manifest.RoutingRule.Stickiness))),
+			},
+		}...)
+	}
+	if !s.manifest.NLBConfig.IsEmpty() {
+		port, _, err := manifest.ParsePortMapping(s.manifest.NLBConfig.Port)
+		if err != nil {
+			return nil, err
+		}
+		wkldParams = append(wkldParams, []*cloudformation.Parameter{
+			{
+				ParameterKey:   aws.String(LBWebServiceNLBAliasesParamKey),
+				ParameterValue: aws.String(s.manifest.NLBConfig.Aliases.ToString()),
+			},
+			{
+				ParameterKey:   aws.String(LBWebServiceNLBPortParamKey),
+				ParameterValue: port,
+			},
+		}...)
+	}
+	return wkldParams, nil
 }
 
 func (s *LoadBalancedWebService) dnsDelegated() bool {
