@@ -1,4 +1,6 @@
+//go:build integration || localintegration
 // +build integration localintegration
+
 // Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 // SPDX-License-Identifier: Apache-2.0
 
@@ -36,12 +38,13 @@ func Test_Stack_Local_Integration(t *testing.T) {
 	require.NoError(t, err)
 	v, ok := mft.(*manifest.LoadBalancedWebService)
 	require.Equal(t, ok, true)
-	serializer, err := stack.NewHTTPSLoadBalancedWebService(v, envName, appName, stack.RuntimeConfig{
+
+	serializer, err := stack.NewLoadBalancedWebService(v, envName, appName, stack.RuntimeConfig{
 		Image: &stack.ECRImage{
 			RepoURL:  imageURL,
 			ImageTag: imageTag,
 		},
-	})
+	}, stack.WithHTTPS())
 	require.NoError(t, err)
 	tpl, err := serializer.Template()
 	require.NoError(t, err)
