@@ -6,9 +6,11 @@ package stack
 import (
 	"fmt"
 	"hash/crc32"
+	"strconv"
 	"strings"
 	"time"
 
+	"github.com/aws/copilot-cli/internal/pkg/aws/partitions"
 	"github.com/aws/copilot-cli/internal/pkg/deploy"
 	"github.com/aws/copilot-cli/internal/pkg/template/override"
 
@@ -32,6 +34,7 @@ const (
 	defaultIAM             = disabled
 	defaultReadOnly        = true
 	defaultWritePermission = false
+	defaultNLBProtocol     = manifest.TCP
 )
 
 // Supported capacityproviders for Fargate services
@@ -51,7 +54,7 @@ func convertSidecar(s map[string]*manifest.SidecarConfig) ([]*template.SidecarOp
 	}
 	var sidecars []*template.SidecarOpts
 	for name, config := range s {
-		port, protocol, err := parsePortMapping(config.Port)
+		port, protocol, err := manifest.ParsePortMapping(config.Port)
 		if err != nil {
 			return nil, err
 		}
@@ -113,22 +116,6 @@ func convertDependsOn(d manifest.DependsOn) map[string]string {
 	return dependsOn
 }
 
-// Valid sidecar portMapping example: 2000/udp, or 2000 (default to be tcp).
-func parsePortMapping(s *string) (port *string, protocol *string, err error) {
-	if s == nil {
-		return nil, nil, nil
-	}
-	portProtocol := strings.Split(*s, "/")
-	switch len(portProtocol) {
-	case 1:
-		return aws.String(portProtocol[0]), nil, nil
-	case 2:
-		return aws.String(portProtocol[0]), aws.String(portProtocol[1]), nil
-	default:
-		return nil, nil, fmt.Errorf("cannot parse port mapping from %s", *s)
-	}
-}
-
 func convertAdvancedCount(a manifest.AdvancedCount) (*template.AdvancedCount, error) {
 	if a.IsEmpty() {
 		return nil, nil
@@ -256,6 +243,107 @@ func convertHTTPHealthCheck(hc *manifest.HealthCheckArgsOrString) template.HTTPH
 	return opts
 }
 
+type networkLoadBalancerConfig struct {
+	settings *template.NetworkLoadBalancer
+
+	// If a domain is associated these values are not empty.
+	appDNSDelegationRole *string
+	appDNSName           *string
+	certValidatorLambda  string
+	customDomainLambda   string
+}
+
+func (s *LoadBalancedWebService) convertNetworkLoadBalancer() (networkLoadBalancerConfig, error) {
+	nlbConfig := s.manifest.NLBConfig
+	if nlbConfig.IsEmpty() {
+		return networkLoadBalancerConfig{}, nil
+	}
+
+	// Parse listener port and protocol.
+	port, protocol, err := manifest.ParsePortMapping(nlbConfig.Port)
+	if err != nil {
+		return networkLoadBalancerConfig{}, err
+	}
+	if protocol == nil {
+		protocol = aws.String(defaultNLBProtocol)
+	}
+
+	// Configure target container and port.
+	targetContainer := s.name
+	if nlbConfig.TargetContainer != nil {
+		targetContainer = aws.StringValue(nlbConfig.TargetContainer)
+	}
+
+	// By default, the target port is the same as listener port.
+	targetPort := aws.StringValue(port)
+	if targetContainer != s.name {
+		// If the target container is a sidecar container, the target port is the exposed sidecar port.
+		sideCarPort := s.manifest.Sidecars[targetContainer].Port // We validated that a sidecar container exposes a port if it is a target container.
+		port, _, err := manifest.ParsePortMapping(sideCarPort)
+		if err != nil {
+			return networkLoadBalancerConfig{}, err
+		}
+		targetPort = aws.StringValue(port)
+	}
+	// Finally, if a target port is explicitly specified, use that value.
+	if nlbConfig.TargetPort != nil {
+		targetPort = strconv.Itoa(aws.IntValue(nlbConfig.TargetPort))
+	}
+
+	aliases, err := convertAlias(nlbConfig.Aliases)
+	if err != nil {
+		return networkLoadBalancerConfig{}, fmt.Errorf(`convert "nlb.alias" to string slice: %w`, err)
+	}
+
+	hc := template.NLBHealthCheck{
+		HealthyThreshold:   nlbConfig.HealthCheck.HealthyThreshold,
+		UnhealthyThreshold: nlbConfig.HealthCheck.UnhealthyThreshold,
+	}
+	if nlbConfig.HealthCheck.Port != nil {
+		hc.Port = strconv.Itoa(aws.IntValue(nlbConfig.HealthCheck.Port))
+	}
+	if nlbConfig.HealthCheck.Timeout != nil {
+		hc.Timeout = aws.Int64(int64(nlbConfig.HealthCheck.Timeout.Seconds()))
+	}
+	if nlbConfig.HealthCheck.Interval != nil {
+		hc.Interval = aws.Int64(int64(nlbConfig.HealthCheck.Interval.Seconds()))
+	}
+	config := networkLoadBalancerConfig{
+		settings: &template.NetworkLoadBalancer{
+			PublicSubnetCIDRs: s.publicSubnetCIDRBlocks,
+			Listener: template.NetworkLoadBalancerListener{
+				Port:            aws.StringValue(port),
+				Protocol:        strings.ToUpper(aws.StringValue(protocol)),
+				TargetContainer: targetContainer,
+				TargetPort:      targetPort,
+				SSLPolicy:       nlbConfig.SSLPolicy,
+				Aliases:         aliases,
+				HealthCheck:     hc,
+				Stickiness:      nlbConfig.Stickiness,
+			},
+			MainContainerPort: s.containerPort(),
+		},
+	}
+
+	if s.dnsDelegationEnabled {
+		dnsDelegationRole, dnsName := convertAppInformation(s.appInfo)
+		config.appDNSName = dnsName
+		config.appDNSDelegationRole = dnsDelegationRole
+
+		nlbCertValidatorLambda, err := s.parser.Read(nlbCertValidatorPath)
+		if err != nil {
+			return networkLoadBalancerConfig{}, fmt.Errorf("read nlb certificate validator lambda: %w", err)
+		}
+		nlbCustomDomainLambda, err := s.parser.Read(nlbCustomDomainPath)
+		if err != nil {
+			return networkLoadBalancerConfig{}, fmt.Errorf("read nlb custom domain lambda: %w", err)
+		}
+		config.certValidatorLambda = nlbCertValidatorLambda.String()
+		config.customDomainLambda = nlbCustomDomainLambda.String()
+	}
+	return config, nil
+}
+
 func convertExecuteCommand(e *manifest.ExecuteCommand) *template.ExecuteCommandOpts {
 	if e.Config.IsEmpty() && !aws.BoolValue(e.Enable) {
 		return nil
@@ -539,9 +627,9 @@ func convertPublish(topics []manifest.Topic, accountID, region, app, env, svc st
 	if len(topics) == 0 {
 		return nil, nil
 	}
-	partition, ok := endpoints.PartitionForRegion(endpoints.DefaultPartitions(), region)
-	if !ok {
-		return nil, fmt.Errorf("find the partition for region %s", region)
+	partition, err := partitions.Region(region).Partition()
+	if err != nil {
+		return nil, err
 	}
 	var publishers template.PublishOpts
 	// convert the topics to template Topics
