@@ -1389,3 +1389,75 @@ func Test_convertSubscribe(t *testing.T) {
 		})
 	}
 }
+
+func Test_convertPlatform(t *testing.T) {
+	testCases := map[string]struct {
+		in  manifest.PlatformArgsOrString
+		out template.RuntimePlatformOpts
+	}{
+		"should return empty struct if user did not set a platform field in the manifest": {},
+		"should return windows server 2019 full and x86_64 when advanced config specifies full": {
+			in: manifest.PlatformArgsOrString{
+				PlatformArgs: manifest.PlatformArgs{
+					OSFamily: aws.String(manifest.OSWindowsServer2019Full),
+					Arch:     aws.String(manifest.ArchX86),
+				},
+			},
+			out: template.RuntimePlatformOpts{
+				OS:   template.OSWindowsServerFull,
+				Arch: template.ArchX86,
+			},
+		},
+		"should return windows server core and x86_64 when platform is 'windows/x86_64'": {
+			in: manifest.PlatformArgsOrString{
+				PlatformString: (*manifest.PlatformString)(aws.String("windows/amd64")),
+			},
+			out: template.RuntimePlatformOpts{
+				OS:   template.OSWindowsServerCore,
+				Arch: template.ArchX86,
+			},
+		},
+		"should return linux and x86_64 when platform is 'linux/amd64'": {
+			in: manifest.PlatformArgsOrString{
+				PlatformString: (*manifest.PlatformString)(aws.String("linux/amd64")),
+			},
+			out: template.RuntimePlatformOpts{
+				OS:   template.OSLinux,
+				Arch: template.ArchX86,
+			},
+		},
+		"should return linux and arm when platform is 'linux/arm'": {
+			in: manifest.PlatformArgsOrString{
+				PlatformString: (*manifest.PlatformString)(aws.String("linux/arm")),
+			},
+			out: template.RuntimePlatformOpts{
+				OS:   template.OSLinux,
+				Arch: template.ArchARM64,
+			},
+		},
+	}
+
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			require.Equal(t, tc.out, convertPlatform(tc.in))
+		})
+	}
+}
+
+func Test_convertHTTPVersion(t *testing.T) {
+	testCases := map[string]struct {
+		in     *string
+		wanted *string
+	}{
+		"should return nil if there is no user input": {},
+		"should return as uppercase on any user input": {
+			in:     aws.String("gRPC"),
+			wanted: aws.String("GRPC"),
+		},
+	}
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			require.Equal(t, tc.wanted, convertHTTPVersion(tc.in))
+		})
+	}
+}
