@@ -1,4 +1,6 @@
+//go:build integration
 // +build integration
+
 // Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 // SPDX-License-Identifier: Apache-2.0
 
@@ -25,7 +27,7 @@ func TestAutoscalingIntegration_Validate(t *testing.T) {
 	require.NoError(t, err)
 	v, ok := mft.(*manifest.LoadBalancedWebService)
 	require.Equal(t, ok, true)
-	serializer, err := stack.NewHTTPSLoadBalancedWebService(v, envName, appName, stack.RuntimeConfig{
+	serializer, err := stack.NewLoadBalancedWebService(v, envName, appName, stack.RuntimeConfig{
 		Image: &stack.ECRImage{
 			RepoURL:  imageURL,
 			ImageTag: imageTag,
