@@ -39,6 +39,7 @@ const (
 	WorkloadTaskMemoryParamKey   = "TaskMemory"
 	WorkloadTaskCountParamKey    = "TaskCount"
 	WorkloadLogRetentionParamKey = "LogRetention"
+	WorkloadEnvFileARNParamKey   = "EnvFileARN"
 )
 
 // Parameter logical IDs for workloads on App Runner.
@@ -63,6 +64,7 @@ const (
 type RuntimeConfig struct {
 	Image             *ECRImage         // Optional. Image location in an ECR repository.
 	AddonsTemplateURL string            // Optional. S3 object URL for the addons template.
+	EnvFileARN        string            // Optional. S3 object ARN for the env file.
 	AdditionalTags    map[string]string // AdditionalTags are labels applied to resources in the workload stack.
 
 	// The target environment metadata.
