@@ -11,19 +11,25 @@ import (
 	"strings"
 	"text/tabwriter"
 
+	"gopkg.in/yaml.v3"
+
+	"github.com/aws/copilot-cli/internal/pkg/aws/ec2"
 	"github.com/aws/copilot-cli/internal/pkg/aws/sessions"
 	"github.com/aws/copilot-cli/internal/pkg/config"
 	"github.com/aws/copilot-cli/internal/pkg/deploy"
 	cfnstack "github.com/aws/copilot-cli/internal/pkg/deploy/cloudformation/stack"
 	"github.com/aws/copilot-cli/internal/pkg/describe/stack"
 	"github.com/aws/copilot-cli/internal/pkg/term/color"
-	"gopkg.in/yaml.v3"
 )
 
 var (
 	fmtLegacySvcDiscoveryEndpoint = "%s.local"
 )
 
+type vpcSubnetLister interface {
+	ListVPCSubnets(vpcID string) (*ec2.VPCSubnets, error)
+}
+
 // EnvDescription contains the information about an environment.
 type EnvDescription struct {
 	Environment    *config.Environment `json:"environment"`
@@ -46,9 +52,10 @@ type EnvDescriber struct {
 	env             *config.Environment
 	enableResources bool
 
-	configStore ConfigStoreSvc
-	deployStore DeployedEnvServicesLister
-	cfn         stackDescriber
+	configStore  ConfigStoreSvc
+	deployStore  DeployedEnvServicesLister
+	cfn          stackDescriber
+	subnetLister vpcSubnetLister
 
 	// Cached values for reuse.
 	description *EnvDescription
@@ -78,9 +85,10 @@ func NewEnvDescriber(opt NewEnvDescriberConfig) (*EnvDescriber, error) {
 		env:             env,
 		enableResources: opt.EnableResources,
 
-		configStore: opt.ConfigStore,
-		deployStore: opt.DeployStore,
-		cfn:         stack.NewStackDescriber(cfnstack.NameForEnv(opt.App, opt.Env), sess),
+		configStore:  opt.ConfigStore,
+		deployStore:  opt.DeployStore,
+		cfn:          stack.NewStackDescriber(cfnstack.NameForEnv(opt.App, opt.Env), sess),
+		subnetLister: ec2.New(sess),
 	}, nil
 }
 
@@ -178,6 +186,24 @@ func (d *EnvDescriber) ServiceDiscoveryEndpoint() (string, error) {
 	return fmt.Sprintf(fmtLegacySvcDiscoveryEndpoint, d.app), nil
 }
 
+// PublicCIDRBlocks returns the public CIDR blocks of the public subnets in the environment VPC.
+func (d *EnvDescriber) PublicCIDRBlocks() ([]string, error) {
+	_, envVPC, err := d.loadStackInfo()
+	if err != nil {
+		return nil, err
+	}
+	vpcID := envVPC.ID
+	subnets, err := d.subnetLister.ListVPCSubnets(vpcID)
+	if err != nil {
+		return nil, fmt.Errorf("list subnets of vpc %s in environment %s: %w", vpcID, d.env.Name, err)
+	}
+	var cidrBlocks []string
+	for _, subnet := range subnets.Public {
+		cidrBlocks = append(cidrBlocks, subnet.CIDRBlock)
+	}
+	return cidrBlocks, nil
+}
+
 func (d *EnvDescriber) loadStackInfo() (map[string]string, EnvironmentVPC, error) {
 	var environmentVPC EnvironmentVPC
 
@@ -262,7 +288,6 @@ func (e *EnvDescription) HumanString() string {
 		sort.Strings(keys)
 		for _, key := range keys {
 			fmt.Fprintf(writer, "  %s\t%s\n", key, e.Tags[key])
-			writer.Flush()
 		}
 	}
 	writer.Flush()
