@@ -8,6 +8,7 @@ import (
 	"fmt"
 	"testing"
 
+	"github.com/aws/copilot-cli/internal/pkg/aws/ec2"
 	"github.com/aws/copilot-cli/internal/pkg/config"
 	"github.com/aws/copilot-cli/internal/pkg/deploy"
 	cfstack "github.com/aws/copilot-cli/internal/pkg/deploy/cloudformation/stack"
@@ -21,6 +22,7 @@ type envDescriberMocks struct {
 	configStoreSvc *mocks.MockConfigStoreSvc
 	deployStoreSvc *mocks.MockDeployedEnvServicesLister
 	stackDescriber *mocks.MockstackDescriber
+	subnetLister   *mocks.MockvpcSubnetLister
 }
 
 var wantedResources = []*stack.Resource{
@@ -365,6 +367,95 @@ func TestEnvDescriber_ServiceDiscoveryEndpoint(t *testing.T) {
 	}
 }
 
+func TestEnvDescriber_PublicCIDRBlocks(t *testing.T) {
+	testCases := map[string]struct {
+		setupMocks func(mocks envDescriberMocks)
+
+		wantedCIDRBlocks []string
+		wantedErr        error
+	}{
+		"fail to describe the environment to get the VPC ID": {
+			setupMocks: func(m envDescriberMocks) {
+				gomock.InOrder(
+					m.stackDescriber.EXPECT().Describe().Return(stack.StackDescription{}, errors.New("some error")),
+				)
+			},
+			wantedErr: errors.New("retrieve environment stack: some error"),
+		},
+		"fail to get the subnets of the environment VPC": {
+			setupMocks: func(m envDescriberMocks) {
+				gomock.InOrder(
+					m.stackDescriber.EXPECT().Describe().Return(stack.StackDescription{
+						Outputs: map[string]string{
+							"VpcId": "mockVPCID",
+						},
+					}, nil),
+					m.subnetLister.EXPECT().ListVPCSubnets("mockVPCID").Return(nil, errors.New("some error")),
+				)
+			},
+			wantedErr: errors.New("list subnets of vpc mockVPCID in environment mockEnv: some error"),
+		},
+		"return the correct CIDR blocks": {
+			setupMocks: func(m envDescriberMocks) {
+				gomock.InOrder(
+					m.stackDescriber.EXPECT().Describe().Return(stack.StackDescription{
+						Outputs: map[string]string{
+							"VpcId": "mockVPCID",
+						},
+					}, nil),
+					m.subnetLister.EXPECT().ListVPCSubnets("mockVPCID").Return(&ec2.VPCSubnets{
+						Public: []ec2.Subnet{
+							{
+								CIDRBlock: "mockCIDRBlock1",
+							},
+							{
+								CIDRBlock: "mockCIDRBlock2",
+							},
+						},
+					}, nil),
+				)
+			},
+			wantedCIDRBlocks: []string{"mockCIDRBlock1", "mockCIDRBlock2"},
+		},
+	}
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			// GIVEN
+			ctrl := gomock.NewController(t)
+			defer ctrl.Finish()
+			m := envDescriberMocks{
+				configStoreSvc: mocks.NewMockConfigStoreSvc(ctrl),
+				deployStoreSvc: mocks.NewMockDeployedEnvServicesLister(ctrl),
+				stackDescriber: mocks.NewMockstackDescriber(ctrl),
+				subnetLister:   mocks.NewMockvpcSubnetLister(ctrl),
+			}
+
+			tc.setupMocks(m)
+			d := &EnvDescriber{
+				env: &config.Environment{
+					Name: "mockEnv",
+				},
+
+				configStore:  m.configStoreSvc,
+				deployStore:  m.deployStoreSvc,
+				cfn:          m.stackDescriber,
+				subnetLister: m.subnetLister,
+			}
+
+			// WHEN
+			actual, err := d.PublicCIDRBlocks()
+
+			// THEN
+			if tc.wantedErr != nil {
+				require.EqualError(t, err, tc.wantedErr.Error())
+			} else {
+				require.NoError(t, err)
+				require.Equal(t, tc.wantedCIDRBlocks, actual)
+			}
+		})
+	}
+}
+
 func TestEnvDescription_JSONString(t *testing.T) {
 	testApp := &config.Application{
 		Name: "testApp",
@@ -452,25 +543,25 @@ func TestEnvDescription_HumanString(t *testing.T) {
 
 	wantedContent := `About
 
-  Name              testEnv
-  Production        false
-  Region            us-west-2
-  Account ID        123456789012
+  Name        testEnv
+  Production  false
+  Region      us-west-2
+  Account ID  123456789012
 
 Services
 
-  Name              Type
-  ----              ----
-  testSvc1          load-balanced
-  testSvc2          load-balanced
-  testSvc3          load-balanced
+  Name      Type
+  ----      ----
+  testSvc1  load-balanced
+  testSvc2  load-balanced
+  testSvc3  load-balanced
 
 Tags
 
-  Key               Value
-  ---               -----
-  key1              value1
-  key2              value2
+  Key     Value
+  ---     -----
+  key1    value1
+  key2    value2
 
 Resources
 
