@@ -14,6 +14,8 @@ import (
 	"strings"
 	"text/tabwriter"
 
+	"github.com/aws/copilot-cli/internal/pkg/docker/dockerengine"
+
 	"github.com/aws/aws-sdk-go/aws/arn"
 	"github.com/aws/aws-sdk-go/aws/awserr"
 	cfnstack "github.com/aws/copilot-cli/internal/pkg/deploy/cloudformation/stack"
@@ -25,6 +27,11 @@ import (
 const (
 	envOutputPublicLoadBalancerDNSName = "PublicLoadBalancerDNSName"
 	envOutputSubdomain                 = "EnvironmentSubdomain"
+	svcParamHTTPSEnabled               = "HTTPSEnabled"
+
+	svcStackResourceALBTargetGroupLogicalID = "TargetGroup"
+	svcStackResourceNLBTargetGroupLogicalID = "NLBTargetGroup"
+	svcOutputPublicNLBDNSName               = "PublicNetworkLoadBalancerDNSName"
 )
 
 type envDescriber interface {
@@ -35,8 +42,14 @@ type envDescriber interface {
 
 // LBWebServiceDescriber retrieves information about a load balanced web service.
 type LBWebServiceDescriber struct {
-	*ecsServiceDescriber
-	envDescriber map[string]envDescriber
+	app             string
+	svc             string
+	enableResources bool
+
+	store                DeployedEnvServicesLister
+	initClients          func(string) error
+	ecsServiceDescribers map[string]ecsDescriber
+	envDescriber         map[string]envDescriber
 
 	// cache only last svc paramerters
 	svcParams map[string]string
@@ -45,20 +58,18 @@ type LBWebServiceDescriber struct {
 // NewLBWebServiceDescriber instantiates a load balanced service describer.
 func NewLBWebServiceDescriber(opt NewServiceConfig) (*LBWebServiceDescriber, error) {
 	describer := &LBWebServiceDescriber{
-		ecsServiceDescriber: &ecsServiceDescriber{
-			app:               opt.App,
-			svc:               opt.Svc,
-			enableResources:   opt.EnableResources,
-			store:             opt.DeployStore,
-			svcStackDescriber: make(map[string]ecsStackDescriber),
-		},
-		envDescriber: make(map[string]envDescriber),
+		app:                  opt.App,
+		svc:                  opt.Svc,
+		enableResources:      opt.EnableResources,
+		store:                opt.DeployStore,
+		ecsServiceDescribers: make(map[string]ecsDescriber),
+		envDescriber:         make(map[string]envDescriber),
 	}
-	describer.initDescribers = func(env string) error {
-		if _, ok := describer.svcStackDescriber[env]; ok {
+	describer.initClients = func(env string) error {
+		if _, ok := describer.ecsServiceDescribers[env]; ok {
 			return nil
 		}
-		svcDescr, err := NewServiceDescriber(NewServiceConfig{
+		svcDescr, err := NewECSServiceDescriber(NewServiceConfig{
 			App:         opt.App,
 			Env:         env,
 			Svc:         opt.Svc,
@@ -67,7 +78,7 @@ func NewLBWebServiceDescriber(opt NewServiceConfig) (*LBWebServiceDescriber, err
 		if err != nil {
 			return err
 		}
-		describer.svcStackDescriber[env] = svcDescr
+		describer.ecsServiceDescribers[env] = svcDescr
 		envDescr, err := NewEnvDescriber(NewEnvDescriberConfig{
 			App:         opt.App,
 			Env:         env,
@@ -95,7 +106,7 @@ func (d *LBWebServiceDescriber) Describe() (HumanJSONStringer, error) {
 	var envVars []*containerEnvVar
 	var secrets []*secret
 	for _, env := range environments {
-		err := d.initDescribers(env)
+		err := d.initClients(env)
 		if err != nil {
 			return nil, err
 		}
@@ -107,12 +118,21 @@ func (d *LBWebServiceDescriber) Describe() (HumanJSONStringer, error) {
 			Environment: env,
 			URL:         webServiceURI,
 		})
+		containerPlatform, err := d.ecsServiceDescribers[env].Platform()
+		if err != nil {
+			return nil, fmt.Errorf("retrieve platform: %w", err)
+		}
+		webSvcEnvVars, err := d.ecsServiceDescribers[env].EnvVars()
+		if err != nil {
+			return nil, fmt.Errorf("retrieve environment variables: %w", err)
+		}
 		configs = append(configs, &ECSServiceConfig{
 			ServiceConfig: &ServiceConfig{
 				Environment: env,
 				Port:        d.svcParams[cfnstack.LBWebServiceContainerPortParamKey],
 				CPU:         d.svcParams[cfnstack.WorkloadTaskCPUParamKey],
 				Memory:      d.svcParams[cfnstack.WorkloadTaskMemoryParamKey],
+				Platform:    dockerengine.PlatformString(containerPlatform.OperatingSystem, containerPlatform.Architecture),
 			},
 			Tasks: d.svcParams[cfnstack.WorkloadTaskCountParamKey],
 		})
@@ -125,12 +145,8 @@ func (d *LBWebServiceDescriber) Describe() (HumanJSONStringer, error) {
 			Port:     d.svcParams[cfnstack.LBWebServiceContainerPortParamKey],
 			Endpoint: endpoint,
 		}, env)
-		webSvcEnvVars, err := d.svcStackDescriber[env].EnvVars()
-		if err != nil {
-			return nil, fmt.Errorf("retrieve environment variables: %w", err)
-		}
 		envVars = append(envVars, flattenContainerEnvVars(env, webSvcEnvVars)...)
-		webSvcSecrets, err := d.svcStackDescriber[env].Secrets()
+		webSvcSecrets, err := d.ecsServiceDescribers[env].Secrets()
 		if err != nil {
 			return nil, fmt.Errorf("retrieve secrets: %w", err)
 		}
@@ -139,11 +155,11 @@ func (d *LBWebServiceDescriber) Describe() (HumanJSONStringer, error) {
 	resources := make(map[string][]*stack.Resource)
 	if d.enableResources {
 		for _, env := range environments {
-			err := d.initDescribers(env)
+			err := d.initClients(env)
 			if err != nil {
 				return nil, err
 			}
-			stackResources, err := d.svcStackDescriber[env].ServiceStackResources()
+			stackResources, err := d.ecsServiceDescribers[env].ServiceStackResources()
 			if err != nil {
 				return nil, fmt.Errorf("retrieve service resources: %w", err)
 			}
