@@ -19,9 +19,11 @@ const (
 	scheduledJobManifestPath = "workloads/jobs/scheduled-job/manifest.yml"
 )
 
-// JobTypes holds the valid job "architectures"
-var JobTypes = []string{
-	ScheduledJobType,
+// JobTypes returns the list of supported job manifest types.
+func JobTypes() []string {
+	return []string{
+		ScheduledJobType,
+	}
 }
 
 // ScheduledJob holds the configuration to build a container image that is run
@@ -136,6 +138,11 @@ func (j *ScheduledJob) BuildRequired() (bool, error) {
 	return requiresBuild(j.ImageConfig.Image)
 }
 
+// EnvFile returns the location of the env file against the ws root directory.
+func (j *ScheduledJob) EnvFile() string {
+	return aws.StringValue(j.TaskConfig.EnvFile)
+}
+
 // JobDockerfileBuildRequired returns if the job container image should be built from local Dockerfile.
 func JobDockerfileBuildRequired(job interface{}) (bool, error) {
 	return dockerfileBuildRequired("job", job)
