@@ -27,12 +27,14 @@ const (
 	WorkerServiceType = "Worker Service"
 )
 
-// ServiceTypes are the supported service manifest types.
-var ServiceTypes = []string{
-	RequestDrivenWebServiceType,
-	LoadBalancedWebServiceType,
-	BackendServiceType,
-	WorkerServiceType,
+// ServiceTypes returns the list of supported service manifest types.
+func ServiceTypes() []string {
+	return []string{
+		RequestDrivenWebServiceType,
+		LoadBalancedWebServiceType,
+		BackendServiceType,
+		WorkerServiceType,
+	}
 }
 
 // Range contains either a Range or a range configuration for Autoscaling ranges.
@@ -269,7 +271,7 @@ func ServiceDockerfileBuildRequired(svc interface{}) (bool, error) {
 }
 
 func IsTypeAService(t string) bool {
-	for _, serviceType := range ServiceTypes {
+	for _, serviceType := range ServiceTypes() {
 		if t == serviceType {
 			return true
 		}
@@ -292,7 +294,7 @@ type HTTPHealthCheckArgs struct {
 }
 
 func (h *HTTPHealthCheckArgs) isEmpty() bool {
-	return h.Path == nil && h.HealthyThreshold == nil && h.UnhealthyThreshold == nil &&
+	return h.Path == nil && h.SuccessCodes == nil && h.HealthyThreshold == nil && h.UnhealthyThreshold == nil &&
 		h.Interval == nil && h.Timeout == nil && h.GracePeriod == nil
 }
 
@@ -343,3 +345,35 @@ func (hc *HealthCheckArgsOrString) Path() *string {
 	}
 	return hc.HealthCheckArgs.Path
 }
+
+// NLBHealthCheckArgs holds the configuration to determine if the network load balanced web service is healthy.
+// These options are specifiable under the "healthcheck" field.
+// See https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-elasticloadbalancingv2-targetgroup.html.
+type NLBHealthCheckArgs struct {
+	Port               *int           `yaml:"port"`
+	HealthyThreshold   *int64         `yaml:"healthy_threshold"`
+	UnhealthyThreshold *int64         `yaml:"unhealthy_threshold"`
+	Timeout            *time.Duration `yaml:"timeout"`
+	Interval           *time.Duration `yaml:"interval"`
+}
+
+func (h *NLBHealthCheckArgs) isEmpty() bool {
+	return h.Port == nil && h.HealthyThreshold == nil && h.UnhealthyThreshold == nil && h.Timeout == nil && h.Interval == nil
+}
+
+// ParsePortMapping parses port-protocol string into individual port and protocol strings.
+// Valid examples: 2000/udp, or 2000.
+func ParsePortMapping(s *string) (port *string, protocol *string, err error) {
+	if s == nil {
+		return nil, nil, nil
+	}
+	portProtocol := strings.Split(*s, "/")
+	switch len(portProtocol) {
+	case 1:
+		return aws.String(portProtocol[0]), nil, nil
+	case 2:
+		return aws.String(portProtocol[0]), aws.String(portProtocol[1]), nil
+	default:
+		return nil, nil, fmt.Errorf("cannot parse port mapping from %s", *s)
+	}
+}
