@@ -27,6 +27,7 @@ var defaultTransformers = []mergo.Transformers{
 	efsConfigOrBoolTransformer{},
 	efsVolumeConfigurationTransformer{},
 	sqsQueueOrBoolTransformer{},
+	routingRuleConfigOrBoolTransformer{},
 }
 
 // See a complete list of `reflect.Kind` here: https://pkg.go.dev/reflect#Kind.
@@ -326,6 +327,31 @@ func (q sqsQueueOrBoolTransformer) Transformer(typ reflect.Type) func(dst, src r
 	}
 }
 
+type routingRuleConfigOrBoolTransformer struct{}
+
+// Transformer returns custom merge logic for RoutingRuleConfigOrBool's fields.
+func (t routingRuleConfigOrBoolTransformer) Transformer(typ reflect.Type) func(dst, src reflect.Value) error {
+	if typ != reflect.TypeOf(RoutingRuleConfigOrBool{}) {
+		return nil
+	}
+	return func(dst, src reflect.Value) error {
+		dstStruct, srcStruct := dst.Interface().(RoutingRuleConfigOrBool), src.Interface().(RoutingRuleConfigOrBool)
+
+		if !srcStruct.RoutingRuleConfiguration.isEmpty() {
+			dstStruct.Enabled = nil
+		}
+
+		if srcStruct.Enabled != nil {
+			dstStruct.RoutingRuleConfiguration = RoutingRuleConfiguration{}
+		}
+
+		if dst.CanSet() { // For extra safety to prevent panicking.
+			dst.Set(reflect.ValueOf(dstStruct))
+		}
+		return nil
+	}
+}
+
 type basicTransformer struct{}
 
 // Transformer returns custom merge logic for volume's fields.
