@@ -7,6 +7,7 @@ import (
 	"errors"
 	"fmt"
 	"net"
+	"path/filepath"
 	"regexp"
 	"sort"
 	"strconv"
@@ -27,8 +28,17 @@ const (
 	// Min and Max values for task ephemeral storage in GiB.
 	ephemeralMinValueGiB = 20
 	ephemeralMaxValueGiB = 200
+
+	envFileExt = ".env"
 )
 
+const (
+	TCP = "TCP"
+	tls = "TLS"
+)
+
+var validProtocols = []string{TCP, tls}
+
 var (
 	intRangeBandRegexp  = regexp.MustCompile(`^(\d+)-(\d+)$`)
 	volumesPathRegexp   = regexp.MustCompile(`^[a-zA-Z0-9\-\.\_/]+$`)
@@ -82,6 +92,14 @@ func (l LoadBalancedWebService) Validate() error {
 // Validate returns nil if LoadBalancedWebServiceConfig is configured correctly.
 func (l LoadBalancedWebServiceConfig) Validate() error {
 	var err error
+	if l.RoutingRule.Disabled() && l.NLBConfig.IsEmpty() {
+		return &errAtLeastOneFieldMustBeSpecified{
+			missingFields: []string{"http", "nlb"},
+		}
+	}
+	if l.RoutingRule.Disabled() && (l.Count.AdvancedCount.Requests != nil || l.Count.AdvancedCount.ResponseTime != nil) {
+		return errors.New(`scaling based on "nlb" requests or response time is not supported`)
+	}
 	if err = l.ImageConfig.Validate(); err != nil {
 		return fmt.Errorf(`validate "image": %w`, err)
 	}
@@ -529,8 +547,21 @@ func (CommandOverride) Validate() error {
 	return nil
 }
 
-// Validate returns nil if RoutingRule is configured correctly.
-func (r RoutingRule) Validate() error {
+// Validate returns nil if RoutingRuleConfigOrBool is configured correctly.
+func (r RoutingRuleConfigOrBool) Validate() error {
+	if aws.BoolValue(r.Enabled) {
+		return &errFieldMustBeSpecified{
+			missingField: "path",
+		}
+	}
+	if r.Enabled != nil {
+		return nil
+	}
+	return r.RoutingRuleConfiguration.Validate()
+}
+
+// Validate returns nil if RoutingRuleConfiguration is configured correctly.
+func (r RoutingRuleConfiguration) Validate() error {
 	var err error
 	if err = r.HealthCheck.Validate(); err != nil {
 		return fmt.Errorf(`validate "healthcheck": %w`, err)
@@ -554,6 +585,11 @@ func (r RoutingRule) Validate() error {
 			return fmt.Errorf(`"version" field value '%s' must be one of %s`, *r.ProtocolVersion, english.WordSeries(httpProtocolVersions, "or"))
 		}
 	}
+	if r.Path == nil {
+		return &errFieldMustBeSpecified{
+			missingField: "path",
+		}
+	}
 	return nil
 }
 
@@ -573,6 +609,14 @@ func (h HTTPHealthCheckArgs) Validate() error {
 	return nil
 }
 
+// Validate returns nil if NLBHealthCheckArgs is configured correctly.
+func (h NLBHealthCheckArgs) Validate() error {
+	if h.isEmpty() {
+		return nil
+	}
+	return nil
+}
+
 // Validate returns nil if Alias is configured correctly.
 func (Alias) Validate() error {
 	return nil
@@ -596,9 +640,37 @@ func (c NetworkLoadBalancerConfiguration) Validate() error {
 			missingField: "port",
 		}
 	}
+	if err := validateNLBPort(c.Port); err != nil {
+		return fmt.Errorf(`validate "port": %w`, err)
+	}
 	if err := c.HealthCheck.Validate(); err != nil {
 		return fmt.Errorf(`validate "healthcheck": %w`, err)
 	}
+	if err := c.Aliases.Validate(); err != nil {
+		return fmt.Errorf(`validate "alias": %w`, err)
+	}
+	return nil
+}
+
+func validateNLBPort(port *string) error {
+	_, protocol, err := ParsePortMapping(port)
+	if err != nil {
+		return err
+	}
+	if protocol == nil {
+		return nil
+	}
+	protocolVal := aws.StringValue(protocol)
+	var isValidProtocol bool
+	for _, valid := range validProtocols {
+		if strings.EqualFold(protocolVal, valid) {
+			isValidProtocol = true
+			break
+		}
+	}
+	if !isValidProtocol {
+		return fmt.Errorf(`invalid protocol %s; valid protocols include %s`, protocolVal, english.WordSeries(validProtocols, "and"))
+	}
 	return nil
 }
 
@@ -617,6 +689,12 @@ func (t TaskConfig) Validate() error {
 	if err = t.Storage.Validate(); err != nil {
 		return fmt.Errorf(`validate "storage": %w`, err)
 	}
+	if t.EnvFile != nil {
+		envFile := aws.StringValue(t.EnvFile)
+		if filepath.Ext(envFile) != envFileExt {
+			return fmt.Errorf("environment file %s must have a %s file extension", envFile, envFileExt)
+		}
+	}
 	return nil
 }
 
@@ -661,12 +739,12 @@ func (p PlatformString) Validate() error {
 	if len(args) != 2 {
 		return fmt.Errorf("platform '%s' must be in the format [OS]/[Arch]", string(p))
 	}
-	for _, validPlatform := range ValidShortPlatforms {
+	for _, validPlatform := range validShortPlatforms {
 		if strings.ToLower(string(p)) == validPlatform {
 			return nil
 		}
 	}
-	return fmt.Errorf("platform '%s' is invalid; %s: %s", p, english.PluralWord(len(ValidShortPlatforms), "the valid platform is", "valid platforms are"), english.WordSeries(ValidShortPlatforms, "and"))
+	return fmt.Errorf("platform '%s' is invalid; %s: %s", p, english.PluralWord(len(validShortPlatforms), "the valid platform is", "valid platforms are"), english.WordSeries(validShortPlatforms, "and"))
 }
 
 // Validate returns nil if Count is configured correctly.
