@@ -47,9 +47,11 @@ func TestLoadBalancedWebService_Validate(t *testing.T) {
 			lbConfig: LoadBalancedWebService{
 				LoadBalancedWebServiceConfig: LoadBalancedWebServiceConfig{
 					ImageConfig: testImageConfig,
-					RoutingRule: RoutingRule{
-						TargetContainer:          aws.String("mockTargetContainer"),
-						TargetContainerCamelCase: aws.String("mockTargetContainer"),
+					RoutingRule: RoutingRuleConfigOrBool{
+						RoutingRuleConfiguration: RoutingRuleConfiguration{
+							TargetContainer:          aws.String("mockTargetContainer"),
+							TargetContainerCamelCase: aws.String("mockTargetContainer"),
+						},
 					},
 				},
 			},
@@ -66,6 +68,11 @@ func TestLoadBalancedWebService_Validate(t *testing.T) {
 							},
 						},
 					},
+					RoutingRule: RoutingRuleConfigOrBool{
+						RoutingRuleConfiguration: RoutingRuleConfiguration{
+							Path: stringP("/"),
+						},
+					},
 				},
 			},
 			wantedErrorMsgPrefix: `validate "sidecars[foo]": `,
@@ -79,6 +86,11 @@ func TestLoadBalancedWebService_Validate(t *testing.T) {
 							Placement: (*Placement)(aws.String("")),
 						},
 					},
+					RoutingRule: RoutingRuleConfigOrBool{
+						RoutingRuleConfiguration: RoutingRuleConfiguration{
+							Path: stringP("/"),
+						},
+					},
 				},
 			},
 			wantedErrorMsgPrefix: `validate "network": `,
@@ -92,6 +104,11 @@ func TestLoadBalancedWebService_Validate(t *testing.T) {
 							{},
 						},
 					},
+					RoutingRule: RoutingRuleConfigOrBool{
+						RoutingRuleConfiguration: RoutingRuleConfiguration{
+							Path: stringP("/"),
+						},
+					},
 				},
 			},
 			wantedErrorMsgPrefix: `validate "publish": `,
@@ -105,6 +122,11 @@ func TestLoadBalancedWebService_Validate(t *testing.T) {
 							Path: "Family",
 						},
 					},
+					RoutingRule: RoutingRuleConfigOrBool{
+						RoutingRuleConfiguration: RoutingRuleConfiguration{
+							Path: stringP("/"),
+						},
+					},
 				},
 			},
 			wantedErrorMsgPrefix: `validate "taskdef_overrides[0]": `,
@@ -113,6 +135,11 @@ func TestLoadBalancedWebService_Validate(t *testing.T) {
 			lbConfig: LoadBalancedWebService{
 				LoadBalancedWebServiceConfig: LoadBalancedWebServiceConfig{
 					ImageConfig: testImageConfig,
+					RoutingRule: RoutingRuleConfigOrBool{
+						RoutingRuleConfiguration: RoutingRuleConfiguration{
+							Path: stringP("/"),
+						},
+					},
 				},
 			},
 			wantedError: fmt.Errorf(`"name" must be specified`),
@@ -122,8 +149,11 @@ func TestLoadBalancedWebService_Validate(t *testing.T) {
 				Workload: Workload{Name: aws.String("mockName")},
 				LoadBalancedWebServiceConfig: LoadBalancedWebServiceConfig{
 					ImageConfig: testImageConfig,
-					RoutingRule: RoutingRule{
-						TargetContainer: aws.String("foo"),
+					RoutingRule: RoutingRuleConfigOrBool{
+						RoutingRuleConfiguration: RoutingRuleConfiguration{
+							Path:            stringP("/"),
+							TargetContainer: aws.String("foo"),
+						},
 					},
 				},
 			},
@@ -134,8 +164,11 @@ func TestLoadBalancedWebService_Validate(t *testing.T) {
 				Workload: Workload{Name: aws.String("mockName")},
 				LoadBalancedWebServiceConfig: LoadBalancedWebServiceConfig{
 					ImageConfig: testImageConfig,
-					RoutingRule: RoutingRule{
-						TargetContainer: aws.String("mockName"),
+					RoutingRule: RoutingRuleConfigOrBool{
+						RoutingRuleConfiguration: RoutingRuleConfiguration{
+							Path:            stringP("/"),
+							TargetContainer: aws.String("mockName"),
+						},
 					},
 					NLBConfig: NetworkLoadBalancerConfiguration{
 						Port:            aws.String("443"),
@@ -160,6 +193,11 @@ func TestLoadBalancedWebService_Validate(t *testing.T) {
 							Essential: aws.Bool(false),
 						},
 					},
+					RoutingRule: RoutingRuleConfigOrBool{
+						RoutingRuleConfiguration: RoutingRuleConfiguration{
+							Path: stringP("/"),
+						},
+					},
 				},
 			},
 			wantedErrorMsgPrefix: `validate container dependencies: `,
@@ -173,6 +211,11 @@ func TestLoadBalancedWebService_Validate(t *testing.T) {
 						Platform:       PlatformArgsOrString{PlatformString: (*PlatformString)(aws.String("windows/amd64"))},
 						ExecuteCommand: ExecuteCommand{Enable: aws.Bool(true)},
 					},
+					RoutingRule: RoutingRuleConfigOrBool{
+						RoutingRuleConfiguration: RoutingRuleConfiguration{
+							Path: stringP("/"),
+						},
+					},
 				},
 			},
 			wantedErrorMsgPrefix: `validate Windows: `,
@@ -193,10 +236,75 @@ func TestLoadBalancedWebService_Validate(t *testing.T) {
 							},
 						},
 					},
+					RoutingRule: RoutingRuleConfigOrBool{
+						RoutingRuleConfiguration: RoutingRuleConfiguration{
+							Path: stringP("/"),
+						},
+					},
 				},
 			},
 			wantedErrorMsgPrefix: `validate ARM: `,
 		},
+		"error if neither of http or nlb is enabled": {
+			lbConfig: LoadBalancedWebService{
+				Workload: Workload{
+					Name: aws.String("mockName"),
+				},
+				LoadBalancedWebServiceConfig: LoadBalancedWebServiceConfig{
+					ImageConfig: testImageConfig,
+					RoutingRule: RoutingRuleConfigOrBool{
+						Enabled: aws.Bool(false),
+					},
+				},
+			},
+			wantedError: errors.New(`must specify at least one of "http" or "nlb"`),
+		},
+		"error if scaling based on nlb requests": {
+			lbConfig: LoadBalancedWebService{
+				Workload: Workload{
+					Name: aws.String("mockName"),
+				},
+				LoadBalancedWebServiceConfig: LoadBalancedWebServiceConfig{
+					TaskConfig: TaskConfig{
+						Count: Count{
+							AdvancedCount: AdvancedCount{
+								Requests: aws.Int(3),
+							},
+						},
+					},
+					RoutingRule: RoutingRuleConfigOrBool{
+						Enabled: aws.Bool(false),
+					},
+					NLBConfig: NetworkLoadBalancerConfiguration{
+						Port: aws.String("80"),
+					},
+				},
+			},
+			wantedError: errors.New(`scaling based on "nlb" requests or response time is not supported`),
+		},
+		"error if scaling based on nlb response time": {
+			lbConfig: LoadBalancedWebService{
+				Workload: Workload{
+					Name: aws.String("mockName"),
+				},
+				LoadBalancedWebServiceConfig: LoadBalancedWebServiceConfig{
+					TaskConfig: TaskConfig{
+						Count: Count{
+							AdvancedCount: AdvancedCount{
+								ResponseTime: durationp(10 * time.Second),
+							},
+						},
+					},
+					RoutingRule: RoutingRuleConfigOrBool{
+						Enabled: aws.Bool(false),
+					},
+					NLBConfig: NetworkLoadBalancerConfiguration{
+						Port: aws.String("80"),
+					},
+				},
+			},
+			wantedError: errors.New(`scaling based on "nlb" requests or response time is not supported`),
+		},
 	}
 	for name, tc := range testCases {
 		t.Run(name, func(t *testing.T) {
@@ -908,20 +1016,20 @@ func TestDependsOn_Validate(t *testing.T) {
 
 func TestRoutingRule_Validate(t *testing.T) {
 	testCases := map[string]struct {
-		RoutingRule RoutingRule
+		RoutingRule RoutingRuleConfiguration
 
 		wantedErrorMsgPrefix string
 		wantedError          error
 	}{
 		"error if both target_container and targetContainer are specified": {
-			RoutingRule: RoutingRule{
+			RoutingRule: RoutingRuleConfiguration{
 				TargetContainer:          aws.String("mockContainer"),
 				TargetContainerCamelCase: aws.String("mockContainer"),
 			},
 			wantedError: fmt.Errorf(`must specify one, not both, of "target_container" and "targetContainer"`),
 		},
 		"error if one of allowed_source_ips is not valid": {
-			RoutingRule: RoutingRule{
+			RoutingRule: RoutingRuleConfiguration{
 				AllowedSourceIps: []IPNet{
 					IPNet("10.1.0.0/24"),
 					IPNet("badIP"),
@@ -931,13 +1039,18 @@ func TestRoutingRule_Validate(t *testing.T) {
 			wantedErrorMsgPrefix: `validate "allowed_source_ips[1]": `,
 		},
 		"error if protocol version is not valid": {
-			RoutingRule: RoutingRule{
+			RoutingRule: RoutingRuleConfiguration{
 				ProtocolVersion: aws.String("quic"),
 			},
 			wantedErrorMsgPrefix: `"version" field value 'quic' must be one of GRPC, HTTP1 or HTTP2`,
 		},
+		"error if path is missing": {
+			RoutingRule:          RoutingRuleConfiguration{},
+			wantedErrorMsgPrefix: `"path" must be specified`,
+		},
 		"should not error if protocol version is not uppercase": {
-			RoutingRule: RoutingRule{
+			RoutingRule: RoutingRuleConfiguration{
+				Path:            stringP("/"),
 				ProtocolVersion: aws.String("gRPC"),
 			},
 		},
@@ -977,6 +1090,47 @@ func TestNetworkLoadBalancerConfiguration_Validate(t *testing.T) {
 			wantedErrorMsgPrefix: `validate "nlb": `,
 			wantedError:          fmt.Errorf(`"port" must be specified`),
 		},
+		"error parsing port": {
+			nlb: NetworkLoadBalancerConfiguration{
+				Port: aws.String("sabotage/this/string"),
+			},
+			wantedErrorMsgPrefix: `validate "nlb": `,
+			wantedError:          fmt.Errorf(`validate "port": cannot parse port mapping from sabotage/this/string`),
+		},
+		"success if port is specified without protocol": {
+			nlb: NetworkLoadBalancerConfiguration{
+				Port: aws.String("443"),
+			},
+		},
+		"fail if protocol is not recognized": {
+			nlb: NetworkLoadBalancerConfiguration{
+				Port: aws.String("443/tps"),
+			},
+			wantedErrorMsgPrefix: `validate "nlb": `,
+			wantedError:          fmt.Errorf(`validate "port": invalid protocol tps; valid protocols include TCP and TLS`),
+		},
+		"success if tcp": {
+			nlb: NetworkLoadBalancerConfiguration{
+				Port: aws.String("443/tcp"),
+			},
+		},
+		"error if udp": {
+			nlb: NetworkLoadBalancerConfiguration{
+				Port: aws.String("161/udp"),
+			},
+			wantedError: fmt.Errorf(`validate "port": invalid protocol udp; valid protocols include TCP and TLS`),
+		},
+		"success if tls": {
+			nlb: NetworkLoadBalancerConfiguration{
+				Port: aws.String("443/tls"),
+			},
+		},
+		"error if tcp_udp": {
+			nlb: NetworkLoadBalancerConfiguration{
+				Port: aws.String("443/TCP_udp"),
+			},
+			wantedError: fmt.Errorf(`validate "port": invalid protocol TCP_udp; valid protocols include TCP and TLS`),
+		},
 	}
 
 	for name, tc := range testCases {
@@ -1025,7 +1179,8 @@ func TestTaskConfig_Validate(t *testing.T) {
 	testCases := map[string]struct {
 		TaskConfig TaskConfig
 
-		wantedErrorPrefix string
+		wantedError          error
+		wantedErrorMsgPrefix string
 	}{
 		"error if fail to validate platform": {
 			TaskConfig: TaskConfig{
@@ -1033,7 +1188,7 @@ func TestTaskConfig_Validate(t *testing.T) {
 					PlatformString: (*PlatformString)(aws.String("")),
 				},
 			},
-			wantedErrorPrefix: `validate "platform": `,
+			wantedErrorMsgPrefix: `validate "platform": `,
 		},
 		"error if fail to validate count": {
 			TaskConfig: TaskConfig{
@@ -1044,7 +1199,7 @@ func TestTaskConfig_Validate(t *testing.T) {
 					},
 				},
 			},
-			wantedErrorPrefix: `validate "count": `,
+			wantedErrorMsgPrefix: `validate "count": `,
 		},
 		"error if fail to validate storage": {
 			TaskConfig: TaskConfig{
@@ -1061,18 +1216,29 @@ func TestTaskConfig_Validate(t *testing.T) {
 					},
 				},
 			},
-			wantedErrorPrefix: `validate "storage": `,
+			wantedErrorMsgPrefix: `validate "storage": `,
+		},
+		"error if invalid env file": {
+			TaskConfig: TaskConfig{
+				EnvFile: aws.String("foo"),
+			},
+			wantedError: fmt.Errorf("environment file foo must have a .env file extension"),
 		},
 	}
 	for name, tc := range testCases {
 		t.Run(name, func(t *testing.T) {
 			gotErr := tc.TaskConfig.Validate()
 
-			if tc.wantedErrorPrefix != "" {
-				require.Contains(t, gotErr.Error(), tc.wantedErrorPrefix)
-			} else {
-				require.NoError(t, gotErr)
+			if tc.wantedError != nil {
+				require.EqualError(t, gotErr, tc.wantedError.Error())
+				return
 			}
+			if tc.wantedErrorMsgPrefix != "" {
+				require.Error(t, gotErr)
+				require.Contains(t, gotErr.Error(), tc.wantedErrorMsgPrefix)
+				return
+			}
+			require.NoError(t, gotErr)
 		})
 	}
 }
