@@ -6,7 +6,6 @@ package template
 
 import (
 	"bytes"
-	"crypto/sha256"
 	"embed"
 	"fmt"
 	"io/fs"
@@ -27,12 +26,12 @@ const (
 	DNSDelegationFileName               = "dns-delegation"
 	CustomDomainFileName                = "custom-domain"
 	AppRunnerCustomDomainLambdaFileName = "custom-domain-app-runner"
-	AWSSDKLayerFileName                 = "aws-sdk-layer"
+	NLBCertValidatorLambdaFileName      = "nlb-cert-validator"
+	NLBCustomDomainLambdaFileName       = "nlb-custom-domain"
 
 	customResourceRootPath         = "custom-resources"
 	customResourceZippedScriptName = "index.js"
 	scriptDirName                  = "scripts"
-	layerDirName                   = "layers"
 )
 
 // Groups of files that belong to the same stack.
@@ -45,8 +44,9 @@ var (
 	rdWkldCustomResourceFiles = []string{
 		AppRunnerCustomDomainLambdaFileName,
 	}
-	rdWkldCustomResourceLayers = []string{
-		AWSSDKLayerFileName,
+	nlbWkldCustomResourceFiles = []string{
+		NLBCertValidatorLambdaFileName,
+		NLBCustomDomainLambdaFileName,
 	}
 )
 
@@ -124,32 +124,14 @@ func (t *Template) UploadEnvironmentCustomResources(upload s3.CompressAndUploadF
 	return t.uploadCustomResources(upload, envCustomResourceFiles)
 }
 
-//UploadRequestDrivenWebServiceCustomResources uploads the request driven web service custom resource scripts.
+// UploadRequestDrivenWebServiceCustomResources uploads the request driven web service custom resource scripts.
 func (t *Template) UploadRequestDrivenWebServiceCustomResources(upload s3.CompressAndUploadFunc) (map[string]string, error) {
 	return t.uploadCustomResources(upload, rdWkldCustomResourceFiles)
 }
 
-// UploadRequestDrivenWebServiceLayers uploads already-zipped layers for a request driven web service.
-func (t *Template) UploadRequestDrivenWebServiceLayers(upload s3.UploadFunc) (map[string]string, error) {
-	urls := make(map[string]string)
-	for _, layerName := range rdWkldCustomResourceLayers {
-		content, err := t.Read(path.Join(customResourceRootPath, fmt.Sprintf("%s.zip", layerName)))
-		if err != nil {
-			return nil, err
-		}
-		name := path.Join(layerDirName, layerName)
-		url, err := upload(fmt.Sprintf("%s/%x", name, sha256.Sum256(content.Bytes())), Uploadable{
-			name:    layerName,
-			content: content.Bytes(),
-		})
-		if err != nil {
-			return nil, fmt.Errorf("upload %s: %w", name, err)
-		}
-
-		urls[layerName] = url
-	}
-
-	return urls, nil
+// UploadLoadBalancedWebServiceNLBCustomResources uploads the network load-balanced web service custom resource scripts.
+func (t *Template) UploadNetworkLoadBalancedWebServiceCustomResources(upload s3.CompressAndUploadFunc) (map[string]string, error) {
+	return t.uploadCustomResources(upload, nlbWkldCustomResourceFiles)
 }
 
 func (t *Template) uploadCustomResources(upload s3.CompressAndUploadFunc, fileNames []string) (map[string]string, error) {
@@ -187,7 +169,7 @@ func (t *Template) uploadFileToCompress(upload s3.CompressAndUploadFunc, file fi
 	// Suffix with a SHA256 checksum of the fileToCompress so that
 	// only new content gets a new URL. Otherwise, if two fileToCompresss have the
 	// same content then the URL generated will be identical.
-	url, err := upload(fmt.Sprintf("%s/%x", file.name, sha256.Sum256(contents)), nameBinaries...)
+	url, err := upload(s3.MkdirSHA256(file.name, contents), nameBinaries...)
 	if err != nil {
 		return "", fmt.Errorf("upload %s: %w", file.name, err)
 	}
