@@ -72,6 +72,19 @@ func TestTemplate_ParseScheduledJob(t *testing.T) {
 				ServiceDiscoveryEndpoint: "test.app.local",
 			},
 		},
+		"renders with Windows platform": {
+			opts: template.WorkloadOpts{
+				Network: template.NetworkOpts{
+					AssignPublicIP: template.EnablePublicIP,
+					SubnetsType:    template.PublicSubnetsPlacement,
+				},
+				Platform: template.RuntimePlatformOpts{
+					OS:   "windows",
+					Arch: "x86_64",
+				},
+				ServiceDiscoveryEndpoint: "test.app.local",
+			},
+		},
 	}
 	for name, tc := range testCases {
 		t.Run(name, func(t *testing.T) {
@@ -109,6 +122,7 @@ func TestTemplate_ParseLoadBalancedWebService(t *testing.T) {
 					AssignPublicIP: template.EnablePublicIP,
 					SubnetsType:    template.PublicSubnetsPlacement,
 				},
+				ALBEnabled: true,
 			},
 		},
 		"renders a valid grpc template by default": {
@@ -120,6 +134,7 @@ func TestTemplate_ParseLoadBalancedWebService(t *testing.T) {
 					AssignPublicIP: template.EnablePublicIP,
 					SubnetsType:    template.PublicSubnetsPlacement,
 				},
+				ALBEnabled: true,
 			},
 		},
 		"renders a valid template with addons with no outputs": {
@@ -133,6 +148,7 @@ func TestTemplate_ParseLoadBalancedWebService(t *testing.T) {
 					SubnetsType:    template.PublicSubnetsPlacement,
 				},
 				ServiceDiscoveryEndpoint: "test.app.local",
+				ALBEnabled:               true,
 			},
 		},
 		"renders a valid template with addons with outputs": {
@@ -149,6 +165,7 @@ func TestTemplate_ParseLoadBalancedWebService(t *testing.T) {
 					SubnetsType:    template.PublicSubnetsPlacement,
 				},
 				ServiceDiscoveryEndpoint: "test.app.local",
+				ALBEnabled:               true,
 			},
 		},
 		"renders a valid template with private subnet placement": {
@@ -159,6 +176,7 @@ func TestTemplate_ParseLoadBalancedWebService(t *testing.T) {
 					SubnetsType:    template.PrivateSubnetsPlacement,
 				},
 				ServiceDiscoveryEndpoint: "test.app.local",
+				ALBEnabled:               true,
 			},
 		},
 		"renders a valid template with all storage options": {
@@ -197,6 +215,7 @@ func TestTemplate_ParseLoadBalancedWebService(t *testing.T) {
 						},
 					},
 				},
+				ALBEnabled: true,
 			},
 		},
 		"renders a valid template with minimal storage options": {
@@ -230,6 +249,7 @@ func TestTemplate_ParseLoadBalancedWebService(t *testing.T) {
 						},
 					},
 				},
+				ALBEnabled: true,
 			},
 		},
 		"renders a valid template with ephemeral storage": {
@@ -243,6 +263,7 @@ func TestTemplate_ParseLoadBalancedWebService(t *testing.T) {
 				Storage: &template.StorageOpts{
 					Ephemeral: aws.Int(500),
 				},
+				ALBEnabled: true,
 			},
 		},
 		"renders a valid template with entrypoint and command overrides": {
@@ -255,9 +276,10 @@ func TestTemplate_ParseLoadBalancedWebService(t *testing.T) {
 					AssignPublicIP: template.EnablePublicIP,
 					SubnetsType:    template.PublicSubnetsPlacement,
 				},
+				ALBEnabled: true,
 			},
 		},
-		"renders a valida template with additional addons parameters": {
+		"renders a valid template with additional addons parameters": {
 			opts: template.WorkloadOpts{
 				ServiceDiscoveryEndpoint: "test.app.local",
 				HTTPHealthCheck:          defaultHttpHealthCheck,
@@ -269,6 +291,22 @@ func TestTemplate_ParseLoadBalancedWebService(t *testing.T) {
 DiscoveryServiceArn:
   Fn::GetAtt: [DiscoveryService, Arn]
 `,
+				ALBEnabled: true,
+			},
+		},
+		"renders a valid template with Windows platform": {
+			opts: template.WorkloadOpts{
+				HTTPHealthCheck: defaultHttpHealthCheck,
+				Network: template.NetworkOpts{
+					AssignPublicIP: template.EnablePublicIP,
+					SubnetsType:    template.PublicSubnetsPlacement,
+				},
+				Platform: template.RuntimePlatformOpts{
+					OS:   "windows",
+					Arch: "x86_64",
+				},
+				ServiceDiscoveryEndpoint: "test.app.local",
+				ALBEnabled:               true,
 			},
 		},
 	}
