@@ -208,17 +208,35 @@ type HTTPHealthCheckOpts struct {
 
 // NetworkLoadBalancerListener holds configuration that's need for a Network Load Balancer listener.
 type NetworkLoadBalancerListener struct {
-	Port            string
-	Protocol        string
+	// The port and protocol that the Network Load Balancer listens to.
+	Port     string
+	Protocol string
+
+	// The target container and port to which the traffic is routed to from the Network Load Balancer.
 	TargetContainer string
 	TargetPort      string
-	SSLPolicy       *string
+
+	SSLPolicy *string // The SSL policy applied when using TLS protocol.
+
+	Aliases     []string
+	Stickiness  *bool
+	HealthCheck NLBHealthCheck
+}
+
+// NLBHealthCheck holds configuration for Network Load Balancer health check.
+type NLBHealthCheck struct {
+	Port               string // The port to which health check requests made from Network Load Balancer are routed to.
+	HealthyThreshold   *int64
+	UnhealthyThreshold *int64
+	Timeout            *int64
+	Interval           *int64
 }
 
 // NetworkLoadBalancer holds configuration that's needed for a Network Load Balancer.
 type NetworkLoadBalancer struct {
 	PublicSubnetCIDRs []string
 	Listener          NetworkLoadBalancerListener
+	MainContainerPort string
 }
 
 // AdvancedCount holds configuration for autoscaling and capacity provider
@@ -388,6 +406,7 @@ type WorkloadOpts struct {
 	Publish                  *PublishOpts
 	ServiceDiscoveryEndpoint string
 	HTTPVersion              *string
+	ALBEnabled               bool
 
 	// Additional options for service templates.
 	WorkloadType        string
@@ -403,6 +422,8 @@ type WorkloadOpts struct {
 	EnvControllerLambda            string
 	CredentialsParameter           string
 	BacklogPerTaskCalculatorLambda string
+	NLBCertValidatorFunctionLambda string
+	NLBCustomDomainFunctionLambda  string
 
 	// Additional options for job templates.
 	ScheduleExpression string
@@ -421,9 +442,6 @@ type WorkloadOpts struct {
 
 	// Additional options for worker service templates.
 	Subscribe *SubscribeOpts
-
-	// List of features to enable for testing that are not yet released.
-	FeatureFlags []string
 }
 
 // ParseLoadBalancedWebService parses a load balanced web service's CloudFormation template
@@ -527,7 +545,10 @@ func randomUUIDFunc() (string, error) {
 func envControllerParameters(o WorkloadOpts) []string {
 	parameters := []string{}
 	if o.WorkloadType == "Load Balanced Web Service" {
-		parameters = append(parameters, []string{"ALBWorkloads,", "Aliases,"}...) // YAML needs the comma separator; resolved in EnvContr.
+		if o.ALBEnabled {
+			parameters = append(parameters, "ALBWorkloads,")
+		}
+		parameters = append(parameters, "Aliases,") // YAML needs the comma separator; resolved in EnvContr.
 	}
 	if o.Network.SubnetsType == PrivateSubnetsPlacement {
 		parameters = append(parameters, "NATWorkloads,")
