@@ -93,7 +93,7 @@ type Prompter interface {
 	Get(message, help string, validator prompt.ValidatorFunc, promptOpts ...prompt.PromptConfig) (string, error)
 	SelectOne(message, help string, options []string, promptOpts ...prompt.PromptConfig) (string, error)
 	SelectOption(message, help string, opts []prompt.Option, promptCfgs ...prompt.PromptConfig) (value string, err error)
-	MultiSelect(message, help string, options []string, promptOpts ...prompt.PromptConfig) ([]string, error)
+	MultiSelect(message, help string, options []string, validator prompt.ValidatorFunc, promptOpts ...prompt.PromptConfig) ([]string, error)
 	Confirm(message, help string, promptOpts ...prompt.PromptConfig) (bool, error)
 }
 
@@ -1078,6 +1078,7 @@ func (s *DeploySelect) Topics(promptMsg, help, app string) ([]deploy.Topic, erro
 		promptMsg,
 		help,
 		topicDescriptions,
+		nil,
 		prompt.WithFinalMessage(topicFinalmessage),
 	)
 	if err != nil {
